(* ****************************************************************** *)
(* *****                                                        ***** *)
(* *****  FeynRules model file: Simplified DM models            ***** *)
(* *****                        s-channel spin-1 mediator       ***** *)
(* *****                        Dirac fermion DM                ***** *)
(* *****  Author: C. Chang                                      ***** *)
(* *****                                                        ***** *)
(* ****************************************************************** *)

(* NOTE: This is modified from a model file provided at: http://feynrules.irmp.ucl.ac.be/wiki/DMsimp/ *)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)

M$ModelName = "DMsimp_s_spin1_DiracDM";

M$Information = {
 Authors      -> {"C. Chang"}, 
 Institutions -> {"University of Queensland"},
 Emails       -> {"christopher.chang@uq.net.au"},
};

(***** Setting for interaction order (as e.g. used by MadGraph 5)  ******)

M$InteractionOrderLimit = {
 {DMV, 2}
};

M$InteractionOrderHierarchy = {
 {QCD, 1}, {DMV, 2}, {QED, 2}
};


(* ************************** *)
(* *****     Fields     ***** *)
(* ************************** *)
M$ClassesDescription = {

F[7] == { ClassName -> Xd,
          SelfConjugate -> False,
	      Mass -> {MXd, 10.},
          Width -> 0,
          QuantumNumbers   -> {Q -> 0},
          PDG -> 5000521,
          TeX -> Subscript[X,d],
          FullName -> "Dirac DM" },

V[7] == { ClassName -> Y1,
	      SelfConjugate -> True,
	      Mass -> {MY1, 1000.},
          Width -> {WY1, 10.},
          PDG -> 5000001,
          TeX -> Subscript[Y,1],
          FullName -> "spin-1 mediator" }

};


(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)  
M$Parameters = {

 gVXd == { 
      ParameterType -> External,
      InteractionOrder -> {DMV, 1},
      BlockName -> DMINPUTS,
      OrderBlock       -> 2,
      TeX -> Subscript[g,VXd],
      Description -> "Xd-Y1 vector coupling",
      Value -> 1. },     	  

 gAXd == { 
      ParameterType -> External,
      InteractionOrder -> {DMV, 1},
      BlockName -> DMINPUTS,
      OrderBlock       -> 3,
      TeX -> Subscript[g,AXd],
      Description -> "Xd-Y1 axial-vector coupling",
      Value -> 0. },     	  

 gVq == { 
      ParameterType -> External,
      InteractionOrder -> {DMV, 1},
      BlockName -> DMINPUTS,
      OrderBlock       -> 4,
      TeX -> Subscript[g,Vq],
      Description -> "q-Y1 vector coupling",
      Value -> 0.25 }


};


(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)

L1X := Xdbar.Ga[mu].(gVXd + gAXd Ga[5]).Xd Y1[mu];
      
L1SM := dbar.Ga[mu].(gVq).d Y1[mu] +
        ubar.Ga[mu].(gVq).u Y1[mu] +
        sbar.Ga[mu].(gVq).s Y1[mu] +
        cbar.Ga[mu].(gVq).c Y1[mu] +
        bbar.Ga[mu].(gVq).b Y1[mu] +
        tbar.Ga[mu].(gVq).t Y1[mu];


LDM := L1X + L1SM;
