#include "gambit/ColliderBit/limits/ALEPHSleptonLimits.hpp"

namespace Gambit {
  namespace ColliderBit {

    P2 ALEPHSelectronLimitAt208GeV::convertPt(double x, double y) const
    {
      return P2(50. + (x - 243.00) / (886.00 - 243.00) * (100. - 50.),
                100. + (y - 67.00) / (806.00 - 67.00) * (0. - 100.));
    }

    bool ALEPHSelectronLimitAt208GeV::isWithinExclusionRegion(double x, double y, double mZ) const
    {
      return (y <= x and x <= 208. / 2. and x > mZ / 2.);
    }

    ALEPHSelectronLimitAt208GeV::ALEPHSelectronLimitAt208GeV()
    {
      ///// Limit values /////
      _limitValuesSorted.push_back(0.02);
      _limitValuesSorted.push_back(0.04);
      _limitValuesSorted.push_back(0.06);
      _limitValuesSorted.push_back(0.08);
      _limitValuesSorted.push_back(0.10);
      _limitValuesSorted.push_back(0.12);
      _limitValuesSorted.push_back(0.14);
      _limitValuesSorted.push_back(0.16);
      _limitValuesSorted.push_back(0.18);
      _limitValuesSorted.push_back(0.2);

      ///// Limit Contours /////
      Corners corners;
      ContoursPointer contoursPointer;
      size_t oldSize;

      ///// 0.02pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,207.00));
      corners.push_back(convertPt(782.00,215.00));
      corners.push_back(convertPt(769.00,215.00));
      corners.push_back(convertPt(769.00,207.00));
      corners.push_back(convertPt(782.00,207.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(756.00,223.00));
      corners.push_back(convertPt(756.00,230.00));
      corners.push_back(convertPt(744.00,230.00));
      corners.push_back(convertPt(744.00,223.00));
      corners.push_back(convertPt(756.00,223.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,223.00));
      corners.push_back(convertPt(782.00,230.00));
      corners.push_back(convertPt(769.00,230.00));
      corners.push_back(convertPt(769.00,223.00));
      corners.push_back(convertPt(782.00,223.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(731.00,237.00));
      corners.push_back(convertPt(731.00,245.00));
      corners.push_back(convertPt(718.00,245.00));
      corners.push_back(convertPt(718.00,252.00));
      corners.push_back(convertPt(705.00,252.00));
      corners.push_back(convertPt(705.00,259.00));
      corners.push_back(convertPt(692.00,259.00));
      corners.push_back(convertPt(692.00,267.00));
      corners.push_back(convertPt(679.00,267.00));
      corners.push_back(convertPt(679.00,275.00));
      corners.push_back(convertPt(667.00,275.00));
      corners.push_back(convertPt(667.00,282.00));
      corners.push_back(convertPt(654.00,282.00));
      corners.push_back(convertPt(654.00,289.00));
      corners.push_back(convertPt(641.00,289.00));
      corners.push_back(convertPt(641.00,297.00));
      corners.push_back(convertPt(628.00,297.00));
      corners.push_back(convertPt(628.00,304.00));
      corners.push_back(convertPt(589.00,304.00));
      corners.push_back(convertPt(589.00,311.00));
      corners.push_back(convertPt(577.00,311.00));
      corners.push_back(convertPt(577.00,319.00));
      corners.push_back(convertPt(564.00,319.00));
      corners.push_back(convertPt(564.00,326.00));
      corners.push_back(convertPt(551.00,326.00));
      corners.push_back(convertPt(551.00,334.00));
      corners.push_back(convertPt(538.00,334.00));
      corners.push_back(convertPt(538.00,341.00));
      corners.push_back(convertPt(525.00,341.00));
      corners.push_back(convertPt(525.00,349.00));
      corners.push_back(convertPt(512.00,349.00));
      corners.push_back(convertPt(512.00,356.00));
      corners.push_back(convertPt(500.00,356.00));
      corners.push_back(convertPt(500.00,363.00));
      corners.push_back(convertPt(486.00,363.00));
      corners.push_back(convertPt(486.00,371.00));
      corners.push_back(convertPt(474.00,371.00));
      corners.push_back(convertPt(474.00,379.00));
      corners.push_back(convertPt(461.00,379.00));
      corners.push_back(convertPt(461.00,386.00));
      corners.push_back(convertPt(448.00,386.00));
      corners.push_back(convertPt(448.00,393.00));
      corners.push_back(convertPt(435.00,393.00));
      corners.push_back(convertPt(435.00,400.00));
      corners.push_back(convertPt(422.00,400.00));
      corners.push_back(convertPt(422.00,407.00));
      corners.push_back(convertPt(409.00,407.00));
      corners.push_back(convertPt(409.00,415.00));
      corners.push_back(convertPt(397.00,415.00));
      corners.push_back(convertPt(397.00,423.00));
      corners.push_back(convertPt(384.00,423.00));
      corners.push_back(convertPt(384.00,430.00));
      corners.push_back(convertPt(371.00,430.00));
      corners.push_back(convertPt(371.00,437.00));
      corners.push_back(convertPt(358.00,437.00));
      corners.push_back(convertPt(358.00,445.00));
      corners.push_back(convertPt(345.00,445.00));
      corners.push_back(convertPt(345.00,452.00));
      corners.push_back(convertPt(333.00,452.00));
      corners.push_back(convertPt(333.00,459.00));
      corners.push_back(convertPt(319.00,459.00));
      corners.push_back(convertPt(319.00,467.00));
      corners.push_back(convertPt(306.00,467.00));
      corners.push_back(convertPt(306.00,474.00));
      corners.push_back(convertPt(293.00,474.00));
      corners.push_back(convertPt(293.00,482.00));
      corners.push_back(convertPt(281.00,482.00));
      corners.push_back(convertPt(281.00,489.00));
      corners.push_back(convertPt(268.00,489.00));
      corners.push_back(convertPt(268.00,496.00));
      corners.push_back(convertPt(255.00,496.00));
      corners.push_back(convertPt(255.00,503.00));
      corners.push_back(convertPt(243.00,503.00));
      corners.push_back(convertPt(243.00,511.00));
      corners.push_back(convertPt(230.00,511.00));
      corners.push_back(convertPt(230.00,519.00));
      corners.push_back(convertPt(217.00,519.00));
      corners.push_back(convertPt(217.00,526.00));
      corners.push_back(convertPt(204.00,526.00));
      corners.push_back(convertPt(204.00,533.00));
      corners.push_back(convertPt(191.00,533.00));
      corners.push_back(convertPt(191.00,548.00));
      corners.push_back(convertPt(179.00,548.00));
      corners.push_back(convertPt(179.00,526.00));
      corners.push_back(convertPt(191.00,526.00));
      corners.push_back(convertPt(191.00,519.00));
      corners.push_back(convertPt(204.00,519.00));
      corners.push_back(convertPt(204.00,511.00));
      corners.push_back(convertPt(217.00,511.00));
      corners.push_back(convertPt(217.00,503.00));
      corners.push_back(convertPt(230.00,503.00));
      corners.push_back(convertPt(230.00,496.00));
      corners.push_back(convertPt(243.00,496.00));
      corners.push_back(convertPt(243.00,489.00));
      corners.push_back(convertPt(255.00,489.00));
      corners.push_back(convertPt(255.00,482.00));
      corners.push_back(convertPt(268.00,482.00));
      corners.push_back(convertPt(268.00,474.00));
      corners.push_back(convertPt(281.00,474.00));
      corners.push_back(convertPt(281.00,467.00));
      corners.push_back(convertPt(293.00,467.00));
      corners.push_back(convertPt(293.00,459.00));
      corners.push_back(convertPt(306.00,459.00));
      corners.push_back(convertPt(306.00,452.00));
      corners.push_back(convertPt(319.00,452.00));
      corners.push_back(convertPt(319.00,445.00));
      corners.push_back(convertPt(333.00,445.00));
      corners.push_back(convertPt(333.00,437.00));
      corners.push_back(convertPt(345.00,437.00));
      corners.push_back(convertPt(345.00,430.00));
      corners.push_back(convertPt(358.00,430.00));
      corners.push_back(convertPt(358.00,423.00));
      corners.push_back(convertPt(371.00,423.00));
      corners.push_back(convertPt(371.00,415.00));
      corners.push_back(convertPt(384.00,415.00));
      corners.push_back(convertPt(384.00,407.00));
      corners.push_back(convertPt(397.00,407.00));
      corners.push_back(convertPt(397.00,400.00));
      corners.push_back(convertPt(409.00,400.00));
      corners.push_back(convertPt(409.00,393.00));
      corners.push_back(convertPt(422.00,393.00));
      corners.push_back(convertPt(422.00,386.00));
      corners.push_back(convertPt(448.00,386.00));
      corners.push_back(convertPt(448.00,379.00));
      corners.push_back(convertPt(461.00,379.00));
      corners.push_back(convertPt(461.00,371.00));
      corners.push_back(convertPt(474.00,371.00));
      corners.push_back(convertPt(474.00,363.00));
      corners.push_back(convertPt(486.00,363.00));
      corners.push_back(convertPt(486.00,356.00));
      corners.push_back(convertPt(500.00,356.00));
      corners.push_back(convertPt(500.00,349.00));
      corners.push_back(convertPt(512.00,349.00));
      corners.push_back(convertPt(512.00,341.00));
      corners.push_back(convertPt(525.00,341.00));
      corners.push_back(convertPt(525.00,334.00));
      corners.push_back(convertPt(538.00,334.00));
      corners.push_back(convertPt(538.00,326.00));
      corners.push_back(convertPt(551.00,326.00));
      corners.push_back(convertPt(551.00,319.00));
      corners.push_back(convertPt(564.00,319.00));
      corners.push_back(convertPt(564.00,311.00));
      corners.push_back(convertPt(577.00,311.00));
      corners.push_back(convertPt(577.00,304.00));
      corners.push_back(convertPt(589.00,304.00));
      corners.push_back(convertPt(589.00,297.00));
      corners.push_back(convertPt(602.00,297.00));
      corners.push_back(convertPt(602.00,289.00));
      corners.push_back(convertPt(615.00,289.00));
      corners.push_back(convertPt(615.00,282.00));
      corners.push_back(convertPt(641.00,282.00));
      corners.push_back(convertPt(641.00,275.00));
      corners.push_back(convertPt(654.00,275.00));
      corners.push_back(convertPt(654.00,267.00));
      corners.push_back(convertPt(667.00,267.00));
      corners.push_back(convertPt(667.00,259.00));
      corners.push_back(convertPt(692.00,259.00));
      corners.push_back(convertPt(692.00,252.00));
      corners.push_back(convertPt(705.00,252.00));
      corners.push_back(convertPt(705.00,245.00));
      corners.push_back(convertPt(718.00,245.00));
      corners.push_back(convertPt(718.00,237.00));
      corners.push_back(convertPt(731.00,237.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(0, contoursPointer));

      ///// 0.04pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(873.00,149.00));
      corners.push_back(convertPt(873.00,163.00));
      corners.push_back(convertPt(885.00,163.00));
      corners.push_back(convertPt(885.00,178.00));
      corners.push_back(convertPt(860.00,178.00));
      corners.push_back(convertPt(860.00,186.00));
      corners.push_back(convertPt(846.00,186.00));
      corners.push_back(convertPt(846.00,193.00));
      corners.push_back(convertPt(860.00,193.00));
      corners.push_back(convertPt(860.00,207.00));
      corners.push_back(convertPt(873.00,207.00));
      corners.push_back(convertPt(873.00,215.00));
      corners.push_back(convertPt(860.00,215.00));
      corners.push_back(convertPt(860.00,223.00));
      corners.push_back(convertPt(846.00,223.00));
      corners.push_back(convertPt(846.00,237.00));
      corners.push_back(convertPt(834.00,237.00));
      corners.push_back(convertPt(834.00,245.00));
      corners.push_back(convertPt(808.00,245.00));
      corners.push_back(convertPt(808.00,252.00));
      corners.push_back(convertPt(820.00,252.00));
      corners.push_back(convertPt(820.00,259.00));
      corners.push_back(convertPt(795.00,259.00));
      corners.push_back(convertPt(795.00,275.00));
      corners.push_back(convertPt(808.00,275.00));
      corners.push_back(convertPt(808.00,282.00));
      corners.push_back(convertPt(757.00,282.00));
      corners.push_back(convertPt(757.00,297.00));
      corners.push_back(convertPt(744.00,297.00));
      corners.push_back(convertPt(744.00,304.00));
      corners.push_back(convertPt(705.00,304.00));
      corners.push_back(convertPt(705.00,311.00));
      corners.push_back(convertPt(693.00,311.00));
      corners.push_back(convertPt(693.00,319.00));
      corners.push_back(convertPt(679.00,319.00));
      corners.push_back(convertPt(679.00,334.00));
      corners.push_back(convertPt(667.00,334.00));
      corners.push_back(convertPt(667.00,327.00));
      corners.push_back(convertPt(653.00,327.00));
      corners.push_back(convertPt(653.00,334.00));
      corners.push_back(convertPt(640.00,334.00));
      corners.push_back(convertPt(640.00,349.00));
      corners.push_back(convertPt(602.00,349.00));
      corners.push_back(convertPt(602.00,356.00));
      corners.push_back(convertPt(589.00,356.00));
      corners.push_back(convertPt(589.00,363.00));
      corners.push_back(convertPt(564.00,363.00));
      corners.push_back(convertPt(564.00,370.00));
      corners.push_back(convertPt(551.00,370.00));
      corners.push_back(convertPt(551.00,386.00));
      corners.push_back(convertPt(538.00,386.00));
      corners.push_back(convertPt(538.00,400.00));
      corners.push_back(convertPt(486.00,400.00));
      corners.push_back(convertPt(486.00,407.00));
      corners.push_back(convertPt(461.00,407.00));
      corners.push_back(convertPt(461.00,415.00));
      corners.push_back(convertPt(448.00,415.00));
      corners.push_back(convertPt(448.00,423.00));
      corners.push_back(convertPt(422.00,423.00));
      corners.push_back(convertPt(422.00,430.00));
      corners.push_back(convertPt(409.00,430.00));
      corners.push_back(convertPt(409.00,437.00));
      corners.push_back(convertPt(397.00,437.00));
      corners.push_back(convertPt(397.00,445.00));
      corners.push_back(convertPt(384.00,445.00));
      corners.push_back(convertPt(384.00,452.00));
      corners.push_back(convertPt(371.00,452.00));
      corners.push_back(convertPt(371.00,459.00));
      corners.push_back(convertPt(358.00,459.00));
      corners.push_back(convertPt(358.00,467.00));
      corners.push_back(convertPt(345.00,467.00));
      corners.push_back(convertPt(345.00,474.00));
      corners.push_back(convertPt(319.00,474.00));
      corners.push_back(convertPt(319.00,482.00));
      corners.push_back(convertPt(306.00,482.00));
      corners.push_back(convertPt(306.00,489.00));
      corners.push_back(convertPt(293.00,489.00));
      corners.push_back(convertPt(293.00,496.00));
      corners.push_back(convertPt(268.00,496.00));
      corners.push_back(convertPt(268.00,503.00));
      corners.push_back(convertPt(255.00,503.00));
      corners.push_back(convertPt(255.00,511.00));
      corners.push_back(convertPt(243.00,511.00));
      corners.push_back(convertPt(243.00,526.00));
      corners.push_back(convertPt(230.00,526.00));
      corners.push_back(convertPt(230.00,533.00));
      corners.push_back(convertPt(217.00,533.00));
      corners.push_back(convertPt(217.00,541.00));
      corners.push_back(convertPt(204.00,541.00));
      corners.push_back(convertPt(204.00,548.00));
      corners.push_back(convertPt(191.00,548.00));
      corners.push_back(convertPt(191.00,555.00));
      corners.push_back(convertPt(179.00,555.00));
      corners.push_back(convertPt(179.00,503.00));
      corners.push_back(convertPt(191.00,503.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(204.00,496.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(217.00,489.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(230.00,482.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(243.00,475.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(255.00,467.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(268.00,460.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(281.00,452.00));
      corners.push_back(convertPt(281.00,445.00));
      corners.push_back(convertPt(293.00,445.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(306.00,437.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(319.00,430.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(333.00,422.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(345.00,415.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(358.00,407.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(371.00,400.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(384.00,393.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(397.00,386.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(409.00,379.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(422.00,371.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(435.00,363.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(448.00,356.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(461.00,349.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(473.00,341.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(486.00,334.00));
      corners.push_back(convertPt(486.00,326.00));
      corners.push_back(convertPt(500.00,326.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(512.00,319.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(538.00,311.00));
      corners.push_back(convertPt(538.00,304.00));
      corners.push_back(convertPt(551.00,304.00));
      corners.push_back(convertPt(551.00,297.00));
      corners.push_back(convertPt(564.00,297.00));
      corners.push_back(convertPt(564.00,289.00));
      corners.push_back(convertPt(577.00,289.00));
      corners.push_back(convertPt(577.00,282.00));
      corners.push_back(convertPt(589.00,282.00));
      corners.push_back(convertPt(589.00,275.00));
      corners.push_back(convertPt(602.00,275.00));
      corners.push_back(convertPt(602.00,267.00));
      corners.push_back(convertPt(615.00,267.00));
      corners.push_back(convertPt(615.00,259.00));
      corners.push_back(convertPt(628.00,259.00));
      corners.push_back(convertPt(628.00,252.00));
      corners.push_back(convertPt(641.00,252.00));
      corners.push_back(convertPt(641.00,245.00));
      corners.push_back(convertPt(654.00,245.00));
      corners.push_back(convertPt(654.00,237.00));
      corners.push_back(convertPt(667.00,237.00));
      corners.push_back(convertPt(667.00,230.00));
      corners.push_back(convertPt(679.00,230.00));
      corners.push_back(convertPt(679.00,223.00));
      corners.push_back(convertPt(692.00,223.00));
      corners.push_back(convertPt(692.00,215.00));
      corners.push_back(convertPt(705.00,215.00));
      corners.push_back(convertPt(705.00,207.00));
      corners.push_back(convertPt(718.00,207.00));
      corners.push_back(convertPt(718.00,200.00));
      corners.push_back(convertPt(731.00,200.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(756.00,193.00));
      corners.push_back(convertPt(756.00,186.00));
      corners.push_back(convertPt(769.00,186.00));
      corners.push_back(convertPt(769.00,178.00));
      corners.push_back(convertPt(782.00,178.00));
      corners.push_back(convertPt(782.00,171.00));
      corners.push_back(convertPt(795.00,171.00));
      corners.push_back(convertPt(795.00,163.00));
      corners.push_back(convertPt(808.00,163.00));
      corners.push_back(convertPt(808.00,156.00));
      corners.push_back(convertPt(834.00,156.00));
      corners.push_back(convertPt(834.00,149.00));
      corners.push_back(convertPt(873.00,149.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(757.00,311.00));
      corners.push_back(convertPt(757.00,319.00));
      corners.push_back(convertPt(744.00,319.00));
      corners.push_back(convertPt(744.00,311.00));
      corners.push_back(convertPt(757.00,311.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(679.00,341.00));
      corners.push_back(convertPt(679.00,349.00));
      corners.push_back(convertPt(667.00,349.00));
      corners.push_back(convertPt(667.00,341.00));
      corners.push_back(convertPt(679.00,341.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(1, contoursPointer));

      ///// 0.06pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(898.00,127.00));
      corners.push_back(convertPt(898.00,149.00));
      corners.push_back(convertPt(911.00,149.00));
      corners.push_back(convertPt(911.00,170.00));
      corners.push_back(convertPt(885.00,170.00));
      corners.push_back(convertPt(885.00,186.00));
      corners.push_back(convertPt(898.00,186.00));
      corners.push_back(convertPt(898.00,215.00));
      corners.push_back(convertPt(885.00,215.00));
      corners.push_back(convertPt(885.00,230.00));
      corners.push_back(convertPt(873.00,230.00));
      corners.push_back(convertPt(873.00,252.00));
      corners.push_back(convertPt(860.00,252.00));
      corners.push_back(convertPt(860.00,267.00));
      corners.push_back(convertPt(873.00,267.00));
      corners.push_back(convertPt(873.00,275.00));
      corners.push_back(convertPt(820.00,275.00));
      corners.push_back(convertPt(820.00,289.00));
      corners.push_back(convertPt(795.00,289.00));
      corners.push_back(convertPt(795.00,311.00));
      corners.push_back(convertPt(808.00,311.00));
      corners.push_back(convertPt(808.00,319.00));
      corners.push_back(convertPt(795.00,319.00));
      corners.push_back(convertPt(795.00,311.00));
      corners.push_back(convertPt(782.00,311.00));
      corners.push_back(convertPt(782.00,326.00));
      corners.push_back(convertPt(769.00,326.00));
      corners.push_back(convertPt(769.00,334.00));
      corners.push_back(convertPt(731.00,334.00));
      corners.push_back(convertPt(731.00,341.00));
      corners.push_back(convertPt(718.00,341.00));
      corners.push_back(convertPt(718.00,349.00));
      corners.push_back(convertPt(705.00,349.00));
      corners.push_back(convertPt(705.00,356.00));
      corners.push_back(convertPt(679.00,356.00));
      corners.push_back(convertPt(679.00,363.00));
      corners.push_back(convertPt(653.00,363.00));
      corners.push_back(convertPt(653.00,371.00));
      corners.push_back(convertPt(640.00,371.00));
      corners.push_back(convertPt(640.00,379.00));
      corners.push_back(convertPt(627.00,379.00));
      corners.push_back(convertPt(627.00,386.00));
      corners.push_back(convertPt(602.00,386.00));
      corners.push_back(convertPt(602.00,393.00));
      corners.push_back(convertPt(577.00,393.00));
      corners.push_back(convertPt(577.00,416.00));
      corners.push_back(convertPt(564.00,416.00));
      corners.push_back(convertPt(564.00,423.00));
      corners.push_back(convertPt(526.00,423.00));
      corners.push_back(convertPt(526.00,430.00));
      corners.push_back(convertPt(512.00,430.00));
      corners.push_back(convertPt(512.00,445.00));
      corners.push_back(convertPt(500.00,445.00));
      corners.push_back(convertPt(500.00,452.00));
      corners.push_back(convertPt(486.00,452.00));
      corners.push_back(convertPt(486.00,459.00));
      corners.push_back(convertPt(461.00,459.00));
      corners.push_back(convertPt(461.00,452.00));
      corners.push_back(convertPt(422.00,452.00));
      corners.push_back(convertPt(422.00,467.00));
      corners.push_back(convertPt(410.00,467.00));
      corners.push_back(convertPt(410.00,482.00));
      corners.push_back(convertPt(384.00,482.00));
      corners.push_back(convertPt(384.00,489.00));
      corners.push_back(convertPt(345.00,489.00));
      corners.push_back(convertPt(345.00,496.00));
      corners.push_back(convertPt(333.00,496.00));
      corners.push_back(convertPt(333.00,511.00));
      corners.push_back(convertPt(268.00,511.00));
      corners.push_back(convertPt(268.00,518.00));
      corners.push_back(convertPt(255.00,518.00));
      corners.push_back(convertPt(255.00,533.00));
      corners.push_back(convertPt(242.00,533.00));
      corners.push_back(convertPt(242.00,541.00));
      corners.push_back(convertPt(217.00,541.00));
      corners.push_back(convertPt(217.00,555.00));
      corners.push_back(convertPt(204.00,555.00));
      corners.push_back(convertPt(204.00,562.00));
      corners.push_back(convertPt(179.00,562.00));
      corners.push_back(convertPt(179.00,555.00));
      corners.push_back(convertPt(179.00,503.00));
      corners.push_back(convertPt(191.00,503.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(204.00,496.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(217.00,489.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(230.00,482.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(243.00,475.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(255.00,467.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(268.00,460.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(281.00,452.00));
      corners.push_back(convertPt(281.00,445.00));
      corners.push_back(convertPt(293.00,445.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(306.00,437.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(319.00,430.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(333.00,422.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(345.00,415.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(358.00,407.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(371.00,400.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(384.00,393.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(397.00,386.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(409.00,379.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(422.00,371.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(435.00,363.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(448.00,356.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(461.00,349.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(473.00,341.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(486.00,334.00));
      corners.push_back(convertPt(486.00,326.00));
      corners.push_back(convertPt(500.00,326.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(512.00,319.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(525.00,311.00));
      corners.push_back(convertPt(525.00,304.00));
      corners.push_back(convertPt(538.00,304.00));
      corners.push_back(convertPt(538.00,297.00));
      corners.push_back(convertPt(551.00,297.00));
      corners.push_back(convertPt(551.00,289.00));
      corners.push_back(convertPt(564.00,289.00));
      corners.push_back(convertPt(564.00,282.00));
      corners.push_back(convertPt(577.00,282.00));
      corners.push_back(convertPt(577.00,275.00));
      corners.push_back(convertPt(589.00,275.00));
      corners.push_back(convertPt(589.00,267.00));
      corners.push_back(convertPt(602.00,267.00));
      corners.push_back(convertPt(602.00,259.00));
      corners.push_back(convertPt(615.00,259.00));
      corners.push_back(convertPt(615.00,252.00));
      corners.push_back(convertPt(641.00,252.00));
      corners.push_back(convertPt(641.00,245.00));
      corners.push_back(convertPt(654.00,245.00));
      corners.push_back(convertPt(654.00,237.00));
      corners.push_back(convertPt(667.00,237.00));
      corners.push_back(convertPt(667.00,230.00));
      corners.push_back(convertPt(679.00,230.00));
      corners.push_back(convertPt(679.00,223.00));
      corners.push_back(convertPt(692.00,223.00));
      corners.push_back(convertPt(692.00,215.00));
      corners.push_back(convertPt(705.00,215.00));
      corners.push_back(convertPt(705.00,207.00));
      corners.push_back(convertPt(718.00,207.00));
      corners.push_back(convertPt(718.00,200.00));
      corners.push_back(convertPt(731.00,200.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(744.00,193.00));
      corners.push_back(convertPt(744.00,186.00));
      corners.push_back(convertPt(769.00,186.00));
      corners.push_back(convertPt(769.00,178.00));
      corners.push_back(convertPt(782.00,178.00));
      corners.push_back(convertPt(782.00,171.00));
      corners.push_back(convertPt(795.00,171.00));
      corners.push_back(convertPt(795.00,163.00));
      corners.push_back(convertPt(808.00,163.00));
      corners.push_back(convertPt(808.00,156.00));
      corners.push_back(convertPt(834.00,156.00));
      corners.push_back(convertPt(834.00,149.00));
      corners.push_back(convertPt(846.00,149.00));
      corners.push_back(convertPt(846.00,141.00));
      corners.push_back(convertPt(860.00,141.00));
      corners.push_back(convertPt(860.00,134.00));
      corners.push_back(convertPt(885.00,134.00));
      corners.push_back(convertPt(885.00,127.00));
      corners.push_back(convertPt(898.00,127.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(679.00,386.00));
      corners.push_back(convertPt(679.00,393.00));
      corners.push_back(convertPt(667.00,393.00));
      corners.push_back(convertPt(667.00,386.00));
      corners.push_back(convertPt(679.00,386.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(705.00,386.00));
      corners.push_back(convertPt(705.00,393.00));
      corners.push_back(convertPt(693.00,393.00));
      corners.push_back(convertPt(693.00,386.00));
      corners.push_back(convertPt(705.00,386.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(2, contoursPointer));

      ///// 0.08pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(911.00,120.00));
      corners.push_back(convertPt(911.00,230.00));
      corners.push_back(convertPt(898.00,230.00));
      corners.push_back(convertPt(898.00,252.00));
      corners.push_back(convertPt(885.00,252.00));
      corners.push_back(convertPt(885.00,267.00));
      corners.push_back(convertPt(898.00,267.00));
      corners.push_back(convertPt(898.00,275.00));
      corners.push_back(convertPt(873.00,275.00));
      corners.push_back(convertPt(873.00,282.00));
      corners.push_back(convertPt(860.00,282.00));
      corners.push_back(convertPt(860.00,289.00));
      corners.push_back(convertPt(834.00,289.00));
      corners.push_back(convertPt(834.00,297.00));
      corners.push_back(convertPt(846.00,297.00));
      corners.push_back(convertPt(846.00,311.00));
      corners.push_back(convertPt(834.00,311.00));
      corners.push_back(convertPt(834.00,319.00));
      corners.push_back(convertPt(821.00,319.00));
      corners.push_back(convertPt(821.00,334.00));
      corners.push_back(convertPt(795.00,334.00));
      corners.push_back(convertPt(795.00,349.00));
      corners.push_back(convertPt(757.00,349.00));
      corners.push_back(convertPt(757.00,363.00));
      corners.push_back(convertPt(705.00,363.00));
      corners.push_back(convertPt(705.00,370.00));
      corners.push_back(convertPt(731.00,370.00));
      corners.push_back(convertPt(731.00,378.00));
      corners.push_back(convertPt(744.00,378.00));
      corners.push_back(convertPt(744.00,386.00));
      corners.push_back(convertPt(757.00,386.00));
      corners.push_back(convertPt(757.00,393.00));
      corners.push_back(convertPt(769.00,393.00));
      corners.push_back(convertPt(769.00,400.00));
      corners.push_back(convertPt(731.00,400.00));
      corners.push_back(convertPt(731.00,407.00));
      corners.push_back(convertPt(679.00,407.00));
      corners.push_back(convertPt(679.00,423.00));
      corners.push_back(convertPt(667.00,423.00));
      corners.push_back(convertPt(667.00,430.00));
      corners.push_back(convertPt(628.00,430.00));
      corners.push_back(convertPt(628.00,437.00));
      corners.push_back(convertPt(602.00,437.00));
      corners.push_back(convertPt(602.00,445.00));
      corners.push_back(convertPt(577.00,445.00));
      corners.push_back(convertPt(577.00,452.00));
      corners.push_back(convertPt(564.00,452.00));
      corners.push_back(convertPt(564.00,459.00));
      corners.push_back(convertPt(538.00,459.00));
      corners.push_back(convertPt(538.00,467.00));
      corners.push_back(convertPt(500.00,467.00));
      corners.push_back(convertPt(500.00,475.00));
      corners.push_back(convertPt(473.00,475.00));
      corners.push_back(convertPt(473.00,482.00));
      corners.push_back(convertPt(461.00,482.00));
      corners.push_back(convertPt(461.00,489.00));
      corners.push_back(convertPt(448.00,489.00));
      corners.push_back(convertPt(448.00,496.00));
      corners.push_back(convertPt(397.00,496.00));
      corners.push_back(convertPt(397.00,503.00));
      corners.push_back(convertPt(371.00,503.00));
      corners.push_back(convertPt(371.00,511.00));
      corners.push_back(convertPt(358.00,511.00));
      corners.push_back(convertPt(358.00,519.00));
      corners.push_back(convertPt(345.00,519.00));
      corners.push_back(convertPt(345.00,526.00));
      corners.push_back(convertPt(306.00,526.00));
      corners.push_back(convertPt(306.00,533.00));
      corners.push_back(convertPt(268.00,533.00));
      corners.push_back(convertPt(268.00,541.00));
      corners.push_back(convertPt(255.00,541.00));
      corners.push_back(convertPt(255.00,548.00));
      corners.push_back(convertPt(242.00,548.00));
      corners.push_back(convertPt(242.00,555.00));
      corners.push_back(convertPt(229.00,555.00));
      corners.push_back(convertPt(229.00,563.00));
      corners.push_back(convertPt(217.00,563.00));
      corners.push_back(convertPt(217.00,571.00));
      corners.push_back(convertPt(191.00,571.00));
      corners.push_back(convertPt(191.00,578.00));
      corners.push_back(convertPt(179.00,578.00));
      corners.push_back(convertPt(179.00,496.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(191.00,489.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(204.00,482.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(217.00,475.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(230.00,467.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(243.00,460.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(255.00,452.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(268.00,445.00));
      corners.push_back(convertPt(293.00,445.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(306.00,437.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(319.00,430.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(333.00,422.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(345.00,415.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(358.00,407.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(371.00,400.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(384.00,393.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(397.00,386.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(409.00,379.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(422.00,371.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(435.00,363.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(448.00,356.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(461.00,349.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(473.00,341.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(486.00,334.00));
      corners.push_back(convertPt(486.00,326.00));
      corners.push_back(convertPt(500.00,326.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(512.00,319.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(525.00,311.00));
      corners.push_back(convertPt(525.00,304.00));
      corners.push_back(convertPt(538.00,304.00));
      corners.push_back(convertPt(538.00,297.00));
      corners.push_back(convertPt(551.00,297.00));
      corners.push_back(convertPt(551.00,289.00));
      corners.push_back(convertPt(564.00,289.00));
      corners.push_back(convertPt(564.00,282.00));
      corners.push_back(convertPt(577.00,282.00));
      corners.push_back(convertPt(577.00,275.00));
      corners.push_back(convertPt(589.00,275.00));
      corners.push_back(convertPt(589.00,267.00));
      corners.push_back(convertPt(602.00,267.00));
      corners.push_back(convertPt(602.00,259.00));
      corners.push_back(convertPt(615.00,259.00));
      corners.push_back(convertPt(615.00,252.00));
      corners.push_back(convertPt(628.00,252.00));
      corners.push_back(convertPt(628.00,245.00));
      corners.push_back(convertPt(641.00,245.00));
      corners.push_back(convertPt(641.00,237.00));
      corners.push_back(convertPt(654.00,237.00));
      corners.push_back(convertPt(654.00,230.00));
      corners.push_back(convertPt(667.00,230.00));
      corners.push_back(convertPt(667.00,223.00));
      corners.push_back(convertPt(679.00,223.00));
      corners.push_back(convertPt(679.00,215.00));
      corners.push_back(convertPt(692.00,215.00));
      corners.push_back(convertPt(692.00,207.00));
      corners.push_back(convertPt(705.00,207.00));
      corners.push_back(convertPt(705.00,200.00));
      corners.push_back(convertPt(731.00,200.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(744.00,193.00));
      corners.push_back(convertPt(744.00,186.00));
      corners.push_back(convertPt(756.00,186.00));
      corners.push_back(convertPt(756.00,178.00));
      corners.push_back(convertPt(769.00,178.00));
      corners.push_back(convertPt(769.00,171.00));
      corners.push_back(convertPt(782.00,171.00));
      corners.push_back(convertPt(782.00,163.00));
      corners.push_back(convertPt(795.00,163.00));
      corners.push_back(convertPt(795.00,156.00));
      corners.push_back(convertPt(820.00,156.00));
      corners.push_back(convertPt(820.00,149.00));
      corners.push_back(convertPt(846.00,149.00));
      corners.push_back(convertPt(846.00,141.00));
      corners.push_back(convertPt(860.00,141.00));
      corners.push_back(convertPt(860.00,134.00));
      corners.push_back(convertPt(885.00,134.00));
      corners.push_back(convertPt(885.00,127.00));
      corners.push_back(convertPt(898.00,127.00));
      corners.push_back(convertPt(898.00,120.00));
      corners.push_back(convertPt(911.00,120.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(679.00,445.00));
      corners.push_back(convertPt(679.00,452.00));
      corners.push_back(convertPt(667.00,452.00));
      corners.push_back(convertPt(667.00,445.00));
      corners.push_back(convertPt(679.00,445.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(409.00,526.00));
      corners.push_back(convertPt(409.00,533.00));
      corners.push_back(convertPt(397.00,533.00));
      corners.push_back(convertPt(397.00,526.00));
      corners.push_back(convertPt(409.00,526.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(461.00,526.00));
      corners.push_back(convertPt(461.00,533.00));
      corners.push_back(convertPt(448.00,533.00));
      corners.push_back(convertPt(448.00,526.00));
      corners.push_back(convertPt(461.00,526.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(422.00,608.00));
      corners.push_back(convertPt(422.00,615.00));
      corners.push_back(convertPt(410.00,615.00));
      corners.push_back(convertPt(410.00,623.00));
      corners.push_back(convertPt(397.00,623.00));
      corners.push_back(convertPt(397.00,630.00));
      corners.push_back(convertPt(384.00,630.00));
      corners.push_back(convertPt(384.00,623.00));
      corners.push_back(convertPt(397.00,623.00));
      corners.push_back(convertPt(397.00,615.00));
      corners.push_back(convertPt(410.00,615.00));
      corners.push_back(convertPt(410.00,608.00));
      corners.push_back(convertPt(422.00,608.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(473.00,608.00));
      corners.push_back(convertPt(473.00,615.00));
      corners.push_back(convertPt(461.00,615.00));
      corners.push_back(convertPt(461.00,623.00));
      corners.push_back(convertPt(448.00,623.00));
      corners.push_back(convertPt(448.00,630.00));
      corners.push_back(convertPt(435.00,630.00));
      corners.push_back(convertPt(435.00,623.00));
      corners.push_back(convertPt(448.00,623.00));
      corners.push_back(convertPt(448.00,615.00));
      corners.push_back(convertPt(461.00,615.00));
      corners.push_back(convertPt(461.00,608.00));
      corners.push_back(convertPt(473.00,608.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(306.00,615.00));
      corners.push_back(convertPt(306.00,623.00));
      corners.push_back(convertPt(293.00,623.00));
      corners.push_back(convertPt(293.00,615.00));
      corners.push_back(convertPt(306.00,615.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(525.00,666.00));
      corners.push_back(convertPt(525.00,675.00));
      corners.push_back(convertPt(512.00,675.00));
      corners.push_back(convertPt(512.00,682.00));
      corners.push_back(convertPt(500.00,682.00));
      corners.push_back(convertPt(500.00,689.00));
      corners.push_back(convertPt(486.00,689.00));
      corners.push_back(convertPt(486.00,682.00));
      corners.push_back(convertPt(500.00,682.00));
      corners.push_back(convertPt(500.00,675.00));
      corners.push_back(convertPt(512.00,675.00));
      corners.push_back(convertPt(512.00,666.00));
      corners.push_back(convertPt(525.00,666.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(217.00,675.00));
      corners.push_back(convertPt(217.00,682.00));
      corners.push_back(convertPt(204.00,682.00));
      corners.push_back(convertPt(204.00,689.00));
      corners.push_back(convertPt(191.00,689.00));
      corners.push_back(convertPt(191.00,682.00));
      corners.push_back(convertPt(204.00,682.00));
      corners.push_back(convertPt(204.00,675.00));
      corners.push_back(convertPt(217.00,675.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(371.00,696.00));
      corners.push_back(convertPt(371.00,711.00));
      corners.push_back(convertPt(358.00,711.00));
      corners.push_back(convertPt(358.00,719.00));
      corners.push_back(convertPt(333.00,719.00));
      corners.push_back(convertPt(333.00,704.00));
      corners.push_back(convertPt(345.00,704.00));
      corners.push_back(convertPt(345.00,696.00));
      corners.push_back(convertPt(371.00,696.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(525.00,696.00));
      corners.push_back(convertPt(525.00,704.00));
      corners.push_back(convertPt(512.00,704.00));
      corners.push_back(convertPt(512.00,711.00));
      corners.push_back(convertPt(500.00,711.00));
      corners.push_back(convertPt(500.00,718.00));
      corners.push_back(convertPt(486.00,718.00));
      corners.push_back(convertPt(486.00,711.00));
      corners.push_back(convertPt(500.00,711.00));
      corners.push_back(convertPt(500.00,704.00));
      corners.push_back(convertPt(512.00,704.00));
      corners.push_back(convertPt(512.00,696.00));
      corners.push_back(convertPt(525.00,696.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(422.00,726.00));
      corners.push_back(convertPt(422.00,741.00));
      corners.push_back(convertPt(409.00,741.00));
      corners.push_back(convertPt(409.00,748.00));
      corners.push_back(convertPt(384.00,748.00));
      corners.push_back(convertPt(384.00,734.00));
      corners.push_back(convertPt(396.00,734.00));
      corners.push_back(convertPt(396.00,726.00));
      corners.push_back(convertPt(422.00,726.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(525.00,726.00));
      corners.push_back(convertPt(525.00,734.00));
      corners.push_back(convertPt(512.00,734.00));
      corners.push_back(convertPt(512.00,741.00));
      corners.push_back(convertPt(500.00,741.00));
      corners.push_back(convertPt(500.00,748.00));
      corners.push_back(convertPt(486.00,748.00));
      corners.push_back(convertPt(486.00,741.00));
      corners.push_back(convertPt(500.00,741.00));
      corners.push_back(convertPt(500.00,734.00));
      corners.push_back(convertPt(512.00,734.00));
      corners.push_back(convertPt(512.00,726.00));
      corners.push_back(convertPt(525.00,726.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(3, contoursPointer));

      ///// 0.10pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(911.00,120.00));
      corners.push_back(convertPt(911.00,259.00));
      corners.push_back(convertPt(898.00,259.00));
      corners.push_back(convertPt(898.00,275.00));
      corners.push_back(convertPt(885.00,275.00));
      corners.push_back(convertPt(885.00,282.00));
      corners.push_back(convertPt(873.00,282.00));
      corners.push_back(convertPt(873.00,289.00));
      corners.push_back(convertPt(860.00,289.00));
      corners.push_back(convertPt(860.00,297.00));
      corners.push_back(convertPt(873.00,297.00));
      corners.push_back(convertPt(873.00,311.00));
      corners.push_back(convertPt(860.00,311.00));
      corners.push_back(convertPt(860.00,319.00));
      corners.push_back(convertPt(846.00,319.00));
      corners.push_back(convertPt(846.00,356.00));
      corners.push_back(convertPt(795.00,356.00));
      corners.push_back(convertPt(795.00,363.00));
      corners.push_back(convertPt(808.00,363.00));
      corners.push_back(convertPt(808.00,371.00));
      corners.push_back(convertPt(820.00,371.00));
      corners.push_back(convertPt(820.00,386.00));
      corners.push_back(convertPt(808.00,386.00));
      corners.push_back(convertPt(808.00,393.00));
      corners.push_back(convertPt(820.00,393.00));
      corners.push_back(convertPt(820.00,400.00));
      corners.push_back(convertPt(846.00,400.00));
      corners.push_back(convertPt(846.00,407.00));
      corners.push_back(convertPt(820.00,407.00));
      corners.push_back(convertPt(820.00,400.00));
      corners.push_back(convertPt(808.00,400.00));
      corners.push_back(convertPt(808.00,407.00));
      corners.push_back(convertPt(795.00,407.00));
      corners.push_back(convertPt(795.00,415.00));
      corners.push_back(convertPt(769.00,415.00));
      corners.push_back(convertPt(769.00,423.00));
      corners.push_back(convertPt(757.00,423.00));
      corners.push_back(convertPt(757.00,430.00));
      corners.push_back(convertPt(718.00,430.00));
      corners.push_back(convertPt(718.00,437.00));
      corners.push_back(convertPt(628.00,437.00));
      corners.push_back(convertPt(628.00,452.00));
      corners.push_back(convertPt(615.00,452.00));
      corners.push_back(convertPt(615.00,459.00));
      corners.push_back(convertPt(602.00,459.00));
      corners.push_back(convertPt(602.00,466.00));
      corners.push_back(convertPt(576.00,466.00));
      corners.push_back(convertPt(576.00,474.00));
      corners.push_back(convertPt(551.00,474.00));
      corners.push_back(convertPt(551.00,482.00));
      corners.push_back(convertPt(526.00,482.00));
      corners.push_back(convertPt(526.00,489.00));
      corners.push_back(convertPt(512.00,489.00));
      corners.push_back(convertPt(512.00,496.00));
      corners.push_back(convertPt(486.00,496.00));
      corners.push_back(convertPt(486.00,503.00));
      corners.push_back(convertPt(473.00,503.00));
      corners.push_back(convertPt(473.00,511.00));
      corners.push_back(convertPt(409.00,511.00));
      corners.push_back(convertPt(409.00,519.00));
      corners.push_back(convertPt(422.00,519.00));
      corners.push_back(convertPt(422.00,533.00));
      corners.push_back(convertPt(435.00,533.00));
      corners.push_back(convertPt(435.00,519.00));
      corners.push_back(convertPt(473.00,519.00));
      corners.push_back(convertPt(473.00,533.00));
      corners.push_back(convertPt(461.00,533.00));
      corners.push_back(convertPt(461.00,541.00));
      corners.push_back(convertPt(435.00,541.00));
      corners.push_back(convertPt(435.00,555.00));
      corners.push_back(convertPt(422.00,555.00));
      corners.push_back(convertPt(422.00,541.00));
      corners.push_back(convertPt(384.00,541.00));
      corners.push_back(convertPt(384.00,526.00));
      corners.push_back(convertPt(371.00,526.00));
      corners.push_back(convertPt(371.00,533.00));
      corners.push_back(convertPt(358.00,533.00));
      corners.push_back(convertPt(358.00,541.00));
      corners.push_back(convertPt(319.00,541.00));
      corners.push_back(convertPt(319.00,548.00));
      corners.push_back(convertPt(306.00,548.00));
      corners.push_back(convertPt(306.00,555.00));
      corners.push_back(convertPt(280.00,555.00));
      corners.push_back(convertPt(280.00,562.00));
      corners.push_back(convertPt(268.00,562.00));
      corners.push_back(convertPt(268.00,571.00));
      corners.push_back(convertPt(255.00,571.00));
      corners.push_back(convertPt(255.00,578.00));
      corners.push_back(convertPt(216.00,578.00));
      corners.push_back(convertPt(216.00,585.00));
      corners.push_back(convertPt(204.00,585.00));
      corners.push_back(convertPt(204.00,593.00));
      corners.push_back(convertPt(179.00,593.00));
      corners.push_back(convertPt(179.00,496.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(191.00,489.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(204.00,482.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(217.00,475.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(230.00,467.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(243.00,460.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(255.00,452.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(268.00,445.00));
      corners.push_back(convertPt(281.00,445.00));
      corners.push_back(convertPt(281.00,437.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(293.00,430.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(306.00,422.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(319.00,415.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(333.00,407.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(345.00,400.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(358.00,393.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(371.00,386.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(384.00,379.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(397.00,371.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(409.00,363.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(422.00,356.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(435.00,349.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(448.00,341.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(461.00,334.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(473.00,326.00));
      corners.push_back(convertPt(500.00,326.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(512.00,319.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(525.00,311.00));
      corners.push_back(convertPt(525.00,304.00));
      corners.push_back(convertPt(538.00,304.00));
      corners.push_back(convertPt(538.00,297.00));
      corners.push_back(convertPt(551.00,297.00));
      corners.push_back(convertPt(551.00,289.00));
      corners.push_back(convertPt(564.00,289.00));
      corners.push_back(convertPt(564.00,282.00));
      corners.push_back(convertPt(577.00,282.00));
      corners.push_back(convertPt(577.00,275.00));
      corners.push_back(convertPt(589.00,275.00));
      corners.push_back(convertPt(589.00,267.00));
      corners.push_back(convertPt(602.00,267.00));
      corners.push_back(convertPt(602.00,259.00));
      corners.push_back(convertPt(615.00,259.00));
      corners.push_back(convertPt(615.00,252.00));
      corners.push_back(convertPt(628.00,252.00));
      corners.push_back(convertPt(628.00,245.00));
      corners.push_back(convertPt(641.00,245.00));
      corners.push_back(convertPt(641.00,237.00));
      corners.push_back(convertPt(654.00,237.00));
      corners.push_back(convertPt(654.00,230.00));
      corners.push_back(convertPt(667.00,230.00));
      corners.push_back(convertPt(667.00,223.00));
      corners.push_back(convertPt(679.00,223.00));
      corners.push_back(convertPt(679.00,215.00));
      corners.push_back(convertPt(692.00,215.00));
      corners.push_back(convertPt(692.00,207.00));
      corners.push_back(convertPt(705.00,207.00));
      corners.push_back(convertPt(705.00,200.00));
      corners.push_back(convertPt(718.00,200.00));
      corners.push_back(convertPt(718.00,193.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(731.00,186.00));
      corners.push_back(convertPt(744.00,186.00));
      corners.push_back(convertPt(744.00,178.00));
      corners.push_back(convertPt(756.00,178.00));
      corners.push_back(convertPt(756.00,171.00));
      corners.push_back(convertPt(782.00,171.00));
      corners.push_back(convertPt(782.00,163.00));
      corners.push_back(convertPt(795.00,163.00));
      corners.push_back(convertPt(795.00,156.00));
      corners.push_back(convertPt(808.00,156.00));
      corners.push_back(convertPt(808.00,149.00));
      corners.push_back(convertPt(820.00,149.00));
      corners.push_back(convertPt(820.00,141.00));
      corners.push_back(convertPt(860.00,141.00));
      corners.push_back(convertPt(860.00,134.00));
      corners.push_back(convertPt(885.00,134.00));
      corners.push_back(convertPt(885.00,127.00));
      corners.push_back(convertPt(898.00,127.00));
      corners.push_back(convertPt(898.00,120.00));
      corners.push_back(convertPt(911.00,120.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(795.00,378.00));
      corners.push_back(convertPt(795.00,386.00));
      corners.push_back(convertPt(808.00,386.00));
      corners.push_back(convertPt(808.00,378.00));
      corners.push_back(convertPt(795.00,378.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(884.00,415.00));
      corners.push_back(convertPt(884.00,423.00));
      corners.push_back(convertPt(873.00,423.00));
      corners.push_back(convertPt(873.00,415.00));
      corners.push_back(convertPt(884.00,415.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(898.00,430.00));
      corners.push_back(convertPt(898.00,437.00));
      corners.push_back(convertPt(885.00,437.00));
      corners.push_back(convertPt(885.00,430.00));
      corners.push_back(convertPt(898.00,430.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(679.00,445.00));
      corners.push_back(convertPt(679.00,452.00));
      corners.push_back(convertPt(667.00,452.00));
      corners.push_back(convertPt(667.00,445.00));
      corners.push_back(convertPt(679.00,445.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,459.00));
      corners.push_back(convertPt(782.00,467.00));
      corners.push_back(convertPt(769.00,467.00));
      corners.push_back(convertPt(769.00,459.00));
      corners.push_back(convertPt(782.00,459.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(757.00,475.00));
      corners.push_back(convertPt(757.00,482.00));
      corners.push_back(convertPt(744.00,482.00));
      corners.push_back(convertPt(744.00,475.00));
      corners.push_back(convertPt(757.00,475.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(653.00,489.00));
      corners.push_back(convertPt(653.00,496.00));
      corners.push_back(convertPt(641.00,496.00));
      corners.push_back(convertPt(641.00,489.00));
      corners.push_back(convertPt(653.00,489.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,518.00));
      corners.push_back(convertPt(782.00,526.00));
      corners.push_back(convertPt(769.00,526.00));
      corners.push_back(convertPt(769.00,518.00));
      corners.push_back(convertPt(782.00,518.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(525.00,519.00));
      corners.push_back(convertPt(525.00,533.00));
      corners.push_back(convertPt(512.00,533.00));
      corners.push_back(convertPt(512.00,541.00));
      corners.push_back(convertPt(486.00,541.00));
      corners.push_back(convertPt(486.00,526.00));
      corners.push_back(convertPt(500.00,526.00));
      corners.push_back(convertPt(500.00,519.00));
      corners.push_back(convertPt(525.00,519.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(757.00,533.00));
      corners.push_back(convertPt(757.00,541.00));
      corners.push_back(convertPt(744.00,541.00));
      corners.push_back(convertPt(744.00,533.00));
      corners.push_back(convertPt(757.00,533.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(731.00,548.00));
      corners.push_back(convertPt(731.00,555.00));
      corners.push_back(convertPt(718.00,555.00));
      corners.push_back(convertPt(718.00,548.00));
      corners.push_back(convertPt(731.00,548.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(679.00,563.00));
      corners.push_back(convertPt(679.00,570.00));
      corners.push_back(convertPt(667.00,570.00));
      corners.push_back(convertPt(667.00,563.00));
      corners.push_back(convertPt(679.00,563.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(319.00,578.00));
      corners.push_back(convertPt(319.00,585.00));
      corners.push_back(convertPt(306.00,585.00));
      corners.push_back(convertPt(306.00,600.00));
      corners.push_back(convertPt(281.00,600.00));
      corners.push_back(convertPt(281.00,585.00));
      corners.push_back(convertPt(294.00,585.00));
      corners.push_back(convertPt(294.00,578.00));
      corners.push_back(convertPt(319.00,578.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(679.00,578.00));
      corners.push_back(convertPt(679.00,585.00));
      corners.push_back(convertPt(667.00,585.00));
      corners.push_back(convertPt(667.00,578.00));
      corners.push_back(convertPt(679.00,578.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,578.00));
      corners.push_back(convertPt(782.00,585.00));
      corners.push_back(convertPt(769.00,585.00));
      corners.push_back(convertPt(769.00,578.00));
      corners.push_back(convertPt(782.00,578.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(486.00,585.00));
      corners.push_back(convertPt(486.00,593.00));
      corners.push_back(convertPt(500.00,593.00));
      corners.push_back(convertPt(500.00,600.00));
      corners.push_back(convertPt(512.00,600.00));
      corners.push_back(convertPt(512.00,614.00));
      corners.push_back(convertPt(486.00,614.00));
      corners.push_back(convertPt(486.00,622.00));
      corners.push_back(convertPt(473.00,622.00));
      corners.push_back(convertPt(473.00,630.00));
      corners.push_back(convertPt(461.00,630.00));
      corners.push_back(convertPt(461.00,637.00));
      corners.push_back(convertPt(473.00,637.00));
      corners.push_back(convertPt(473.00,645.00));
      corners.push_back(convertPt(500.00,645.00));
      corners.push_back(convertPt(500.00,652.00));
      corners.push_back(convertPt(525.00,652.00));
      corners.push_back(convertPt(525.00,659.00));
      corners.push_back(convertPt(538.00,659.00));
      corners.push_back(convertPt(538.00,667.00));
      corners.push_back(convertPt(551.00,667.00));
      corners.push_back(convertPt(551.00,675.00));
      corners.push_back(convertPt(563.00,675.00));
      corners.push_back(convertPt(563.00,682.00));
      corners.push_back(convertPt(576.00,682.00));
      corners.push_back(convertPt(576.00,696.00));
      corners.push_back(convertPt(589.00,696.00));
      corners.push_back(convertPt(589.00,755.00));
      corners.push_back(convertPt(602.00,755.00));
      corners.push_back(convertPt(602.00,763.00));
      corners.push_back(convertPt(615.00,763.00));
      corners.push_back(convertPt(615.00,771.00));
      corners.push_back(convertPt(640.00,771.00));
      corners.push_back(convertPt(640.00,778.00));
      corners.push_back(convertPt(653.00,778.00));
      corners.push_back(convertPt(653.00,800.00));
      corners.push_back(convertPt(641.00,800.00));
      corners.push_back(convertPt(641.00,806.00));
      corners.push_back(convertPt(512.00,806.00));
      corners.push_back(convertPt(512.00,800.00));
      corners.push_back(convertPt(500.00,800.00));
      corners.push_back(convertPt(500.00,806.00));
      corners.push_back(convertPt(179.00,806.00));
      corners.push_back(convertPt(179.00,652.00));
      corners.push_back(convertPt(191.00,652.00));
      corners.push_back(convertPt(191.00,645.00));
      corners.push_back(convertPt(204.00,645.00));
      corners.push_back(convertPt(204.00,637.00));
      corners.push_back(convertPt(242.00,637.00));
      corners.push_back(convertPt(242.00,645.00));
      corners.push_back(convertPt(345.00,645.00));
      corners.push_back(convertPt(345.00,637.00));
      corners.push_back(convertPt(358.00,637.00));
      corners.push_back(convertPt(358.00,600.00));
      corners.push_back(convertPt(397.00,600.00));
      corners.push_back(convertPt(397.00,593.00));
      corners.push_back(convertPt(473.00,593.00));
      corners.push_back(convertPt(473.00,585.00));
      corners.push_back(convertPt(486.00,585.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(731.00,593.00));
      corners.push_back(convertPt(731.00,600.00));
      corners.push_back(convertPt(718.00,600.00));
      corners.push_back(convertPt(718.00,593.00));
      corners.push_back(convertPt(731.00,593.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(319.00,607.00));
      corners.push_back(convertPt(319.00,630.00));
      corners.push_back(convertPt(281.00,630.00));
      corners.push_back(convertPt(281.00,615.00));
      corners.push_back(convertPt(293.00,615.00));
      corners.push_back(convertPt(293.00,607.00));
      corners.push_back(convertPt(319.00,607.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(705.00,607.00));
      corners.push_back(convertPt(705.00,614.00));
      corners.push_back(convertPt(693.00,614.00));
      corners.push_back(convertPt(693.00,607.00));
      corners.push_back(convertPt(705.00,607.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(756.00,607.00));
      corners.push_back(convertPt(756.00,614.00));
      corners.push_back(convertPt(744.00,614.00));
      corners.push_back(convertPt(744.00,607.00));
      corners.push_back(convertPt(756.00,607.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(679.00,637.00));
      corners.push_back(convertPt(679.00,645.00));
      corners.push_back(convertPt(667.00,645.00));
      corners.push_back(convertPt(667.00,637.00));
      corners.push_back(convertPt(679.00,637.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(705.00,637.00));
      corners.push_back(convertPt(705.00,645.00));
      corners.push_back(convertPt(693.00,645.00));
      corners.push_back(convertPt(693.00,637.00));
      corners.push_back(convertPt(705.00,637.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,637.00));
      corners.push_back(convertPt(782.00,645.00));
      corners.push_back(convertPt(769.00,645.00));
      corners.push_back(convertPt(769.00,637.00));
      corners.push_back(convertPt(782.00,637.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(731.00,652.00));
      corners.push_back(convertPt(731.00,659.00));
      corners.push_back(convertPt(718.00,659.00));
      corners.push_back(convertPt(718.00,652.00));
      corners.push_back(convertPt(731.00,652.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,652.00));
      corners.push_back(convertPt(782.00,659.00));
      corners.push_back(convertPt(769.00,659.00));
      corners.push_back(convertPt(769.00,652.00));
      corners.push_back(convertPt(782.00,652.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(731.00,667.00));
      corners.push_back(convertPt(731.00,674.00));
      corners.push_back(convertPt(718.00,674.00));
      corners.push_back(convertPt(718.00,667.00));
      corners.push_back(convertPt(731.00,667.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(705.00,682.00));
      corners.push_back(convertPt(705.00,689.00));
      corners.push_back(convertPt(693.00,689.00));
      corners.push_back(convertPt(693.00,682.00));
      corners.push_back(convertPt(705.00,682.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(731.00,696.00));
      corners.push_back(convertPt(731.00,704.00));
      corners.push_back(convertPt(718.00,704.00));
      corners.push_back(convertPt(718.00,696.00));
      corners.push_back(convertPt(731.00,696.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,696.00));
      corners.push_back(convertPt(782.00,704.00));
      corners.push_back(convertPt(769.00,704.00));
      corners.push_back(convertPt(769.00,696.00));
      corners.push_back(convertPt(782.00,696.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(705.00,726.00));
      corners.push_back(convertPt(705.00,734.00));
      corners.push_back(convertPt(693.00,734.00));
      corners.push_back(convertPt(693.00,726.00));
      corners.push_back(convertPt(705.00,726.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(756.00,726.00));
      corners.push_back(convertPt(756.00,734.00));
      corners.push_back(convertPt(744.00,734.00));
      corners.push_back(convertPt(744.00,726.00));
      corners.push_back(convertPt(756.00,726.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(757.00,755.00));
      corners.push_back(convertPt(757.00,763.00));
      corners.push_back(convertPt(743.00,763.00));
      corners.push_back(convertPt(743.00,755.00));
      corners.push_back(convertPt(757.00,755.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(4, contoursPointer));

      ///// 0.12pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(911.00,120.00));
      corners.push_back(convertPt(911.00,134.00));
      corners.push_back(convertPt(923.00,134.00));
      corners.push_back(convertPt(923.00,170.00));
      corners.push_back(convertPt(911.00,170.00));
      corners.push_back(convertPt(911.00,275.00));
      corners.push_back(convertPt(898.00,275.00));
      corners.push_back(convertPt(898.00,282.00));
      corners.push_back(convertPt(885.00,282.00));
      corners.push_back(convertPt(885.00,319.00));
      corners.push_back(convertPt(873.00,319.00));
      corners.push_back(convertPt(873.00,341.00));
      corners.push_back(convertPt(860.00,341.00));
      corners.push_back(convertPt(860.00,349.00));
      corners.push_back(convertPt(873.00,349.00));
      corners.push_back(convertPt(873.00,363.00));
      corners.push_back(convertPt(860.00,363.00));
      corners.push_back(convertPt(860.00,356.00));
      corners.push_back(convertPt(846.00,356.00));
      corners.push_back(convertPt(846.00,371.00));
      corners.push_back(convertPt(860.00,371.00));
      corners.push_back(convertPt(860.00,400.00));
      corners.push_back(convertPt(873.00,400.00));
      corners.push_back(convertPt(873.00,407.00));
      corners.push_back(convertPt(884.00,407.00));
      corners.push_back(convertPt(884.00,386.00));
      corners.push_back(convertPt(898.00,386.00));
      corners.push_back(convertPt(898.00,466.00));
      corners.push_back(convertPt(911.00,466.00));
      corners.push_back(convertPt(911.00,475.00));
      corners.push_back(convertPt(898.00,475.00));
      corners.push_back(convertPt(898.00,482.00));
      corners.push_back(convertPt(884.00,482.00));
      corners.push_back(convertPt(884.00,475.00));
      corners.push_back(convertPt(872.00,475.00));
      corners.push_back(convertPt(872.00,459.00));
      corners.push_back(convertPt(860.00,459.00));
      corners.push_back(convertPt(860.00,445.00));
      corners.push_back(convertPt(846.00,445.00));
      corners.push_back(convertPt(846.00,437.00));
      corners.push_back(convertPt(821.00,437.00));
      corners.push_back(convertPt(821.00,445.00));
      corners.push_back(convertPt(808.00,445.00));
      corners.push_back(convertPt(808.00,430.00));
      corners.push_back(convertPt(782.00,430.00));
      corners.push_back(convertPt(782.00,437.00));
      corners.push_back(convertPt(769.00,437.00));
      corners.push_back(convertPt(769.00,445.00));
      corners.push_back(convertPt(782.00,445.00));
      corners.push_back(convertPt(782.00,452.00));
      corners.push_back(convertPt(795.00,452.00));
      corners.push_back(convertPt(795.00,459.00));
      corners.push_back(convertPt(808.00,459.00));
      corners.push_back(convertPt(808.00,467.00));
      corners.push_back(convertPt(795.00,467.00));
      corners.push_back(convertPt(795.00,475.00));
      corners.push_back(convertPt(782.00,475.00));
      corners.push_back(convertPt(782.00,467.00));
      corners.push_back(convertPt(744.00,467.00));
      corners.push_back(convertPt(744.00,459.00));
      corners.push_back(convertPt(718.00,459.00));
      corners.push_back(convertPt(718.00,467.00));
      corners.push_back(convertPt(667.00,467.00));
      corners.push_back(convertPt(667.00,482.00));
      corners.push_back(convertPt(653.00,482.00));
      corners.push_back(convertPt(653.00,475.00));
      corners.push_back(convertPt(628.00,475.00));
      corners.push_back(convertPt(628.00,482.00));
      corners.push_back(convertPt(615.00,482.00));
      corners.push_back(convertPt(615.00,496.00));
      corners.push_back(convertPt(641.00,496.00));
      corners.push_back(convertPt(641.00,489.00));
      corners.push_back(convertPt(653.00,489.00));
      corners.push_back(convertPt(653.00,496.00));
      corners.push_back(convertPt(641.00,496.00));
      corners.push_back(convertPt(641.00,503.00));
      corners.push_back(convertPt(653.00,503.00));
      corners.push_back(convertPt(653.00,511.00));
      corners.push_back(convertPt(667.00,511.00));
      corners.push_back(convertPt(667.00,526.00));
      corners.push_back(convertPt(679.00,526.00));
      corners.push_back(convertPt(679.00,533.00));
      corners.push_back(convertPt(667.00,533.00));
      corners.push_back(convertPt(667.00,541.00));
      corners.push_back(convertPt(641.00,541.00));
      corners.push_back(convertPt(641.00,555.00));
      corners.push_back(convertPt(653.00,555.00));
      corners.push_back(convertPt(653.00,563.00));
      corners.push_back(convertPt(641.00,563.00));
      corners.push_back(convertPt(641.00,571.00));
      corners.push_back(convertPt(628.00,571.00));
      corners.push_back(convertPt(628.00,578.00));
      corners.push_back(convertPt(641.00,578.00));
      corners.push_back(convertPt(641.00,585.00));
      corners.push_back(convertPt(667.00,585.00));
      corners.push_back(convertPt(667.00,578.00));
      corners.push_back(convertPt(679.00,578.00));
      corners.push_back(convertPt(679.00,570.00));
      corners.push_back(convertPt(667.00,570.00));
      corners.push_back(convertPt(667.00,563.00));
      corners.push_back(convertPt(679.00,563.00));
      corners.push_back(convertPt(679.00,570.00));
      corners.push_back(convertPt(693.00,570.00));
      corners.push_back(convertPt(693.00,578.00));
      corners.push_back(convertPt(679.00,578.00));
      corners.push_back(convertPt(679.00,585.00));
      corners.push_back(convertPt(667.00,585.00));
      corners.push_back(convertPt(667.00,600.00));
      corners.push_back(convertPt(653.00,600.00));
      corners.push_back(convertPt(653.00,607.00));
      corners.push_back(convertPt(667.00,607.00));
      corners.push_back(convertPt(667.00,622.00));
      corners.push_back(convertPt(679.00,622.00));
      corners.push_back(convertPt(679.00,637.00));
      corners.push_back(convertPt(705.00,637.00));
      corners.push_back(convertPt(705.00,652.00));
      corners.push_back(convertPt(718.00,652.00));
      corners.push_back(convertPt(718.00,630.00));
      corners.push_back(convertPt(705.00,630.00));
      corners.push_back(convertPt(705.00,614.00));
      corners.push_back(convertPt(693.00,614.00));
      corners.push_back(convertPt(693.00,607.00));
      corners.push_back(convertPt(705.00,607.00));
      corners.push_back(convertPt(705.00,614.00));
      corners.push_back(convertPt(744.00,614.00));
      corners.push_back(convertPt(744.00,607.00));
      corners.push_back(convertPt(756.00,607.00));
      corners.push_back(convertPt(756.00,614.00));
      corners.push_back(convertPt(744.00,614.00));
      corners.push_back(convertPt(744.00,637.00));
      corners.push_back(convertPt(757.00,637.00));
      corners.push_back(convertPt(757.00,645.00));
      corners.push_back(convertPt(769.00,645.00));
      corners.push_back(convertPt(769.00,637.00));
      corners.push_back(convertPt(782.00,637.00));
      corners.push_back(convertPt(782.00,622.00));
      corners.push_back(convertPt(795.00,622.00));
      corners.push_back(convertPt(795.00,607.00));
      corners.push_back(convertPt(782.00,607.00));
      corners.push_back(convertPt(782.00,600.00));
      corners.push_back(convertPt(756.00,600.00));
      corners.push_back(convertPt(756.00,593.00));
      corners.push_back(convertPt(731.00,593.00));
      corners.push_back(convertPt(731.00,600.00));
      corners.push_back(convertPt(718.00,600.00));
      corners.push_back(convertPt(718.00,593.00));
      corners.push_back(convertPt(731.00,593.00));
      corners.push_back(convertPt(731.00,578.00));
      corners.push_back(convertPt(744.00,578.00));
      corners.push_back(convertPt(744.00,571.00));
      corners.push_back(convertPt(731.00,571.00));
      corners.push_back(convertPt(731.00,555.00));
      corners.push_back(convertPt(718.00,555.00));
      corners.push_back(convertPt(718.00,548.00));
      corners.push_back(convertPt(731.00,548.00));
      corners.push_back(convertPt(731.00,555.00));
      corners.push_back(convertPt(744.00,555.00));
      corners.push_back(convertPt(744.00,548.00));
      corners.push_back(convertPt(757.00,548.00));
      corners.push_back(convertPt(757.00,541.00));
      corners.push_back(convertPt(744.00,541.00));
      corners.push_back(convertPt(744.00,533.00));
      corners.push_back(convertPt(757.00,533.00));
      corners.push_back(convertPt(757.00,541.00));
      corners.push_back(convertPt(769.00,541.00));
      corners.push_back(convertPt(769.00,563.00));
      corners.push_back(convertPt(782.00,563.00));
      corners.push_back(convertPt(782.00,578.00));
      corners.push_back(convertPt(795.00,578.00));
      corners.push_back(convertPt(795.00,593.00));
      corners.push_back(convertPt(808.00,593.00));
      corners.push_back(convertPt(808.00,614.00));
      corners.push_back(convertPt(834.00,614.00));
      corners.push_back(convertPt(834.00,667.00));
      corners.push_back(convertPt(821.00,667.00));
      corners.push_back(convertPt(821.00,689.00));
      corners.push_back(convertPt(808.00,689.00));
      corners.push_back(convertPt(808.00,659.00));
      corners.push_back(convertPt(795.00,659.00));
      corners.push_back(convertPt(795.00,696.00));
      corners.push_back(convertPt(782.00,696.00));
      corners.push_back(convertPt(782.00,704.00));
      corners.push_back(convertPt(769.00,704.00));
      corners.push_back(convertPt(769.00,718.00));
      corners.push_back(convertPt(782.00,718.00));
      corners.push_back(convertPt(782.00,734.00));
      corners.push_back(convertPt(769.00,734.00));
      corners.push_back(convertPt(769.00,741.00));
      corners.push_back(convertPt(782.00,741.00));
      corners.push_back(convertPt(782.00,755.00));
      corners.push_back(convertPt(769.00,755.00));
      corners.push_back(convertPt(769.00,763.00));
      corners.push_back(convertPt(757.00,763.00));
      corners.push_back(convertPt(757.00,800.00));
      corners.push_back(convertPt(744.00,800.00));
      corners.push_back(convertPt(744.00,806.00));
      corners.push_back(convertPt(179.00,806.00));
      corners.push_back(convertPt(179.00,553.00));
      corners.push_back(convertPt(179.00,496.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(191.00,489.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(204.00,482.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(217.00,475.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(230.00,467.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(243.00,460.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(255.00,452.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(268.00,445.00));
      corners.push_back(convertPt(281.00,445.00));
      corners.push_back(convertPt(281.00,437.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(293.00,430.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(306.00,422.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(319.00,415.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(333.00,407.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(345.00,400.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(358.00,393.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(371.00,386.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(384.00,379.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(397.00,371.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(409.00,363.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(422.00,356.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(435.00,349.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(448.00,341.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(461.00,334.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(473.00,326.00));
      corners.push_back(convertPt(486.00,326.00));
      corners.push_back(convertPt(486.00,319.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(500.00,311.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(512.00,304.00));
      corners.push_back(convertPt(538.00,304.00));
      corners.push_back(convertPt(538.00,297.00));
      corners.push_back(convertPt(551.00,297.00));
      corners.push_back(convertPt(551.00,289.00));
      corners.push_back(convertPt(564.00,289.00));
      corners.push_back(convertPt(564.00,282.00));
      corners.push_back(convertPt(577.00,282.00));
      corners.push_back(convertPt(577.00,275.00));
      corners.push_back(convertPt(589.00,275.00));
      corners.push_back(convertPt(589.00,267.00));
      corners.push_back(convertPt(602.00,267.00));
      corners.push_back(convertPt(602.00,259.00));
      corners.push_back(convertPt(615.00,259.00));
      corners.push_back(convertPt(615.00,252.00));
      corners.push_back(convertPt(628.00,252.00));
      corners.push_back(convertPt(628.00,245.00));
      corners.push_back(convertPt(641.00,245.00));
      corners.push_back(convertPt(641.00,237.00));
      corners.push_back(convertPt(654.00,237.00));
      corners.push_back(convertPt(654.00,230.00));
      corners.push_back(convertPt(667.00,230.00));
      corners.push_back(convertPt(667.00,223.00));
      corners.push_back(convertPt(679.00,223.00));
      corners.push_back(convertPt(679.00,215.00));
      corners.push_back(convertPt(692.00,215.00));
      corners.push_back(convertPt(692.00,207.00));
      corners.push_back(convertPt(705.00,207.00));
      corners.push_back(convertPt(705.00,200.00));
      corners.push_back(convertPt(718.00,200.00));
      corners.push_back(convertPt(718.00,193.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(731.00,186.00));
      corners.push_back(convertPt(744.00,186.00));
      corners.push_back(convertPt(744.00,178.00));
      corners.push_back(convertPt(756.00,178.00));
      corners.push_back(convertPt(756.00,171.00));
      corners.push_back(convertPt(769.00,171.00));
      corners.push_back(convertPt(769.00,163.00));
      corners.push_back(convertPt(782.00,163.00));
      corners.push_back(convertPt(782.00,156.00));
      corners.push_back(convertPt(808.00,156.00));
      corners.push_back(convertPt(808.00,149.00));
      corners.push_back(convertPt(820.00,149.00));
      corners.push_back(convertPt(820.00,141.00));
      corners.push_back(convertPt(834.00,141.00));
      corners.push_back(convertPt(834.00,134.00));
      corners.push_back(convertPt(885.00,134.00));
      corners.push_back(convertPt(885.00,127.00));
      corners.push_back(convertPt(898.00,127.00));
      corners.push_back(convertPt(898.00,120.00));
      corners.push_back(convertPt(911.00,120.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(860.00,415.00));
      corners.push_back(convertPt(860.00,423.00));
      corners.push_back(convertPt(873.00,423.00));
      corners.push_back(convertPt(873.00,415.00));
      corners.push_back(convertPt(860.00,415.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(860.00,467.00));
      corners.push_back(convertPt(860.00,482.00));
      corners.push_back(convertPt(846.00,482.00));
      corners.push_back(convertPt(846.00,467.00));
      corners.push_back(convertPt(860.00,467.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(834.00,474.00));
      corners.push_back(convertPt(834.00,482.00));
      corners.push_back(convertPt(821.00,482.00));
      corners.push_back(convertPt(821.00,474.00));
      corners.push_back(convertPt(834.00,474.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(757.00,475.00));
      corners.push_back(convertPt(757.00,482.00));
      corners.push_back(convertPt(744.00,482.00));
      corners.push_back(convertPt(744.00,475.00));
      corners.push_back(convertPt(757.00,475.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(872.00,489.00));
      corners.push_back(convertPt(872.00,511.00));
      corners.push_back(convertPt(860.00,511.00));
      corners.push_back(convertPt(860.00,489.00));
      corners.push_back(convertPt(872.00,489.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(757.00,503.00));
      corners.push_back(convertPt(757.00,511.00));
      corners.push_back(convertPt(744.00,511.00));
      corners.push_back(convertPt(744.00,503.00));
      corners.push_back(convertPt(757.00,503.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,518.00));
      corners.push_back(convertPt(782.00,526.00));
      corners.push_back(convertPt(769.00,526.00));
      corners.push_back(convertPt(769.00,518.00));
      corners.push_back(convertPt(782.00,518.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(884.00,518.00));
      corners.push_back(convertPt(884.00,526.00));
      corners.push_back(convertPt(873.00,526.00));
      corners.push_back(convertPt(873.00,518.00));
      corners.push_back(convertPt(884.00,518.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(718.00,526.00));
      corners.push_back(convertPt(718.00,541.00));
      corners.push_back(convertPt(705.00,541.00));
      corners.push_back(convertPt(705.00,526.00));
      corners.push_back(convertPt(718.00,526.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(319.00,571.00));
      corners.push_back(convertPt(319.00,578.00));
      corners.push_back(convertPt(344.00,578.00));
      corners.push_back(convertPt(344.00,571.00));
      corners.push_back(convertPt(319.00,571.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(821.00,570.00));
      corners.push_back(convertPt(821.00,578.00));
      corners.push_back(convertPt(808.00,578.00));
      corners.push_back(convertPt(808.00,570.00));
      corners.push_back(convertPt(821.00,570.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(795.00,630.00));
      corners.push_back(convertPt(795.00,637.00));
      corners.push_back(convertPt(808.00,637.00));
      corners.push_back(convertPt(808.00,630.00));
      corners.push_back(convertPt(795.00,630.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(769.00,645.00));
      corners.push_back(convertPt(769.00,652.00));
      corners.push_back(convertPt(782.00,652.00));
      corners.push_back(convertPt(782.00,659.00));
      corners.push_back(convertPt(795.00,659.00));
      corners.push_back(convertPt(795.00,652.00));
      corners.push_back(convertPt(820.00,652.00));
      corners.push_back(convertPt(820.00,645.00));
      corners.push_back(convertPt(769.00,645.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(757.00,659.00));
      corners.push_back(convertPt(757.00,689.00));
      corners.push_back(convertPt(769.00,689.00));
      corners.push_back(convertPt(769.00,682.00));
      corners.push_back(convertPt(782.00,682.00));
      corners.push_back(convertPt(782.00,667.00));
      corners.push_back(convertPt(769.00,667.00));
      corners.push_back(convertPt(769.00,659.00));
      corners.push_back(convertPt(757.00,659.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(860.00,682.00));
      corners.push_back(convertPt(860.00,689.00));
      corners.push_back(convertPt(846.00,689.00));
      corners.push_back(convertPt(846.00,682.00));
      corners.push_back(convertPt(860.00,682.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(705.00,689.00));
      corners.push_back(convertPt(705.00,696.00));
      corners.push_back(convertPt(718.00,696.00));
      corners.push_back(convertPt(718.00,689.00));
      corners.push_back(convertPt(705.00,689.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(860.00,696.00));
      corners.push_back(convertPt(860.00,771.00));
      corners.push_back(convertPt(846.00,771.00));
      corners.push_back(convertPt(846.00,696.00));
      corners.push_back(convertPt(860.00,696.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(821.00,718.00));
      corners.push_back(convertPt(821.00,726.00));
      corners.push_back(convertPt(795.00,726.00));
      corners.push_back(convertPt(795.00,718.00));
      corners.push_back(convertPt(821.00,718.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(731.00,734.00));
      corners.push_back(convertPt(731.00,748.00));
      corners.push_back(convertPt(744.00,748.00));
      corners.push_back(convertPt(744.00,734.00));
      corners.push_back(convertPt(731.00,734.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(808.00,734.00));
      corners.push_back(convertPt(808.00,741.00));
      corners.push_back(convertPt(795.00,741.00));
      corners.push_back(convertPt(795.00,734.00));
      corners.push_back(convertPt(808.00,734.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(782.00,800.00));
      corners.push_back(convertPt(782.00,806.00));
      corners.push_back(convertPt(769.00,806.00));
      corners.push_back(convertPt(769.00,800.00));
      corners.push_back(convertPt(782.00,800.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(5, contoursPointer));

      ///// 0.14pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(923.00,120.00));
      corners.push_back(convertPt(923.00,170.00));
      corners.push_back(convertPt(911.00,170.00));
      corners.push_back(convertPt(911.00,193.00));
      corners.push_back(convertPt(923.00,193.00));
      corners.push_back(convertPt(923.00,237.00));
      corners.push_back(convertPt(911.00,237.00));
      corners.push_back(convertPt(911.00,289.00));
      corners.push_back(convertPt(885.00,289.00));
      corners.push_back(convertPt(885.00,304.00));
      corners.push_back(convertPt(898.00,304.00));
      corners.push_back(convertPt(898.00,326.00));
      corners.push_back(convertPt(885.00,326.00));
      corners.push_back(convertPt(885.00,319.00));
      corners.push_back(convertPt(873.00,319.00));
      corners.push_back(convertPt(873.00,333.00));
      corners.push_back(convertPt(885.00,333.00));
      corners.push_back(convertPt(885.00,371.00));
      corners.push_back(convertPt(898.00,371.00));
      corners.push_back(convertPt(898.00,400.00));
      corners.push_back(convertPt(911.00,400.00));
      corners.push_back(convertPt(911.00,445.00));
      corners.push_back(convertPt(923.00,445.00));
      corners.push_back(convertPt(923.00,475.00));
      corners.push_back(convertPt(911.00,475.00));
      corners.push_back(convertPt(911.00,503.00));
      corners.push_back(convertPt(898.00,503.00));
      corners.push_back(convertPt(898.00,496.00));
      corners.push_back(convertPt(884.00,496.00));
      corners.push_back(convertPt(884.00,511.00));
      corners.push_back(convertPt(898.00,511.00));
      corners.push_back(convertPt(898.00,541.00));
      corners.push_back(convertPt(884.00,541.00));
      corners.push_back(convertPt(884.00,533.00));
      corners.push_back(convertPt(873.00,533.00));
      corners.push_back(convertPt(873.00,518.00));
      corners.push_back(convertPt(860.00,518.00));
      corners.push_back(convertPt(860.00,503.00));
      corners.push_back(convertPt(834.00,503.00));
      corners.push_back(convertPt(834.00,511.00));
      corners.push_back(convertPt(846.00,511.00));
      corners.push_back(convertPt(846.00,526.00));
      corners.push_back(convertPt(860.00,526.00));
      corners.push_back(convertPt(860.00,541.00));
      corners.push_back(convertPt(846.00,541.00));
      corners.push_back(convertPt(846.00,548.00));
      corners.push_back(convertPt(834.00,548.00));
      corners.push_back(convertPt(834.00,563.00));
      corners.push_back(convertPt(846.00,563.00));
      corners.push_back(convertPt(846.00,659.00));
      corners.push_back(convertPt(860.00,659.00));
      corners.push_back(convertPt(860.00,600.00));
      corners.push_back(convertPt(873.00,600.00));
      corners.push_back(convertPt(873.00,637.00));
      corners.push_back(convertPt(884.00,637.00));
      corners.push_back(convertPt(884.00,645.00));
      corners.push_back(convertPt(898.00,645.00));
      corners.push_back(convertPt(898.00,652.00));
      corners.push_back(convertPt(884.00,652.00));
      corners.push_back(convertPt(884.00,704.00));
      corners.push_back(convertPt(898.00,704.00));
      corners.push_back(convertPt(898.00,806.00));
      corners.push_back(convertPt(884.00,806.00));
      corners.push_back(convertPt(884.00,719.00));
      corners.push_back(convertPt(873.00,719.00));
      corners.push_back(convertPt(873.00,806.00));
      corners.push_back(convertPt(179.00,806.00));
      corners.push_back(convertPt(179.00,496.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(191.00,489.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(204.00,482.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(217.00,475.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(230.00,467.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(243.00,460.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(255.00,452.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(268.00,445.00));
      corners.push_back(convertPt(281.00,445.00));
      corners.push_back(convertPt(281.00,437.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(293.00,430.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(306.00,422.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(319.00,415.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(333.00,407.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(345.00,400.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(358.00,393.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(371.00,386.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(384.00,379.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(397.00,371.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(409.00,363.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(422.00,356.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(435.00,349.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(448.00,341.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(461.00,334.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(473.00,326.00));
      corners.push_back(convertPt(486.00,326.00));
      corners.push_back(convertPt(486.00,319.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(500.00,311.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(512.00,304.00));
      corners.push_back(convertPt(525.00,304.00));
      corners.push_back(convertPt(525.00,297.00));
      corners.push_back(convertPt(538.00,297.00));
      corners.push_back(convertPt(538.00,289.00));
      corners.push_back(convertPt(551.00,289.00));
      corners.push_back(convertPt(551.00,282.00));
      corners.push_back(convertPt(564.00,282.00));
      corners.push_back(convertPt(564.00,275.00));
      corners.push_back(convertPt(577.00,275.00));
      corners.push_back(convertPt(577.00,267.00));
      corners.push_back(convertPt(589.00,267.00));
      corners.push_back(convertPt(589.00,259.00));
      corners.push_back(convertPt(602.00,259.00));
      corners.push_back(convertPt(602.00,252.00));
      corners.push_back(convertPt(628.00,252.00));
      corners.push_back(convertPt(628.00,245.00));
      corners.push_back(convertPt(641.00,245.00));
      corners.push_back(convertPt(641.00,237.00));
      corners.push_back(convertPt(654.00,237.00));
      corners.push_back(convertPt(654.00,230.00));
      corners.push_back(convertPt(667.00,230.00));
      corners.push_back(convertPt(667.00,223.00));
      corners.push_back(convertPt(679.00,223.00));
      corners.push_back(convertPt(679.00,215.00));
      corners.push_back(convertPt(692.00,215.00));
      corners.push_back(convertPt(692.00,207.00));
      corners.push_back(convertPt(705.00,207.00));
      corners.push_back(convertPt(705.00,200.00));
      corners.push_back(convertPt(718.00,200.00));
      corners.push_back(convertPt(718.00,193.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(731.00,186.00));
      corners.push_back(convertPt(744.00,186.00));
      corners.push_back(convertPt(744.00,178.00));
      corners.push_back(convertPt(756.00,178.00));
      corners.push_back(convertPt(756.00,171.00));
      corners.push_back(convertPt(769.00,171.00));
      corners.push_back(convertPt(769.00,163.00));
      corners.push_back(convertPt(782.00,163.00));
      corners.push_back(convertPt(782.00,156.00));
      corners.push_back(convertPt(795.00,156.00));
      corners.push_back(convertPt(795.00,149.00));
      corners.push_back(convertPt(808.00,149.00));
      corners.push_back(convertPt(808.00,141.00));
      corners.push_back(convertPt(834.00,141.00));
      corners.push_back(convertPt(834.00,134.00));
      corners.push_back(convertPt(846.00,134.00));
      corners.push_back(convertPt(846.00,127.00));
      corners.push_back(convertPt(873.00,127.00));
      corners.push_back(convertPt(873.00,134.00));
      corners.push_back(convertPt(885.00,134.00));
      corners.push_back(convertPt(885.00,127.00));
      corners.push_back(convertPt(898.00,127.00));
      corners.push_back(convertPt(898.00,120.00));
      corners.push_back(convertPt(923.00,120.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(911.00,356.00));
      corners.push_back(convertPt(911.00,363.00));
      corners.push_back(convertPt(898.00,363.00));
      corners.push_back(convertPt(898.00,356.00));
      corners.push_back(convertPt(911.00,356.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(873.00,371.00));
      corners.push_back(convertPt(873.00,379.00));
      corners.push_back(convertPt(885.00,379.00));
      corners.push_back(convertPt(885.00,371.00));
      corners.push_back(convertPt(873.00,371.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(846.00,452.00));
      corners.push_back(convertPt(846.00,459.00));
      corners.push_back(convertPt(860.00,459.00));
      corners.push_back(convertPt(860.00,452.00));
      corners.push_back(convertPt(846.00,452.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(821.00,459.00));
      corners.push_back(convertPt(821.00,466.00));
      corners.push_back(convertPt(834.00,466.00));
      corners.push_back(convertPt(834.00,459.00));
      corners.push_back(convertPt(821.00,459.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(808.00,489.00));
      corners.push_back(convertPt(808.00,503.00));
      corners.push_back(convertPt(834.00,503.00));
      corners.push_back(convertPt(834.00,496.00));
      corners.push_back(convertPt(821.00,496.00));
      corners.push_back(convertPt(821.00,489.00));
      corners.push_back(convertPt(808.00,489.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(795.00,503.00));
      corners.push_back(convertPt(795.00,511.00));
      corners.push_back(convertPt(808.00,511.00));
      corners.push_back(convertPt(808.00,503.00));
      corners.push_back(convertPt(795.00,503.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(821.00,511.00));
      corners.push_back(convertPt(821.00,526.00));
      corners.push_back(convertPt(834.00,526.00));
      corners.push_back(convertPt(834.00,511.00));
      corners.push_back(convertPt(821.00,511.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(795.00,518.00));
      corners.push_back(convertPt(795.00,526.00));
      corners.push_back(convertPt(808.00,526.00));
      corners.push_back(convertPt(808.00,518.00));
      corners.push_back(convertPt(795.00,518.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(808.00,526.00));
      corners.push_back(convertPt(808.00,533.00));
      corners.push_back(convertPt(821.00,533.00));
      corners.push_back(convertPt(821.00,526.00));
      corners.push_back(convertPt(808.00,526.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(808.00,548.00));
      corners.push_back(convertPt(808.00,556.00));
      corners.push_back(convertPt(821.00,556.00));
      corners.push_back(convertPt(821.00,548.00));
      corners.push_back(convertPt(808.00,548.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(898.00,548.00));
      corners.push_back(convertPt(898.00,563.00));
      corners.push_back(convertPt(911.00,563.00));
      corners.push_back(convertPt(911.00,578.00));
      corners.push_back(convertPt(898.00,578.00));
      corners.push_back(convertPt(898.00,571.00));
      corners.push_back(convertPt(884.00,571.00));
      corners.push_back(convertPt(884.00,585.00));
      corners.push_back(convertPt(873.00,585.00));
      corners.push_back(convertPt(873.00,555.00));
      corners.push_back(convertPt(884.00,555.00));
      corners.push_back(convertPt(884.00,548.00));
      corners.push_back(convertPt(898.00,548.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(860.00,667.00));
      corners.push_back(convertPt(860.00,682.00));
      corners.push_back(convertPt(872.00,682.00));
      corners.push_back(convertPt(872.00,667.00));
      corners.push_back(convertPt(860.00,667.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(821.00,741.00));
      corners.push_back(convertPt(821.00,748.00));
      corners.push_back(convertPt(834.00,748.00));
      corners.push_back(convertPt(834.00,741.00));
      corners.push_back(convertPt(821.00,741.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(834.00,755.00));
      corners.push_back(convertPt(834.00,763.00));
      corners.push_back(convertPt(846.00,763.00));
      corners.push_back(convertPt(846.00,755.00));
      corners.push_back(convertPt(834.00,755.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(6, contoursPointer));

      ///// 0.16pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(923.00,120.00));
      corners.push_back(convertPt(923.00,237.00));
      corners.push_back(convertPt(911.00,237.00));
      corners.push_back(convertPt(911.00,252.00));
      corners.push_back(convertPt(923.00,252.00));
      corners.push_back(convertPt(923.00,281.00));
      corners.push_back(convertPt(911.00,281.00));
      corners.push_back(convertPt(911.00,289.00));
      corners.push_back(convertPt(898.00,289.00));
      corners.push_back(convertPt(898.00,304.00));
      corners.push_back(convertPt(911.00,304.00));
      corners.push_back(convertPt(911.00,326.00));
      corners.push_back(convertPt(898.00,326.00));
      corners.push_back(convertPt(898.00,349.00));
      corners.push_back(convertPt(911.00,349.00));
      corners.push_back(convertPt(911.00,430.00));
      corners.push_back(convertPt(923.00,430.00));
      corners.push_back(convertPt(923.00,475.00));
      corners.push_back(convertPt(911.00,475.00));
      corners.push_back(convertPt(911.00,614.00));
      corners.push_back(convertPt(898.00,614.00));
      corners.push_back(convertPt(898.00,623.00));
      corners.push_back(convertPt(911.00,623.00));
      corners.push_back(convertPt(911.00,725.00));
      corners.push_back(convertPt(898.00,725.00));
      corners.push_back(convertPt(898.00,806.00));
      corners.push_back(convertPt(179.00,806.00));
      corners.push_back(convertPt(179.00,496.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(191.00,489.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(204.00,482.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(217.00,475.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(230.00,467.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(243.00,460.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(255.00,452.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(268.00,445.00));
      corners.push_back(convertPt(281.00,445.00));
      corners.push_back(convertPt(281.00,437.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(293.00,430.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(306.00,422.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(319.00,415.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(333.00,407.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(345.00,400.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(358.00,393.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(371.00,386.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(384.00,379.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(397.00,371.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(409.00,363.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(422.00,356.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(435.00,349.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(448.00,341.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(461.00,334.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(473.00,326.00));
      corners.push_back(convertPt(486.00,326.00));
      corners.push_back(convertPt(486.00,319.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(500.00,311.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(512.00,304.00));
      corners.push_back(convertPt(525.00,304.00));
      corners.push_back(convertPt(525.00,297.00));
      corners.push_back(convertPt(538.00,297.00));
      corners.push_back(convertPt(538.00,289.00));
      corners.push_back(convertPt(551.00,289.00));
      corners.push_back(convertPt(551.00,282.00));
      corners.push_back(convertPt(564.00,282.00));
      corners.push_back(convertPt(564.00,275.00));
      corners.push_back(convertPt(577.00,275.00));
      corners.push_back(convertPt(577.00,267.00));
      corners.push_back(convertPt(589.00,267.00));
      corners.push_back(convertPt(589.00,259.00));
      corners.push_back(convertPt(602.00,259.00));
      corners.push_back(convertPt(602.00,252.00));
      corners.push_back(convertPt(615.00,252.00));
      corners.push_back(convertPt(615.00,245.00));
      corners.push_back(convertPt(628.00,245.00));
      corners.push_back(convertPt(628.00,237.00));
      corners.push_back(convertPt(641.00,237.00));
      corners.push_back(convertPt(641.00,230.00));
      corners.push_back(convertPt(654.00,230.00));
      corners.push_back(convertPt(654.00,223.00));
      corners.push_back(convertPt(667.00,223.00));
      corners.push_back(convertPt(667.00,215.00));
      corners.push_back(convertPt(692.00,215.00));
      corners.push_back(convertPt(692.00,207.00));
      corners.push_back(convertPt(705.00,207.00));
      corners.push_back(convertPt(705.00,200.00));
      corners.push_back(convertPt(718.00,200.00));
      corners.push_back(convertPt(718.00,193.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(731.00,186.00));
      corners.push_back(convertPt(744.00,186.00));
      corners.push_back(convertPt(744.00,178.00));
      corners.push_back(convertPt(756.00,178.00));
      corners.push_back(convertPt(756.00,171.00));
      corners.push_back(convertPt(769.00,171.00));
      corners.push_back(convertPt(769.00,163.00));
      corners.push_back(convertPt(782.00,163.00));
      corners.push_back(convertPt(782.00,156.00));
      corners.push_back(convertPt(795.00,156.00));
      corners.push_back(convertPt(795.00,149.00));
      corners.push_back(convertPt(808.00,149.00));
      corners.push_back(convertPt(808.00,141.00));
      corners.push_back(convertPt(820.00,141.00));
      corners.push_back(convertPt(820.00,134.00));
      corners.push_back(convertPt(846.00,134.00));
      corners.push_back(convertPt(846.00,127.00));
      corners.push_back(convertPt(898.00,127.00));
      corners.push_back(convertPt(898.00,120.00));
      corners.push_back(convertPt(923.00,120.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(885.00,349.00));
      corners.push_back(convertPt(885.00,356.00));
      corners.push_back(convertPt(898.00,356.00));
      corners.push_back(convertPt(898.00,349.00));
      corners.push_back(convertPt(885.00,349.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(860.00,585.00));
      corners.push_back(convertPt(860.00,600.00));
      corners.push_back(convertPt(873.00,600.00));
      corners.push_back(convertPt(873.00,585.00));
      corners.push_back(convertPt(860.00,585.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(7, contoursPointer));

      ///// 0.18pb /////
      corners.clear();
      corners.push_back(convertPt(873.00,120.00));
      corners.push_back(convertPt(873.00,127.00));
      corners.push_back(convertPt(898.00,127.00));
      corners.push_back(convertPt(898.00,120.00));
      corners.push_back(convertPt(923.00,120.00));
      corners.push_back(convertPt(923.00,281.00));
      corners.push_back(convertPt(911.00,281.00));
      corners.push_back(convertPt(911.00,379.00));
      corners.push_back(convertPt(923.00,379.00));
      corners.push_back(convertPt(923.00,503.00));
      corners.push_back(convertPt(911.00,503.00));
      corners.push_back(convertPt(911.00,630.00));
      corners.push_back(convertPt(923.00,630.00));
      corners.push_back(convertPt(923.00,688.00));
      corners.push_back(convertPt(911.00,688.00));
      corners.push_back(convertPt(911.00,777.00));
      corners.push_back(convertPt(898.00,777.00));
      corners.push_back(convertPt(898.00,806.00));
      corners.push_back(convertPt(179.00,806.00));
      corners.push_back(convertPt(179.00,496.00));
      corners.push_back(convertPt(191.00,496.00));
      corners.push_back(convertPt(191.00,489.00));
      corners.push_back(convertPt(204.00,489.00));
      corners.push_back(convertPt(204.00,482.00));
      corners.push_back(convertPt(217.00,482.00));
      corners.push_back(convertPt(217.00,475.00));
      corners.push_back(convertPt(230.00,475.00));
      corners.push_back(convertPt(230.00,467.00));
      corners.push_back(convertPt(243.00,467.00));
      corners.push_back(convertPt(243.00,460.00));
      corners.push_back(convertPt(255.00,460.00));
      corners.push_back(convertPt(255.00,452.00));
      corners.push_back(convertPt(268.00,452.00));
      corners.push_back(convertPt(268.00,445.00));
      corners.push_back(convertPt(281.00,445.00));
      corners.push_back(convertPt(281.00,437.00));
      corners.push_back(convertPt(293.00,437.00));
      corners.push_back(convertPt(293.00,430.00));
      corners.push_back(convertPt(306.00,430.00));
      corners.push_back(convertPt(306.00,422.00));
      corners.push_back(convertPt(319.00,422.00));
      corners.push_back(convertPt(319.00,415.00));
      corners.push_back(convertPt(333.00,415.00));
      corners.push_back(convertPt(333.00,407.00));
      corners.push_back(convertPt(345.00,407.00));
      corners.push_back(convertPt(345.00,400.00));
      corners.push_back(convertPt(358.00,400.00));
      corners.push_back(convertPt(358.00,393.00));
      corners.push_back(convertPt(371.00,393.00));
      corners.push_back(convertPt(371.00,386.00));
      corners.push_back(convertPt(384.00,386.00));
      corners.push_back(convertPt(384.00,379.00));
      corners.push_back(convertPt(397.00,379.00));
      corners.push_back(convertPt(397.00,371.00));
      corners.push_back(convertPt(409.00,371.00));
      corners.push_back(convertPt(409.00,363.00));
      corners.push_back(convertPt(422.00,363.00));
      corners.push_back(convertPt(422.00,356.00));
      corners.push_back(convertPt(435.00,356.00));
      corners.push_back(convertPt(435.00,349.00));
      corners.push_back(convertPt(448.00,349.00));
      corners.push_back(convertPt(448.00,341.00));
      corners.push_back(convertPt(461.00,341.00));
      corners.push_back(convertPt(461.00,334.00));
      corners.push_back(convertPt(473.00,334.00));
      corners.push_back(convertPt(473.00,326.00));
      corners.push_back(convertPt(486.00,326.00));
      corners.push_back(convertPt(486.00,319.00));
      corners.push_back(convertPt(500.00,319.00));
      corners.push_back(convertPt(500.00,311.00));
      corners.push_back(convertPt(512.00,311.00));
      corners.push_back(convertPt(512.00,304.00));
      corners.push_back(convertPt(525.00,304.00));
      corners.push_back(convertPt(525.00,297.00));
      corners.push_back(convertPt(538.00,297.00));
      corners.push_back(convertPt(538.00,289.00));
      corners.push_back(convertPt(551.00,289.00));
      corners.push_back(convertPt(551.00,282.00));
      corners.push_back(convertPt(564.00,282.00));
      corners.push_back(convertPt(564.00,275.00));
      corners.push_back(convertPt(577.00,275.00));
      corners.push_back(convertPt(577.00,267.00));
      corners.push_back(convertPt(589.00,267.00));
      corners.push_back(convertPt(589.00,259.00));
      corners.push_back(convertPt(602.00,259.00));
      corners.push_back(convertPt(602.00,252.00));
      corners.push_back(convertPt(615.00,252.00));
      corners.push_back(convertPt(615.00,245.00));
      corners.push_back(convertPt(628.00,245.00));
      corners.push_back(convertPt(628.00,237.00));
      corners.push_back(convertPt(641.00,237.00));
      corners.push_back(convertPt(641.00,230.00));
      corners.push_back(convertPt(654.00,230.00));
      corners.push_back(convertPt(654.00,223.00));
      corners.push_back(convertPt(667.00,223.00));
      corners.push_back(convertPt(667.00,215.00));
      corners.push_back(convertPt(679.00,215.00));
      corners.push_back(convertPt(679.00,207.00));
      corners.push_back(convertPt(692.00,207.00));
      corners.push_back(convertPt(692.00,200.00));
      corners.push_back(convertPt(718.00,200.00));
      corners.push_back(convertPt(718.00,193.00));
      corners.push_back(convertPt(731.00,193.00));
      corners.push_back(convertPt(731.00,186.00));
      corners.push_back(convertPt(744.00,186.00));
      corners.push_back(convertPt(744.00,178.00));
      corners.push_back(convertPt(756.00,178.00));
      corners.push_back(convertPt(756.00,171.00));
      corners.push_back(convertPt(769.00,171.00));
      corners.push_back(convertPt(769.00,163.00));
      corners.push_back(convertPt(782.00,163.00));
      corners.push_back(convertPt(782.00,156.00));
      corners.push_back(convertPt(795.00,156.00));
      corners.push_back(convertPt(795.00,149.00));
      corners.push_back(convertPt(808.00,149.00));
      corners.push_back(convertPt(808.00,141.00));
      corners.push_back(convertPt(820.00,141.00));
      corners.push_back(convertPt(820.00,134.00));
      corners.push_back(convertPt(834.00,134.00));
      corners.push_back(convertPt(834.00,127.00));
      corners.push_back(convertPt(860.00,127.00));
      corners.push_back(convertPt(860.00,120.00));
      corners.push_back(convertPt(873.00,120.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(8, contoursPointer));

      ///// 0.2pb /////
      corners.clear();
      corners.push_back(convertPt(936.00,53.00));
      corners.push_back(convertPt(936.00,806.0));
      corners.push_back(convertPt(179.00,806.0));
      corners.push_back(convertPt(179.00,482.0));
      corners.push_back(convertPt(191.00,482.0));
      corners.push_back(convertPt(191.00,474.0));
      corners.push_back(convertPt(203.00,474.0));
      corners.push_back(convertPt(203.00,466.0));
      corners.push_back(convertPt(216.00,466.0));
      corners.push_back(convertPt(216.00,459.0));
      corners.push_back(convertPt(229.00,459.0));
      corners.push_back(convertPt(229.00,452.0));
      corners.push_back(convertPt(242.00,452.0));
      corners.push_back(convertPt(242.00,445.0));
      corners.push_back(convertPt(255.00,445.0));
      corners.push_back(convertPt(255.00,437.0));
      corners.push_back(convertPt(268.00,437.0));
      corners.push_back(convertPt(268.00,430.0));
      corners.push_back(convertPt(280.00,430.0));
      corners.push_back(convertPt(280.00,422.0));
      corners.push_back(convertPt(293.00,422.0));
      corners.push_back(convertPt(293.00,415.0));
      corners.push_back(convertPt(306.00,415.0));
      corners.push_back(convertPt(306.00,407.0));
      corners.push_back(convertPt(319.00,407.0));
      corners.push_back(convertPt(319.00,400.0));
      corners.push_back(convertPt(332.00,400.0));
      corners.push_back(convertPt(332.00,393.0));
      corners.push_back(convertPt(345.00,393.0));
      corners.push_back(convertPt(345.00,386.0));
      corners.push_back(convertPt(358.00,386.0));
      corners.push_back(convertPt(358.00,379.0));
      corners.push_back(convertPt(371.00,379.0));
      corners.push_back(convertPt(371.00,371.0));
      corners.push_back(convertPt(384.00,371.0));
      corners.push_back(convertPt(384.00,363.0));
      corners.push_back(convertPt(396.00,363.0));
      corners.push_back(convertPt(396.00,356.0));
      corners.push_back(convertPt(409.00,356.0));
      corners.push_back(convertPt(409.00,349.0));
      corners.push_back(convertPt(422.00,349.0));
      corners.push_back(convertPt(422.00,341.0));
      corners.push_back(convertPt(435.00,341.0));
      corners.push_back(convertPt(435.00,334.0));
      corners.push_back(convertPt(448.00,334.0));
      corners.push_back(convertPt(448.00,327.0));
      corners.push_back(convertPt(460.00,327.0));
      corners.push_back(convertPt(460.00,319.0));
      corners.push_back(convertPt(473.00,319.0));
      corners.push_back(convertPt(473.00,311.0));
      corners.push_back(convertPt(486.00,311.0));
      corners.push_back(convertPt(486.00,304.0));
      corners.push_back(convertPt(500.00,304.0));
      corners.push_back(convertPt(500.00,297.0));
      corners.push_back(convertPt(512.00,297.0));
      corners.push_back(convertPt(512.00,289.0));
      corners.push_back(convertPt(525.00,289.0));
      corners.push_back(convertPt(525.00,282.0));
      corners.push_back(convertPt(538.00,282.0));
      corners.push_back(convertPt(538.00,275.0));
      corners.push_back(convertPt(551.00,275.0));
      corners.push_back(convertPt(551.00,267.0));
      corners.push_back(convertPt(564.00,267.0));
      corners.push_back(convertPt(564.00,259.0));
      corners.push_back(convertPt(576.00,259.0));
      corners.push_back(convertPt(576.00,252.0));
      corners.push_back(convertPt(589.00,252.0));
      corners.push_back(convertPt(589.00,245.0));
      corners.push_back(convertPt(602.00,245.0));
      corners.push_back(convertPt(602.00,237.0));
      corners.push_back(convertPt(615.00,237.0));
      corners.push_back(convertPt(615.00,230.0));
      corners.push_back(convertPt(628.00,230.0));
      corners.push_back(convertPt(628.00,223.0));
      corners.push_back(convertPt(641.00,223.0));
      corners.push_back(convertPt(641.00,215.0));
      corners.push_back(convertPt(653.00,215.0));
      corners.push_back(convertPt(653.00,207.0));
      corners.push_back(convertPt(667.00,207.0));
      corners.push_back(convertPt(667.00,200.0));
      corners.push_back(convertPt(679.00,200.0));
      corners.push_back(convertPt(679.00,193.0));
      corners.push_back(convertPt(692.00,193.0));
      corners.push_back(convertPt(692.00,186.0));
      corners.push_back(convertPt(705.00,186.0));
      corners.push_back(convertPt(705.00,178.0));
      corners.push_back(convertPt(718.00,178.0));
      corners.push_back(convertPt(718.00,171.0));
      corners.push_back(convertPt(731.00,171.0));
      corners.push_back(convertPt(731.00,163.0));
      corners.push_back(convertPt(744.00,163.0));
      corners.push_back(convertPt(744.00,156.0));
      corners.push_back(convertPt(757.00,156.0));
      corners.push_back(convertPt(757.00,149.0));
      corners.push_back(convertPt(769.00,149.0));
      corners.push_back(convertPt(769.00,141.0));
      corners.push_back(convertPt(782.00,141.0));
      corners.push_back(convertPt(782.00,134.0));
      corners.push_back(convertPt(795.00,134.0));
      corners.push_back(convertPt(795.00,127.0));
      corners.push_back(convertPt(808.00,127.0));
      corners.push_back(convertPt(808.00,119.0));
      corners.push_back(convertPt(820.00,119.0));
      corners.push_back(convertPt(820.00,111.0));
      corners.push_back(convertPt(834.00,111.0));
      corners.push_back(convertPt(834.00,104.0));
      corners.push_back(convertPt(846.00,104.0));
      corners.push_back(convertPt(846.00,97.00));
      corners.push_back(convertPt(860.00,97.00));
      corners.push_back(convertPt(860.00,90.00));
      corners.push_back(convertPt(872.00,90.00));
      corners.push_back(convertPt(872.00,82.00));
      corners.push_back(convertPt(884.00,82.00));
      corners.push_back(convertPt(884.00,75.00));
      corners.push_back(convertPt(898.00,75.00));
      corners.push_back(convertPt(898.00,67.00));
      corners.push_back(convertPt(911.00,67.00));
      corners.push_back(convertPt(911.00,60.00));
      corners.push_back(convertPt(924.00,60.00));
      corners.push_back(convertPt(924.00,53.00));
      corners.push_back(convertPt(936.00,53.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(9, contoursPointer));

    }


    
    P2 ALEPHSmuonLimitAt208GeV::convertPt(double x, double y) const
    {
      return P2(50. + (x - 240.00) / (883.00 - 240.00) * (100. - 50.),
                100. + (y - 63.00) / (803.00 - 63.00) * (0. - 100.));
    }
    bool ALEPHSmuonLimitAt208GeV::isWithinExclusionRegion(double x, double y, double mZ) const
    {
      return (y <= x and x <= 208. / 2. and x > mZ / 2.);
    }
    ALEPHSmuonLimitAt208GeV::ALEPHSmuonLimitAt208GeV() {
      ///// Limit values /////
      _limitValuesSorted.push_back(0.01);
      _limitValuesSorted.push_back(0.02);
      _limitValuesSorted.push_back(0.03);
      _limitValuesSorted.push_back(0.04);
      _limitValuesSorted.push_back(0.05);
      _limitValuesSorted.push_back(0.06);
      _limitValuesSorted.push_back(0.07);
      _limitValuesSorted.push_back(0.08);
      _limitValuesSorted.push_back(0.09);
      _limitValuesSorted.push_back(0.1);

      ///// Limit Contours /////
      Corners corners;
      ContoursPointer contoursPointer;
      size_t oldSize;

      ///// 0.01pb /////
      corners.clear();
      corners.push_back(convertPt(317.00,456.00));
      corners.push_back(convertPt(317.00,464.00));
      corners.push_back(convertPt(304.00,464.00));
      corners.push_back(convertPt(304.00,472.00));
      corners.push_back(convertPt(291.00,472.00));
      corners.push_back(convertPt(291.00,479.00));
      corners.push_back(convertPt(278.00,479.00));
      corners.push_back(convertPt(278.00,486.00));
      corners.push_back(convertPt(265.00,486.00));
      corners.push_back(convertPt(265.00,494.00));
      corners.push_back(convertPt(253.00,494.00));
      corners.push_back(convertPt(253.00,501.00));
      corners.push_back(convertPt(240.00,501.00));
      corners.push_back(convertPt(240.00,508.00));
      corners.push_back(convertPt(226.00,508.00));
      corners.push_back(convertPt(226.00,516.00));
      corners.push_back(convertPt(214.00,516.00));
      corners.push_back(convertPt(214.00,524.00));
      corners.push_back(convertPt(201.00,524.00));
      corners.push_back(convertPt(201.00,531.00));
      corners.push_back(convertPt(188.00,531.00));
      corners.push_back(convertPt(188.00,538.00));
      corners.push_back(convertPt(176.00,538.00));
      corners.push_back(convertPt(176.00,531.00));
      corners.push_back(convertPt(188.00,531.00));
      corners.push_back(convertPt(188.00,524.00));
      corners.push_back(convertPt(201.00,524.00));
      corners.push_back(convertPt(201.00,516.00));
      corners.push_back(convertPt(214.00,516.00));
      corners.push_back(convertPt(214.00,508.00));
      corners.push_back(convertPt(226.00,508.00));
      corners.push_back(convertPt(226.00,501.00));
      corners.push_back(convertPt(240.00,501.00));
      corners.push_back(convertPt(240.00,494.00));
      corners.push_back(convertPt(253.00,494.00));
      corners.push_back(convertPt(253.00,486.00));
      corners.push_back(convertPt(265.00,486.00));
      corners.push_back(convertPt(265.00,479.00));
      corners.push_back(convertPt(278.00,479.00));
      corners.push_back(convertPt(278.00,472.00));
      corners.push_back(convertPt(291.00,472.00));
      corners.push_back(convertPt(291.00,464.00));
      corners.push_back(convertPt(304.00,464.00));
      corners.push_back(convertPt(304.00,456.00));
      corners.push_back(convertPt(317.00,456.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(0, contoursPointer));

      ///// 0.02pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(792.00,183.00));
      corners.push_back(convertPt(792.00,205.00));
      corners.push_back(convertPt(767.00,205.00));
      corners.push_back(convertPt(767.00,220.00));
      corners.push_back(convertPt(754.00,220.00));
      corners.push_back(convertPt(754.00,227.00));
      corners.push_back(convertPt(741.00,227.00));
      corners.push_back(convertPt(741.00,235.00));
      corners.push_back(convertPt(754.00,235.00));
      corners.push_back(convertPt(754.00,242.00));
      corners.push_back(convertPt(728.00,242.00));
      corners.push_back(convertPt(728.00,250.00));
      corners.push_back(convertPt(716.00,250.00));
      corners.push_back(convertPt(716.00,257.00));
      corners.push_back(convertPt(702.00,257.00));
      corners.push_back(convertPt(702.00,271.00));
      corners.push_back(convertPt(689.00,271.00));
      corners.push_back(convertPt(689.00,294.00));
      corners.push_back(convertPt(651.00,294.00));
      corners.push_back(convertPt(651.00,301.00));
      corners.push_back(convertPt(626.00,301.00));
      corners.push_back(convertPt(626.00,316.00));
      corners.push_back(convertPt(599.00,316.00));
      corners.push_back(convertPt(599.00,323.00));
      corners.push_back(convertPt(587.00,323.00));
      corners.push_back(convertPt(587.00,331.00));
      corners.push_back(convertPt(573.00,331.00));
      corners.push_back(convertPt(573.00,338.00));
      corners.push_back(convertPt(561.00,338.00));
      corners.push_back(convertPt(561.00,346.00));
      corners.push_back(convertPt(549.00,346.00));
      corners.push_back(convertPt(549.00,353.00));
      corners.push_back(convertPt(535.00,353.00));
      corners.push_back(convertPt(535.00,360.00));
      corners.push_back(convertPt(522.00,360.00));
      corners.push_back(convertPt(522.00,367.00));
      corners.push_back(convertPt(509.00,367.00));
      corners.push_back(convertPt(509.00,375.00));
      corners.push_back(convertPt(497.00,375.00));
      corners.push_back(convertPt(497.00,383.00));
      corners.push_back(convertPt(484.00,383.00));
      corners.push_back(convertPt(484.00,390.00));
      corners.push_back(convertPt(471.00,390.00));
      corners.push_back(convertPt(471.00,397.00));
      corners.push_back(convertPt(446.00,397.00));
      corners.push_back(convertPt(446.00,404.00));
      corners.push_back(convertPt(432.00,404.00));
      corners.push_back(convertPt(432.00,412.00));
      corners.push_back(convertPt(420.00,412.00));
      corners.push_back(convertPt(420.00,419.00));
      corners.push_back(convertPt(406.00,419.00));
      corners.push_back(convertPt(406.00,427.00));
      corners.push_back(convertPt(394.00,427.00));
      corners.push_back(convertPt(394.00,434.00));
      corners.push_back(convertPt(368.00,434.00));
      corners.push_back(convertPt(368.00,442.00));
      corners.push_back(convertPt(355.00,442.00));
      corners.push_back(convertPt(355.00,449.00));
      corners.push_back(convertPt(342.00,449.00));
      corners.push_back(convertPt(342.00,456.00));
      corners.push_back(convertPt(329.00,456.00));
      corners.push_back(convertPt(329.00,464.00));
      corners.push_back(convertPt(304.00,464.00));
      corners.push_back(convertPt(304.00,472.00));
      corners.push_back(convertPt(291.00,472.00));
      corners.push_back(convertPt(291.00,486.00));
      corners.push_back(convertPt(278.00,486.00));
      corners.push_back(convertPt(278.00,494.00));
      corners.push_back(convertPt(253.00,494.00));
      corners.push_back(convertPt(253.00,501.00));
      corners.push_back(convertPt(240.00,501.00));
      corners.push_back(convertPt(240.00,516.00));
      corners.push_back(convertPt(214.00,516.00));
      corners.push_back(convertPt(214.00,524.00));
      corners.push_back(convertPt(201.00,524.00));
      corners.push_back(convertPt(201.00,538.00));
      corners.push_back(convertPt(188.00,538.00));
      corners.push_back(convertPt(188.00,546.00));
      corners.push_back(convertPt(176.00,546.00));
      corners.push_back(convertPt(176.00,501.00));
      corners.push_back(convertPt(188.00,501.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(201.00,494.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(214.00,486.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(226.00,479.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(240.00,472.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(253.00,464.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(265.00,456.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(278.00,449.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(291.00,442.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(304.00,434.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(317.00,427.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(330.00,419.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(343.00,412.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(355.00,404.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(368.00,397.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(382.00,390.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(394.00,383.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(407.00,376.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(420.00,368.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(432.00,360.00));
      corners.push_back(convertPt(432.00,353.00));
      corners.push_back(convertPt(446.00,353.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(458.00,346.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(471.00,338.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(484.00,331.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(497.00,324.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(510.00,316.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(522.00,309.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(535.00,301.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(549.00,294.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(561.00,287.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(574.00,280.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(599.00,272.00));
      corners.push_back(convertPt(599.00,264.00));
      corners.push_back(convertPt(613.00,264.00));
      corners.push_back(convertPt(613.00,257.00));
      corners.push_back(convertPt(626.00,257.00));
      corners.push_back(convertPt(626.00,250.00));
      corners.push_back(convertPt(639.00,250.00));
      corners.push_back(convertPt(639.00,242.00));
      corners.push_back(convertPt(651.00,242.00));
      corners.push_back(convertPt(651.00,235.00));
      corners.push_back(convertPt(664.00,235.00));
      corners.push_back(convertPt(664.00,228.00));
      corners.push_back(convertPt(689.00,228.00));
      corners.push_back(convertPt(689.00,220.00));
      corners.push_back(convertPt(702.00,220.00));
      corners.push_back(convertPt(702.00,212.00));
      corners.push_back(convertPt(716.00,212.00));
      corners.push_back(convertPt(716.00,205.00));
      corners.push_back(convertPt(728.00,205.00));
      corners.push_back(convertPt(728.00,198.00));
      corners.push_back(convertPt(754.00,198.00));
      corners.push_back(convertPt(754.00,190.00));
      corners.push_back(convertPt(780.00,190.00));
      corners.push_back(convertPt(780.00,183.00));
      corners.push_back(convertPt(792.00,183.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(651.00,309.00));
      corners.push_back(convertPt(651.00,316.00));
      corners.push_back(convertPt(639.00,316.00));
      corners.push_back(convertPt(639.00,309.00));
      corners.push_back(convertPt(651.00,309.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(1, contoursPointer));

      ///// 0.03pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(818.00,153.00));
      corners.push_back(convertPt(818.00,168.00));
      corners.push_back(convertPt(831.00,168.00));
      corners.push_back(convertPt(831.00,160.00));
      corners.push_back(convertPt(844.00,160.00));
      corners.push_back(convertPt(844.00,175.00));
      corners.push_back(convertPt(831.00,175.00));
      corners.push_back(convertPt(831.00,183.00));
      corners.push_back(convertPt(818.00,183.00));
      corners.push_back(convertPt(818.00,190.00));
      corners.push_back(convertPt(805.00,190.00));
      corners.push_back(convertPt(805.00,198.00));
      corners.push_back(convertPt(792.00,198.00));
      corners.push_back(convertPt(792.00,212.00));
      corners.push_back(convertPt(780.00,212.00));
      corners.push_back(convertPt(780.00,227.00));
      corners.push_back(convertPt(805.00,227.00));
      corners.push_back(convertPt(805.00,235.00));
      corners.push_back(convertPt(780.00,235.00));
      corners.push_back(convertPt(780.00,250.00));
      corners.push_back(convertPt(767.00,250.00));
      corners.push_back(convertPt(767.00,264.00));
      corners.push_back(convertPt(754.00,264.00));
      corners.push_back(convertPt(754.00,271.00));
      corners.push_back(convertPt(741.00,271.00));
      corners.push_back(convertPt(741.00,294.00));
      corners.push_back(convertPt(728.00,294.00));
      corners.push_back(convertPt(728.00,301.00));
      corners.push_back(convertPt(716.00,301.00));
      corners.push_back(convertPt(716.00,323.00));
      corners.push_back(convertPt(677.00,323.00));
      corners.push_back(convertPt(677.00,338.00));
      corners.push_back(convertPt(664.00,338.00));
      corners.push_back(convertPt(664.00,346.00));
      corners.push_back(convertPt(639.00,346.00));
      corners.push_back(convertPt(639.00,353.00));
      corners.push_back(convertPt(626.00,353.00));
      corners.push_back(convertPt(626.00,346.00));
      corners.push_back(convertPt(599.00,346.00));
      corners.push_back(convertPt(599.00,353.00));
      corners.push_back(convertPt(587.00,353.00));
      corners.push_back(convertPt(587.00,367.00));
      corners.push_back(convertPt(561.00,367.00));
      corners.push_back(convertPt(561.00,375.00));
      corners.push_back(convertPt(535.00,375.00));
      corners.push_back(convertPt(535.00,383.00));
      corners.push_back(convertPt(522.00,383.00));
      corners.push_back(convertPt(522.00,390.00));
      corners.push_back(convertPt(510.00,390.00));
      corners.push_back(convertPt(510.00,397.00));
      corners.push_back(convertPt(497.00,397.00));
      corners.push_back(convertPt(497.00,404.00));
      corners.push_back(convertPt(471.00,404.00));
      corners.push_back(convertPt(471.00,412.00));
      corners.push_back(convertPt(458.00,412.00));
      corners.push_back(convertPt(458.00,419.00));
      corners.push_back(convertPt(446.00,419.00));
      corners.push_back(convertPt(446.00,427.00));
      corners.push_back(convertPt(420.00,427.00));
      corners.push_back(convertPt(420.00,434.00));
      corners.push_back(convertPt(406.00,434.00));
      corners.push_back(convertPt(406.00,442.00));
      corners.push_back(convertPt(394.00,442.00));
      corners.push_back(convertPt(394.00,449.00));
      corners.push_back(convertPt(368.00,449.00));
      corners.push_back(convertPt(368.00,456.00));
      corners.push_back(convertPt(355.00,456.00));
      corners.push_back(convertPt(355.00,464.00));
      corners.push_back(convertPt(342.00,464.00));
      corners.push_back(convertPt(342.00,471.00));
      corners.push_back(convertPt(317.00,471.00));
      corners.push_back(convertPt(317.00,479.00));
      corners.push_back(convertPt(304.00,479.00));
      corners.push_back(convertPt(304.00,486.00));
      corners.push_back(convertPt(291.00,486.00));
      corners.push_back(convertPt(291.00,494.00));
      corners.push_back(convertPt(278.00,494.00));
      corners.push_back(convertPt(278.00,501.00));
      corners.push_back(convertPt(253.00,501.00));
      corners.push_back(convertPt(253.00,516.00));
      corners.push_back(convertPt(240.00,516.00));
      corners.push_back(convertPt(240.00,524.00));
      corners.push_back(convertPt(214.00,524.00));
      corners.push_back(convertPt(214.00,531.00));
      corners.push_back(convertPt(201.00,531.00));
      corners.push_back(convertPt(201.00,546.00));
      corners.push_back(convertPt(188.00,546.00));
      corners.push_back(convertPt(188.00,553.00));
      corners.push_back(convertPt(176.00,553.00));
      corners.push_back(convertPt(176.00,501.00));
      corners.push_back(convertPt(188.00,501.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(201.00,494.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(214.00,486.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(226.00,479.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(240.00,472.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(253.00,464.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(265.00,456.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(278.00,449.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(291.00,442.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(304.00,434.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(317.00,427.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(330.00,419.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(343.00,412.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(355.00,404.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(368.00,397.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(382.00,390.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(394.00,383.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(407.00,376.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(420.00,368.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(432.00,360.00));
      corners.push_back(convertPt(432.00,353.00));
      corners.push_back(convertPt(446.00,353.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(458.00,346.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(471.00,338.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(484.00,331.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(497.00,324.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(510.00,316.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(522.00,309.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(535.00,301.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(549.00,294.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(561.00,287.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(574.00,280.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(587.00,272.00));
      corners.push_back(convertPt(587.00,264.00));
      corners.push_back(convertPt(599.00,264.00));
      corners.push_back(convertPt(599.00,257.00));
      corners.push_back(convertPt(613.00,257.00));
      corners.push_back(convertPt(613.00,250.00));
      corners.push_back(convertPt(626.00,250.00));
      corners.push_back(convertPt(626.00,242.00));
      corners.push_back(convertPt(639.00,242.00));
      corners.push_back(convertPt(639.00,235.00));
      corners.push_back(convertPt(651.00,235.00));
      corners.push_back(convertPt(651.00,228.00));
      corners.push_back(convertPt(664.00,228.00));
      corners.push_back(convertPt(664.00,220.00));
      corners.push_back(convertPt(689.00,220.00));
      corners.push_back(convertPt(689.00,212.00));
      corners.push_back(convertPt(702.00,212.00));
      corners.push_back(convertPt(702.00,205.00));
      corners.push_back(convertPt(716.00,205.00));
      corners.push_back(convertPt(716.00,198.00));
      corners.push_back(convertPt(728.00,198.00));
      corners.push_back(convertPt(728.00,190.00));
      corners.push_back(convertPt(741.00,190.00));
      corners.push_back(convertPt(741.00,183.00));
      corners.push_back(convertPt(754.00,183.00));
      corners.push_back(convertPt(754.00,175.00));
      corners.push_back(convertPt(780.00,175.00));
      corners.push_back(convertPt(780.00,168.00));
      corners.push_back(convertPt(792.00,168.00));
      corners.push_back(convertPt(792.00,160.00));
      corners.push_back(convertPt(805.00,160.00));
      corners.push_back(convertPt(805.00,153.00));
      corners.push_back(convertPt(818.00,153.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(805.00,168.00));
      corners.push_back(convertPt(805.00,175.00));
      corners.push_back(convertPt(818.00,175.00));
      corners.push_back(convertPt(818.00,168.00));
      corners.push_back(convertPt(805.00,168.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(2, contoursPointer));

      ///// 0.04pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(844.00,138.00));
      corners.push_back(convertPt(844.00,146.00));
      corners.push_back(convertPt(831.00,146.00));
      corners.push_back(convertPt(831.00,153.00));
      corners.push_back(convertPt(818.00,153.00));
      corners.push_back(convertPt(818.00,168.00));
      corners.push_back(convertPt(831.00,168.00));
      corners.push_back(convertPt(831.00,160.00));
      corners.push_back(convertPt(844.00,160.00));
      corners.push_back(convertPt(844.00,153.00));
      corners.push_back(convertPt(857.00,153.00));
      corners.push_back(convertPt(857.00,160.00));
      corners.push_back(convertPt(844.00,160.00));
      corners.push_back(convertPt(844.00,183.00));
      corners.push_back(convertPt(831.00,183.00));
      corners.push_back(convertPt(831.00,190.00));
      corners.push_back(convertPt(818.00,190.00));
      corners.push_back(convertPt(818.00,198.00));
      corners.push_back(convertPt(805.00,198.00));
      corners.push_back(convertPt(805.00,205.00));
      corners.push_back(convertPt(818.00,205.00));
      corners.push_back(convertPt(818.00,220.00));
      corners.push_back(convertPt(831.00,220.00));
      corners.push_back(convertPt(831.00,227.00));
      corners.push_back(convertPt(818.00,227.00));
      corners.push_back(convertPt(818.00,250.00));
      corners.push_back(convertPt(792.00,250.00));
      corners.push_back(convertPt(792.00,286.00));
      corners.push_back(convertPt(780.00,286.00));
      corners.push_back(convertPt(780.00,301.00));
      corners.push_back(convertPt(767.00,301.00));
      corners.push_back(convertPt(767.00,316.00));
      corners.push_back(convertPt(741.00,316.00));
      corners.push_back(convertPt(741.00,323.00));
      corners.push_back(convertPt(728.00,323.00));
      corners.push_back(convertPt(728.00,331.00));
      corners.push_back(convertPt(716.00,331.00));
      corners.push_back(convertPt(716.00,338.00));
      corners.push_back(convertPt(677.00,338.00));
      corners.push_back(convertPt(677.00,346.00));
      corners.push_back(convertPt(664.00,346.00));
      corners.push_back(convertPt(664.00,353.00));
      corners.push_back(convertPt(639.00,353.00));
      corners.push_back(convertPt(639.00,360.00));
      corners.push_back(convertPt(613.00,360.00));
      corners.push_back(convertPt(613.00,367.00));
      corners.push_back(convertPt(599.00,367.00));
      corners.push_back(convertPt(599.00,375.00));
      corners.push_back(convertPt(587.00,375.00));
      corners.push_back(convertPt(587.00,382.00));
      corners.push_back(convertPt(561.00,382.00));
      corners.push_back(convertPt(561.00,390.00));
      corners.push_back(convertPt(549.00,390.00));
      corners.push_back(convertPt(549.00,397.00));
      corners.push_back(convertPt(535.00,397.00));
      corners.push_back(convertPt(535.00,404.00));
      corners.push_back(convertPt(522.00,404.00));
      corners.push_back(convertPt(522.00,412.00));
      corners.push_back(convertPt(497.00,412.00));
      corners.push_back(convertPt(497.00,419.00));
      corners.push_back(convertPt(471.00,419.00));
      corners.push_back(convertPt(471.00,427.00));
      corners.push_back(convertPt(458.00,427.00));
      corners.push_back(convertPt(458.00,434.00));
      corners.push_back(convertPt(446.00,434.00));
      corners.push_back(convertPt(446.00,442.00));
      corners.push_back(convertPt(420.00,442.00));
      corners.push_back(convertPt(420.00,449.00));
      corners.push_back(convertPt(406.00,449.00));
      corners.push_back(convertPt(406.00,456.00));
      corners.push_back(convertPt(394.00,456.00));
      corners.push_back(convertPt(394.00,464.00));
      corners.push_back(convertPt(381.00,464.00));
      corners.push_back(convertPt(381.00,471.00));
      corners.push_back(convertPt(355.00,471.00));
      corners.push_back(convertPt(355.00,479.00));
      corners.push_back(convertPt(317.00,479.00));
      corners.push_back(convertPt(317.00,494.00));
      corners.push_back(convertPt(304.00,494.00));
      corners.push_back(convertPt(304.00,501.00));
      corners.push_back(convertPt(278.00,501.00));
      corners.push_back(convertPt(278.00,508.00));
      corners.push_back(convertPt(265.00,508.00));
      corners.push_back(convertPt(265.00,516.00));
      corners.push_back(convertPt(253.00,516.00));
      corners.push_back(convertPt(253.00,524.00));
      corners.push_back(convertPt(240.00,524.00));
      corners.push_back(convertPt(240.00,531.00));
      corners.push_back(convertPt(214.00,531.00));
      corners.push_back(convertPt(214.00,546.00));
      corners.push_back(convertPt(201.00,546.00));
      corners.push_back(convertPt(201.00,560.00));
      corners.push_back(convertPt(176.00,560.00));
      corners.push_back(convertPt(176.00,494.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(188.00,486.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(201.00,479.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(214.00,472.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(226.00,464.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(240.00,456.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(253.00,449.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(265.00,442.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(278.00,434.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(291.00,427.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(304.00,419.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(317.00,412.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(330.00,404.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(343.00,397.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(355.00,390.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(368.00,383.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(382.00,376.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(394.00,368.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(407.00,360.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(420.00,353.00));
      corners.push_back(convertPt(446.00,353.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(458.00,346.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(471.00,338.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(484.00,331.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(497.00,324.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(510.00,316.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(522.00,309.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(535.00,301.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(549.00,294.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(561.00,287.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(574.00,280.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(587.00,272.00));
      corners.push_back(convertPt(587.00,264.00));
      corners.push_back(convertPt(599.00,264.00));
      corners.push_back(convertPt(599.00,257.00));
      corners.push_back(convertPt(613.00,257.00));
      corners.push_back(convertPt(613.00,250.00));
      corners.push_back(convertPt(626.00,250.00));
      corners.push_back(convertPt(626.00,242.00));
      corners.push_back(convertPt(639.00,242.00));
      corners.push_back(convertPt(639.00,235.00));
      corners.push_back(convertPt(651.00,235.00));
      corners.push_back(convertPt(651.00,228.00));
      corners.push_back(convertPt(664.00,228.00));
      corners.push_back(convertPt(664.00,220.00));
      corners.push_back(convertPt(677.00,220.00));
      corners.push_back(convertPt(677.00,212.00));
      corners.push_back(convertPt(689.00,212.00));
      corners.push_back(convertPt(689.00,205.00));
      corners.push_back(convertPt(702.00,205.00));
      corners.push_back(convertPt(702.00,198.00));
      corners.push_back(convertPt(716.00,198.00));
      corners.push_back(convertPt(716.00,190.00));
      corners.push_back(convertPt(728.00,190.00));
      corners.push_back(convertPt(728.00,183.00));
      corners.push_back(convertPt(741.00,183.00));
      corners.push_back(convertPt(741.00,175.00));
      corners.push_back(convertPt(767.00,175.00));
      corners.push_back(convertPt(767.00,168.00));
      corners.push_back(convertPt(780.00,168.00));
      corners.push_back(convertPt(780.00,160.00));
      corners.push_back(convertPt(792.00,160.00));
      corners.push_back(convertPt(792.00,153.00));
      corners.push_back(convertPt(818.00,153.00));
      corners.push_back(convertPt(818.00,146.00));
      corners.push_back(convertPt(831.00,146.00));
      corners.push_back(convertPt(831.00,138.00));
      corners.push_back(convertPt(844.00,138.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(805.00,168.00));
      corners.push_back(convertPt(805.00,175.00));
      corners.push_back(convertPt(818.00,175.00));
      corners.push_back(convertPt(818.00,168.00));
      corners.push_back(convertPt(805.00,168.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(895.00,412.00));
      corners.push_back(convertPt(895.00,419.00));
      corners.push_back(convertPt(882.00,419.00));
      corners.push_back(convertPt(882.00,412.00));
      corners.push_back(convertPt(895.00,412.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(857.00,419.00));
      corners.push_back(convertPt(857.00,442.00));
      corners.push_back(convertPt(882.00,442.00));
      corners.push_back(convertPt(882.00,449.00));
      corners.push_back(convertPt(895.00,449.00));
      corners.push_back(convertPt(895.00,471.00));
      corners.push_back(convertPt(882.00,471.00));
      corners.push_back(convertPt(882.00,486.00));
      corners.push_back(convertPt(869.00,486.00));
      corners.push_back(convertPt(869.00,471.00));
      corners.push_back(convertPt(857.00,471.00));
      corners.push_back(convertPt(857.00,464.00));
      corners.push_back(convertPt(844.00,464.00));
      corners.push_back(convertPt(844.00,456.00));
      corners.push_back(convertPt(831.00,456.00));
      corners.push_back(convertPt(831.00,449.00));
      corners.push_back(convertPt(844.00,449.00));
      corners.push_back(convertPt(844.00,419.00));
      corners.push_back(convertPt(857.00,419.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,649.00));
      corners.push_back(convertPt(780.00,656.00));
      corners.push_back(convertPt(767.00,656.00));
      corners.push_back(convertPt(767.00,649.00));
      corners.push_back(convertPt(780.00,649.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(805.00,679.00));
      corners.push_back(convertPt(805.00,722.00));
      corners.push_back(convertPt(792.00,722.00));
      corners.push_back(convertPt(792.00,708.00));
      corners.push_back(convertPt(780.00,708.00));
      corners.push_back(convertPt(780.00,701.00));
      corners.push_back(convertPt(792.00,701.00));
      corners.push_back(convertPt(792.00,679.00));
      corners.push_back(convertPt(805.00,679.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,722.00));
      corners.push_back(convertPt(780.00,730.00));
      corners.push_back(convertPt(767.00,730.00));
      corners.push_back(convertPt(767.00,722.00));
      corners.push_back(convertPt(780.00,722.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,738.00));
      corners.push_back(convertPt(780.00,745.00));
      corners.push_back(convertPt(767.00,745.00));
      corners.push_back(convertPt(767.00,738.00));
      corners.push_back(convertPt(780.00,738.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(3, contoursPointer));

      ///// 0.05pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,124.00));
      corners.push_back(convertPt(869.00,131.00));
      corners.push_back(convertPt(857.00,131.00));
      corners.push_back(convertPt(857.00,138.00));
      corners.push_back(convertPt(844.00,138.00));
      corners.push_back(convertPt(844.00,146.00));
      corners.push_back(convertPt(831.00,146.00));
      corners.push_back(convertPt(831.00,153.00));
      corners.push_back(convertPt(818.00,153.00));
      corners.push_back(convertPt(818.00,160.00));
      corners.push_back(convertPt(844.00,160.00));
      corners.push_back(convertPt(844.00,153.00));
      corners.push_back(convertPt(857.00,153.00));
      corners.push_back(convertPt(857.00,160.00));
      corners.push_back(convertPt(844.00,160.00));
      corners.push_back(convertPt(844.00,168.00));
      corners.push_back(convertPt(869.00,168.00));
      corners.push_back(convertPt(869.00,175.00));
      corners.push_back(convertPt(857.00,175.00));
      corners.push_back(convertPt(857.00,183.00));
      corners.push_back(convertPt(844.00,183.00));
      corners.push_back(convertPt(844.00,190.00));
      corners.push_back(convertPt(857.00,190.00));
      corners.push_back(convertPt(857.00,198.00));
      corners.push_back(convertPt(844.00,198.00));
      corners.push_back(convertPt(844.00,205.00));
      corners.push_back(convertPt(857.00,205.00));
      corners.push_back(convertPt(857.00,220.00));
      corners.push_back(convertPt(844.00,220.00));
      corners.push_back(convertPt(844.00,242.00));
      corners.push_back(convertPt(818.00,242.00));
      corners.push_back(convertPt(818.00,264.00));
      corners.push_back(convertPt(831.00,264.00));
      corners.push_back(convertPt(831.00,271.00));
      corners.push_back(convertPt(818.00,271.00));
      corners.push_back(convertPt(818.00,294.00));
      corners.push_back(convertPt(792.00,294.00));
      corners.push_back(convertPt(792.00,316.00));
      corners.push_back(convertPt(805.00,316.00));
      corners.push_back(convertPt(805.00,323.00));
      corners.push_back(convertPt(792.00,323.00));
      corners.push_back(convertPt(792.00,316.00));
      corners.push_back(convertPt(780.00,316.00));
      corners.push_back(convertPt(780.00,323.00));
      corners.push_back(convertPt(754.00,323.00));
      corners.push_back(convertPt(754.00,331.00));
      corners.push_back(convertPt(728.00,331.00));
      corners.push_back(convertPt(728.00,338.00));
      corners.push_back(convertPt(716.00,338.00));
      corners.push_back(convertPt(716.00,346.00));
      corners.push_back(convertPt(690.00,346.00));
      corners.push_back(convertPt(690.00,353.00));
      corners.push_back(convertPt(677.00,353.00));
      corners.push_back(convertPt(677.00,360.00));
      corners.push_back(convertPt(651.00,360.00));
      corners.push_back(convertPt(651.00,367.00));
      corners.push_back(convertPt(626.00,367.00));
      corners.push_back(convertPt(626.00,383.00));
      corners.push_back(convertPt(613.00,383.00));
      corners.push_back(convertPt(613.00,390.00));
      corners.push_back(convertPt(587.00,390.00));
      corners.push_back(convertPt(587.00,397.00));
      corners.push_back(convertPt(574.00,397.00));
      corners.push_back(convertPt(574.00,404.00));
      corners.push_back(convertPt(561.00,404.00));
      corners.push_back(convertPt(561.00,412.00));
      corners.push_back(convertPt(549.00,412.00));
      corners.push_back(convertPt(549.00,419.00));
      corners.push_back(convertPt(535.00,419.00));
      corners.push_back(convertPt(535.00,427.00));
      corners.push_back(convertPt(511.00,427.00));
      corners.push_back(convertPt(511.00,434.00));
      corners.push_back(convertPt(484.00,434.00));
      corners.push_back(convertPt(484.00,442.00));
      corners.push_back(convertPt(458.00,442.00));
      corners.push_back(convertPt(458.00,449.00));
      corners.push_back(convertPt(446.00,449.00));
      corners.push_back(convertPt(446.00,456.00));
      corners.push_back(convertPt(432.00,456.00));
      corners.push_back(convertPt(432.00,464.00));
      corners.push_back(convertPt(420.00,464.00));
      corners.push_back(convertPt(420.00,471.00));
      corners.push_back(convertPt(406.00,471.00));
      corners.push_back(convertPt(406.00,479.00));
      corners.push_back(convertPt(394.00,479.00));
      corners.push_back(convertPt(394.00,486.00));
      corners.push_back(convertPt(368.00,486.00));
      corners.push_back(convertPt(368.00,494.00));
      corners.push_back(convertPt(355.00,494.00));
      corners.push_back(convertPt(355.00,501.00));
      corners.push_back(convertPt(342.00,501.00));
      corners.push_back(convertPt(342.00,508.00));
      corners.push_back(convertPt(330.00,508.00));
      corners.push_back(convertPt(330.00,516.00));
      corners.push_back(convertPt(291.00,516.00));
      corners.push_back(convertPt(291.00,523.00));
      corners.push_back(convertPt(278.00,523.00));
      corners.push_back(convertPt(278.00,546.00));
      corners.push_back(convertPt(265.00,546.00));
      corners.push_back(convertPt(265.00,538.00));
      corners.push_back(convertPt(214.00,538.00));
      corners.push_back(convertPt(214.00,560.00));
      corners.push_back(convertPt(201.00,560.00));
      corners.push_back(convertPt(201.00,568.00));
      corners.push_back(convertPt(176.00,568.00));
      corners.push_back(convertPt(176.00,494.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(188.00,486.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(201.00,479.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(214.00,472.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(226.00,464.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(240.00,456.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(253.00,449.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(265.00,442.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(278.00,434.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(291.00,427.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(304.00,419.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(317.00,412.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(330.00,404.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(343.00,397.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(355.00,390.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(368.00,383.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(382.00,376.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(394.00,368.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(407.00,360.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(420.00,353.00));
      corners.push_back(convertPt(432.00,353.00));
      corners.push_back(convertPt(432.00,346.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(446.00,338.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(458.00,331.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(471.00,324.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(484.00,316.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(497.00,309.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(510.00,301.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(522.00,294.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(535.00,287.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(549.00,280.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(561.00,272.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(574.00,264.00));
      corners.push_back(convertPt(599.00,264.00));
      corners.push_back(convertPt(599.00,257.00));
      corners.push_back(convertPt(613.00,257.00));
      corners.push_back(convertPt(613.00,250.00));
      corners.push_back(convertPt(626.00,250.00));
      corners.push_back(convertPt(626.00,242.00));
      corners.push_back(convertPt(639.00,242.00));
      corners.push_back(convertPt(639.00,235.00));
      corners.push_back(convertPt(651.00,235.00));
      corners.push_back(convertPt(651.00,228.00));
      corners.push_back(convertPt(664.00,228.00));
      corners.push_back(convertPt(664.00,220.00));
      corners.push_back(convertPt(677.00,220.00));
      corners.push_back(convertPt(677.00,212.00));
      corners.push_back(convertPt(689.00,212.00));
      corners.push_back(convertPt(689.00,205.00));
      corners.push_back(convertPt(702.00,205.00));
      corners.push_back(convertPt(702.00,198.00));
      corners.push_back(convertPt(716.00,198.00));
      corners.push_back(convertPt(716.00,190.00));
      corners.push_back(convertPt(728.00,190.00));
      corners.push_back(convertPt(728.00,183.00));
      corners.push_back(convertPt(741.00,183.00));
      corners.push_back(convertPt(741.00,175.00));
      corners.push_back(convertPt(754.00,175.00));
      corners.push_back(convertPt(754.00,168.00));
      corners.push_back(convertPt(780.00,168.00));
      corners.push_back(convertPt(780.00,160.00));
      corners.push_back(convertPt(792.00,160.00));
      corners.push_back(convertPt(792.00,153.00));
      corners.push_back(convertPt(805.00,153.00));
      corners.push_back(convertPt(805.00,146.00));
      corners.push_back(convertPt(818.00,146.00));
      corners.push_back(convertPt(818.00,138.00));
      corners.push_back(convertPt(831.00,138.00));
      corners.push_back(convertPt(831.00,131.00));
      corners.push_back(convertPt(857.00,131.00));
      corners.push_back(convertPt(857.00,124.00));
      corners.push_back(convertPt(869.00,124.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(908.00,331.00));
      corners.push_back(convertPt(908.00,338.00));
      corners.push_back(convertPt(895.00,338.00));
      corners.push_back(convertPt(895.00,331.00));
      corners.push_back(convertPt(908.00,331.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,353.00));
      corners.push_back(convertPt(780.00,360.00));
      corners.push_back(convertPt(767.00,360.00));
      corners.push_back(convertPt(767.00,353.00));
      corners.push_back(convertPt(780.00,353.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(882.00,375.00));
      corners.push_back(convertPt(882.00,390.00));
      corners.push_back(convertPt(895.00,390.00));
      corners.push_back(convertPt(895.00,383.00));
      corners.push_back(convertPt(908.00,383.00));
      corners.push_back(convertPt(908.00,434.00));
      corners.push_back(convertPt(895.00,434.00));
      corners.push_back(convertPt(895.00,501.00));
      corners.push_back(convertPt(882.00,501.00));
      corners.push_back(convertPt(882.00,486.00));
      corners.push_back(convertPt(844.00,486.00));
      corners.push_back(convertPt(844.00,471.00));
      corners.push_back(convertPt(857.00,471.00));
      corners.push_back(convertPt(857.00,464.00));
      corners.push_back(convertPt(831.00,464.00));
      corners.push_back(convertPt(831.00,442.00));
      corners.push_back(convertPt(844.00,442.00));
      corners.push_back(convertPt(844.00,419.00));
      corners.push_back(convertPt(857.00,419.00));
      corners.push_back(convertPt(857.00,397.00));
      corners.push_back(convertPt(869.00,397.00));
      corners.push_back(convertPt(869.00,375.00));
      corners.push_back(convertPt(882.00,375.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,404.00));
      corners.push_back(convertPt(869.00,419.00));
      corners.push_back(convertPt(882.00,419.00));
      corners.push_back(convertPt(882.00,404.00));
      corners.push_back(convertPt(869.00,404.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(806.00,412.00));
      corners.push_back(convertPt(806.00,419.00));
      corners.push_back(convertPt(818.00,419.00));
      corners.push_back(convertPt(818.00,427.00));
      corners.push_back(convertPt(806.00,427.00));
      corners.push_back(convertPt(806.00,419.00));
      corners.push_back(convertPt(792.00,419.00));
      corners.push_back(convertPt(792.00,412.00));
      corners.push_back(convertPt(806.00,412.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(574.00,427.00));
      corners.push_back(convertPt(574.00,434.00));
      corners.push_back(convertPt(561.00,434.00));
      corners.push_back(convertPt(561.00,442.00));
      corners.push_back(convertPt(549.00,442.00));
      corners.push_back(convertPt(549.00,449.00));
      corners.push_back(convertPt(535.00,449.00));
      corners.push_back(convertPt(535.00,434.00));
      corners.push_back(convertPt(549.00,434.00));
      corners.push_back(convertPt(549.00,427.00));
      corners.push_back(convertPt(574.00,427.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(818.00,434.00));
      corners.push_back(convertPt(818.00,442.00));
      corners.push_back(convertPt(806.00,442.00));
      corners.push_back(convertPt(806.00,434.00));
      corners.push_back(convertPt(818.00,434.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(458.00,494.00));
      corners.push_back(convertPt(458.00,501.00));
      corners.push_back(convertPt(447.00,501.00));
      corners.push_back(convertPt(447.00,494.00));
      corners.push_back(convertPt(458.00,494.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(844.00,501.00));
      corners.push_back(convertPt(844.00,531.00));
      corners.push_back(convertPt(857.00,531.00));
      corners.push_back(convertPt(857.00,546.00));
      corners.push_back(convertPt(844.00,546.00));
      corners.push_back(convertPt(844.00,531.00));
      corners.push_back(convertPt(831.00,531.00));
      corners.push_back(convertPt(831.00,546.00));
      corners.push_back(convertPt(818.00,546.00));
      corners.push_back(convertPt(818.00,531.00));
      corners.push_back(convertPt(831.00,531.00));
      corners.push_back(convertPt(831.00,523.00));
      corners.push_back(convertPt(818.00,523.00));
      corners.push_back(convertPt(818.00,516.00));
      corners.push_back(convertPt(805.00,516.00));
      corners.push_back(convertPt(805.00,508.00));
      corners.push_back(convertPt(818.00,508.00));
      corners.push_back(convertPt(818.00,516.00));
      corners.push_back(convertPt(831.00,516.00));
      corners.push_back(convertPt(831.00,501.00));
      corners.push_back(convertPt(844.00,501.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(355.00,553.00));
      corners.push_back(convertPt(355.00,560.00));
      corners.push_back(convertPt(342.00,560.00));
      corners.push_back(convertPt(342.00,553.00));
      corners.push_back(convertPt(355.00,553.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(792.00,553.00));
      corners.push_back(convertPt(792.00,575.00));
      corners.push_back(convertPt(831.00,575.00));
      corners.push_back(convertPt(831.00,642.00));
      corners.push_back(convertPt(818.00,642.00));
      corners.push_back(convertPt(818.00,656.00));
      corners.push_back(convertPt(831.00,656.00));
      corners.push_back(convertPt(831.00,708.00));
      corners.push_back(convertPt(818.00,708.00));
      corners.push_back(convertPt(818.00,759.00));
      corners.push_back(convertPt(831.00,759.00));
      corners.push_back(convertPt(831.00,803.00));
      corners.push_back(convertPt(767.00,803.00));
      corners.push_back(convertPt(767.00,797.00));
      corners.push_back(convertPt(780.00,797.00));
      corners.push_back(convertPt(780.00,745.00));
      corners.push_back(convertPt(767.00,745.00));
      corners.push_back(convertPt(767.00,738.00));
      corners.push_back(convertPt(754.00,738.00));
      corners.push_back(convertPt(754.00,730.00));
      corners.push_back(convertPt(767.00,730.00));
      corners.push_back(convertPt(767.00,722.00));
      corners.push_back(convertPt(780.00,722.00));
      corners.push_back(convertPt(780.00,715.00));
      corners.push_back(convertPt(767.00,715.00));
      corners.push_back(convertPt(767.00,671.00));
      corners.push_back(convertPt(754.00,671.00));
      corners.push_back(convertPt(754.00,627.00));
      corners.push_back(convertPt(741.00,627.00));
      corners.push_back(convertPt(741.00,620.00));
      corners.push_back(convertPt(754.00,620.00));
      corners.push_back(convertPt(754.00,627.00));
      corners.push_back(convertPt(780.00,627.00));
      corners.push_back(convertPt(780.00,612.00));
      corners.push_back(convertPt(792.00,612.00));
      corners.push_back(convertPt(792.00,583.00));
      corners.push_back(convertPt(780.00,583.00));
      corners.push_back(convertPt(780.00,553.00));
      corners.push_back(convertPt(792.00,553.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(844.00,553.00));
      corners.push_back(convertPt(844.00,560.00));
      corners.push_back(convertPt(831.00,560.00));
      corners.push_back(convertPt(831.00,553.00));
      corners.push_back(convertPt(844.00,553.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(728.00,560.00));
      corners.push_back(convertPt(728.00,568.00));
      corners.push_back(convertPt(716.00,568.00));
      corners.push_back(convertPt(716.00,560.00));
      corners.push_back(convertPt(728.00,560.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(432.00,568.00));
      corners.push_back(convertPt(432.00,575.00));
      corners.push_back(convertPt(420.00,575.00));
      corners.push_back(convertPt(420.00,568.00));
      corners.push_back(convertPt(432.00,568.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(368.00,575.00));
      corners.push_back(convertPt(368.00,590.00));
      corners.push_back(convertPt(355.00,590.00));
      corners.push_back(convertPt(355.00,597.00));
      corners.push_back(convertPt(330.00,597.00));
      corners.push_back(convertPt(330.00,605.00));
      corners.push_back(convertPt(278.00,605.00));
      corners.push_back(convertPt(278.00,612.00));
      corners.push_back(convertPt(265.00,612.00));
      corners.push_back(convertPt(265.00,590.00));
      corners.push_back(convertPt(278.00,590.00));
      corners.push_back(convertPt(278.00,597.00));
      corners.push_back(convertPt(330.00,597.00));
      corners.push_back(convertPt(330.00,590.00));
      corners.push_back(convertPt(342.00,590.00));
      corners.push_back(convertPt(342.00,583.00));
      corners.push_back(convertPt(355.00,583.00));
      corners.push_back(convertPt(355.00,575.00));
      corners.push_back(convertPt(368.00,575.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(702.00,590.00));
      corners.push_back(convertPt(702.00,597.00));
      corners.push_back(convertPt(689.00,597.00));
      corners.push_back(convertPt(689.00,590.00));
      corners.push_back(convertPt(702.00,590.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(188.00,626.00));
      corners.push_back(convertPt(188.00,635.00));
      corners.push_back(convertPt(176.00,635.00));
      corners.push_back(convertPt(176.00,626.00));
      corners.push_back(convertPt(188.00,626.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(677.00,649.00));
      corners.push_back(convertPt(677.00,656.00));
      corners.push_back(convertPt(664.00,656.00));
      corners.push_back(convertPt(664.00,649.00));
      corners.push_back(convertPt(677.00,649.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(702.00,678.00));
      corners.push_back(convertPt(702.00,686.00));
      corners.push_back(convertPt(690.00,686.00));
      corners.push_back(convertPt(690.00,678.00));
      corners.push_back(convertPt(702.00,678.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,730.00));
      corners.push_back(convertPt(780.00,738.00));
      corners.push_back(convertPt(792.00,738.00));
      corners.push_back(convertPt(792.00,730.00));
      corners.push_back(convertPt(780.00,730.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(792.00,775.00));
      corners.push_back(convertPt(792.00,797.00));
      corners.push_back(convertPt(805.00,797.00));
      corners.push_back(convertPt(805.00,775.00));
      corners.push_back(convertPt(792.00,775.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(754.00,797.00));
      corners.push_back(convertPt(754.00,803.00));
      corners.push_back(convertPt(741.00,803.00));
      corners.push_back(convertPt(741.00,797.00));
      corners.push_back(convertPt(754.00,797.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(4, contoursPointer));

      ///// 0.06pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,116.00));
      corners.push_back(convertPt(869.00,131.00));
      corners.push_back(convertPt(857.00,131.00));
      corners.push_back(convertPt(857.00,138.00));
      corners.push_back(convertPt(844.00,138.00));
      corners.push_back(convertPt(844.00,146.00));
      corners.push_back(convertPt(831.00,146.00));
      corners.push_back(convertPt(831.00,153.00));
      corners.push_back(convertPt(857.00,153.00));
      corners.push_back(convertPt(857.00,160.00));
      corners.push_back(convertPt(869.00,160.00));
      corners.push_back(convertPt(869.00,153.00));
      corners.push_back(convertPt(882.00,153.00));
      corners.push_back(convertPt(882.00,175.00));
      corners.push_back(convertPt(869.00,175.00));
      corners.push_back(convertPt(869.00,212.00));
      corners.push_back(convertPt(882.00,212.00));
      corners.push_back(convertPt(882.00,220.00));
      corners.push_back(convertPt(857.00,220.00));
      corners.push_back(convertPt(857.00,235.00));
      corners.push_back(convertPt(844.00,235.00));
      corners.push_back(convertPt(844.00,271.00));
      corners.push_back(convertPt(831.00,271.00));
      corners.push_back(convertPt(831.00,279.00));
      corners.push_back(convertPt(844.00,279.00));
      corners.push_back(convertPt(844.00,294.00));
      corners.push_back(convertPt(818.00,294.00));
      corners.push_back(convertPt(818.00,309.00));
      corners.push_back(convertPt(831.00,309.00));
      corners.push_back(convertPt(831.00,323.00));
      corners.push_back(convertPt(792.00,323.00));
      corners.push_back(convertPt(792.00,331.00));
      corners.push_back(convertPt(754.00,331.00));
      corners.push_back(convertPt(754.00,338.00));
      corners.push_back(convertPt(728.00,338.00));
      corners.push_back(convertPt(728.00,346.00));
      corners.push_back(convertPt(716.00,346.00));
      corners.push_back(convertPt(716.00,353.00));
      corners.push_back(convertPt(703.00,353.00));
      corners.push_back(convertPt(703.00,367.00));
      corners.push_back(convertPt(677.00,367.00));
      corners.push_back(convertPt(677.00,375.00));
      corners.push_back(convertPt(664.00,375.00));
      corners.push_back(convertPt(664.00,383.00));
      corners.push_back(convertPt(651.00,383.00));
      corners.push_back(convertPt(651.00,390.00));
      corners.push_back(convertPt(638.00,390.00));
      corners.push_back(convertPt(638.00,397.00));
      corners.push_back(convertPt(626.00,397.00));
      corners.push_back(convertPt(626.00,404.00));
      corners.push_back(convertPt(613.00,404.00));
      corners.push_back(convertPt(613.00,412.00));
      corners.push_back(convertPt(587.00,412.00));
      corners.push_back(convertPt(587.00,420.00));
      corners.push_back(convertPt(574.00,420.00));
      corners.push_back(convertPt(574.00,449.00));
      corners.push_back(convertPt(510.00,449.00));
      corners.push_back(convertPt(510.00,456.00));
      corners.push_back(convertPt(484.00,456.00));
      corners.push_back(convertPt(484.00,464.00));
      corners.push_back(convertPt(471.00,464.00));
      corners.push_back(convertPt(471.00,471.00));
      corners.push_back(convertPt(458.00,471.00));
      corners.push_back(convertPt(458.00,479.00));
      corners.push_back(convertPt(447.00,479.00));
      corners.push_back(convertPt(447.00,486.00));
      corners.push_back(convertPt(471.00,486.00));
      corners.push_back(convertPt(471.00,508.00));
      corners.push_back(convertPt(432.00,508.00));
      corners.push_back(convertPt(432.00,501.00));
      corners.push_back(convertPt(420.00,501.00));
      corners.push_back(convertPt(420.00,508.00));
      corners.push_back(convertPt(394.00,508.00));
      corners.push_back(convertPt(394.00,516.00));
      corners.push_back(convertPt(381.00,516.00));
      corners.push_back(convertPt(381.00,524.00));
      corners.push_back(convertPt(368.00,524.00));
      corners.push_back(convertPt(368.00,531.00));
      corners.push_back(convertPt(342.00,531.00));
      corners.push_back(convertPt(342.00,538.00));
      corners.push_back(convertPt(317.00,538.00));
      corners.push_back(convertPt(317.00,553.00));
      corners.push_back(convertPt(304.00,553.00));
      corners.push_back(convertPt(304.00,560.00));
      corners.push_back(convertPt(291.00,560.00));
      corners.push_back(convertPt(291.00,575.00));
      corners.push_back(convertPt(304.00,575.00));
      corners.push_back(convertPt(304.00,582.00));
      corners.push_back(convertPt(329.00,582.00));
      corners.push_back(convertPt(329.00,575.00));
      corners.push_back(convertPt(355.00,575.00));
      corners.push_back(convertPt(355.00,568.00));
      corners.push_back(convertPt(329.00,568.00));
      corners.push_back(convertPt(329.00,546.00));
      corners.push_back(convertPt(368.00,546.00));
      corners.push_back(convertPt(368.00,560.00));
      corners.push_back(convertPt(393.00,560.00));
      corners.push_back(convertPt(393.00,553.00));
      corners.push_back(convertPt(432.00,553.00));
      corners.push_back(convertPt(432.00,560.00));
      corners.push_back(convertPt(573.00,560.00));
      corners.push_back(convertPt(573.00,568.00));
      corners.push_back(convertPt(625.00,568.00));
      corners.push_back(convertPt(625.00,560.00));
      corners.push_back(convertPt(638.00,560.00));
      corners.push_back(convertPt(638.00,568.00));
      corners.push_back(convertPt(690.00,568.00));
      corners.push_back(convertPt(690.00,575.00));
      corners.push_back(convertPt(703.00,575.00));
      corners.push_back(convertPt(703.00,583.00));
      corners.push_back(convertPt(716.00,583.00));
      corners.push_back(convertPt(716.00,597.00));
      corners.push_back(convertPt(728.00,597.00));
      corners.push_back(convertPt(728.00,612.00));
      corners.push_back(convertPt(716.00,612.00));
      corners.push_back(convertPt(716.00,635.00));
      corners.push_back(convertPt(702.00,635.00));
      corners.push_back(convertPt(702.00,627.00));
      corners.push_back(convertPt(664.00,627.00));
      corners.push_back(convertPt(664.00,649.00));
      corners.push_back(convertPt(677.00,649.00));
      corners.push_back(convertPt(677.00,656.00));
      corners.push_back(convertPt(689.00,656.00));
      corners.push_back(convertPt(689.00,671.00));
      corners.push_back(convertPt(677.00,671.00));
      corners.push_back(convertPt(677.00,663.00));
      corners.push_back(convertPt(664.00,663.00));
      corners.push_back(convertPt(664.00,656.00));
      corners.push_back(convertPt(651.00,656.00));
      corners.push_back(convertPt(651.00,612.00));
      corners.push_back(convertPt(638.00,612.00));
      corners.push_back(convertPt(638.00,597.00));
      corners.push_back(convertPt(625.00,597.00));
      corners.push_back(convertPt(625.00,590.00));
      corners.push_back(convertPt(561.00,590.00));
      corners.push_back(convertPt(561.00,583.00));
      corners.push_back(convertPt(458.00,583.00));
      corners.push_back(convertPt(458.00,590.00));
      corners.push_back(convertPt(394.00,590.00));
      corners.push_back(convertPt(394.00,597.00));
      corners.push_back(convertPt(382.00,597.00));
      corners.push_back(convertPt(382.00,605.00));
      corners.push_back(convertPt(368.00,605.00));
      corners.push_back(convertPt(368.00,612.00));
      corners.push_back(convertPt(342.00,612.00));
      corners.push_back(convertPt(342.00,620.00));
      corners.push_back(convertPt(317.00,620.00));
      corners.push_back(convertPt(317.00,627.00));
      corners.push_back(convertPt(278.00,627.00));
      corners.push_back(convertPt(278.00,635.00));
      corners.push_back(convertPt(253.00,635.00));
      corners.push_back(convertPt(253.00,627.00));
      corners.push_back(convertPt(226.00,627.00));
      corners.push_back(convertPt(226.00,568.00));
      corners.push_back(convertPt(214.00,568.00));
      corners.push_back(convertPt(214.00,590.00));
      corners.push_back(convertPt(188.00,590.00));
      corners.push_back(convertPt(188.00,597.00));
      corners.push_back(convertPt(176.00,597.00));
      corners.push_back(convertPt(176.00,494.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(188.00,486.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(201.00,479.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(214.00,472.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(226.00,464.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(240.00,456.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(253.00,449.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(265.00,442.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(278.00,434.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(291.00,427.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(304.00,419.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(317.00,412.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(330.00,404.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(343.00,397.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(355.00,390.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(368.00,383.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(382.00,376.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(394.00,368.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(407.00,360.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(420.00,353.00));
      corners.push_back(convertPt(432.00,353.00));
      corners.push_back(convertPt(432.00,346.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(446.00,338.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(458.00,331.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(471.00,324.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(484.00,316.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(497.00,309.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(510.00,301.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(522.00,294.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(535.00,287.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(549.00,280.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(561.00,272.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(574.00,264.00));
      corners.push_back(convertPt(587.00,264.00));
      corners.push_back(convertPt(587.00,257.00));
      corners.push_back(convertPt(599.00,257.00));
      corners.push_back(convertPt(599.00,250.00));
      corners.push_back(convertPt(613.00,250.00));
      corners.push_back(convertPt(613.00,242.00));
      corners.push_back(convertPt(626.00,242.00));
      corners.push_back(convertPt(626.00,235.00));
      corners.push_back(convertPt(639.00,235.00));
      corners.push_back(convertPt(639.00,228.00));
      corners.push_back(convertPt(651.00,228.00));
      corners.push_back(convertPt(651.00,220.00));
      corners.push_back(convertPt(677.00,220.00));
      corners.push_back(convertPt(677.00,212.00));
      corners.push_back(convertPt(689.00,212.00));
      corners.push_back(convertPt(689.00,205.00));
      corners.push_back(convertPt(702.00,205.00));
      corners.push_back(convertPt(702.00,198.00));
      corners.push_back(convertPt(716.00,198.00));
      corners.push_back(convertPt(716.00,190.00));
      corners.push_back(convertPt(728.00,190.00));
      corners.push_back(convertPt(728.00,183.00));
      corners.push_back(convertPt(741.00,183.00));
      corners.push_back(convertPt(741.00,175.00));
      corners.push_back(convertPt(754.00,175.00));
      corners.push_back(convertPt(754.00,168.00));
      corners.push_back(convertPt(767.00,168.00));
      corners.push_back(convertPt(767.00,160.00));
      corners.push_back(convertPt(780.00,160.00));
      corners.push_back(convertPt(780.00,153.00));
      corners.push_back(convertPt(792.00,153.00));
      corners.push_back(convertPt(792.00,146.00));
      corners.push_back(convertPt(818.00,146.00));
      corners.push_back(convertPt(818.00,138.00));
      corners.push_back(convertPt(831.00,138.00));
      corners.push_back(convertPt(831.00,131.00));
      corners.push_back(convertPt(844.00,131.00));
      corners.push_back(convertPt(844.00,124.00));
      corners.push_back(convertPt(857.00,124.00));
      corners.push_back(convertPt(857.00,116.00));
      corners.push_back(convertPt(869.00,116.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(844.00,160.00));
      corners.push_back(convertPt(844.00,168.00));
      corners.push_back(convertPt(857.00,168.00));
      corners.push_back(convertPt(857.00,160.00));
      corners.push_back(convertPt(844.00,160.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(908.00,331.00));
      corners.push_back(convertPt(908.00,338.00));
      corners.push_back(convertPt(895.00,338.00));
      corners.push_back(convertPt(895.00,331.00));
      corners.push_back(convertPt(908.00,331.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(754.00,353.00));
      corners.push_back(convertPt(754.00,360.00));
      corners.push_back(convertPt(741.00,360.00));
      corners.push_back(convertPt(741.00,353.00));
      corners.push_back(convertPt(754.00,353.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,353.00));
      corners.push_back(convertPt(780.00,360.00));
      corners.push_back(convertPt(767.00,360.00));
      corners.push_back(convertPt(767.00,353.00));
      corners.push_back(convertPt(780.00,353.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(895.00,353.00));
      corners.push_back(convertPt(895.00,383.00));
      corners.push_back(convertPt(908.00,383.00));
      corners.push_back(convertPt(908.00,531.00));
      corners.push_back(convertPt(895.00,531.00));
      corners.push_back(convertPt(895.00,501.00));
      corners.push_back(convertPt(882.00,501.00));
      corners.push_back(convertPt(882.00,516.00));
      corners.push_back(convertPt(869.00,516.00));
      corners.push_back(convertPt(869.00,560.00));
      corners.push_back(convertPt(857.00,560.00));
      corners.push_back(convertPt(857.00,575.00));
      corners.push_back(convertPt(844.00,575.00));
      corners.push_back(convertPt(844.00,605.00));
      corners.push_back(convertPt(857.00,605.00));
      corners.push_back(convertPt(857.00,723.00));
      corners.push_back(convertPt(869.00,723.00));
      corners.push_back(convertPt(869.00,738.00));
      corners.push_back(convertPt(857.00,738.00));
      corners.push_back(convertPt(857.00,723.00));
      corners.push_back(convertPt(844.00,723.00));
      corners.push_back(convertPt(844.00,752.00));
      corners.push_back(convertPt(857.00,752.00));
      corners.push_back(convertPt(857.00,745.00));
      corners.push_back(convertPt(869.00,745.00));
      corners.push_back(convertPt(869.00,803.00));
      corners.push_back(convertPt(857.00,803.00));
      corners.push_back(convertPt(857.00,775.00));
      corners.push_back(convertPt(844.00,775.00));
      corners.push_back(convertPt(844.00,803.00));
      corners.push_back(convertPt(728.00,803.00));
      corners.push_back(convertPt(728.00,730.00));
      corners.push_back(convertPt(741.00,730.00));
      corners.push_back(convertPt(741.00,686.00));
      corners.push_back(convertPt(754.00,686.00));
      corners.push_back(convertPt(754.00,663.00));
      corners.push_back(convertPt(741.00,663.00));
      corners.push_back(convertPt(741.00,649.00));
      corners.push_back(convertPt(754.00,649.00));
      corners.push_back(convertPt(754.00,642.00));
      corners.push_back(convertPt(741.00,642.00));
      corners.push_back(convertPt(741.00,620.00));
      corners.push_back(convertPt(766.00,620.00));
      corners.push_back(convertPt(766.00,597.00));
      corners.push_back(convertPt(780.00,597.00));
      corners.push_back(convertPt(780.00,575.00));
      corners.push_back(convertPt(766.00,575.00));
      corners.push_back(convertPt(766.00,568.00));
      corners.push_back(convertPt(780.00,568.00));
      corners.push_back(convertPt(780.00,553.00));
      corners.push_back(convertPt(766.00,553.00));
      corners.push_back(convertPt(766.00,546.00));
      corners.push_back(convertPt(780.00,546.00));
      corners.push_back(convertPt(780.00,553.00));
      corners.push_back(convertPt(792.00,553.00));
      corners.push_back(convertPt(792.00,538.00));
      corners.push_back(convertPt(805.00,538.00));
      corners.push_back(convertPt(805.00,531.00));
      corners.push_back(convertPt(792.00,531.00));
      corners.push_back(convertPt(792.00,516.00));
      corners.push_back(convertPt(805.00,516.00));
      corners.push_back(convertPt(805.00,494.00));
      corners.push_back(convertPt(818.00,494.00));
      corners.push_back(convertPt(818.00,486.00));
      corners.push_back(convertPt(831.00,486.00));
      corners.push_back(convertPt(831.00,479.00));
      corners.push_back(convertPt(818.00,479.00));
      corners.push_back(convertPt(818.00,464.00));
      corners.push_back(convertPt(831.00,464.00));
      corners.push_back(convertPt(831.00,442.00));
      corners.push_back(convertPt(818.00,442.00));
      corners.push_back(convertPt(818.00,449.00));
      corners.push_back(convertPt(806.00,449.00));
      corners.push_back(convertPt(806.00,442.00));
      corners.push_back(convertPt(767.00,442.00));
      corners.push_back(convertPt(767.00,412.00));
      corners.push_back(convertPt(754.00,412.00));
      corners.push_back(convertPt(754.00,404.00));
      corners.push_back(convertPt(780.00,404.00));
      corners.push_back(convertPt(780.00,397.00));
      corners.push_back(convertPt(792.00,397.00));
      corners.push_back(convertPt(792.00,404.00));
      corners.push_back(convertPt(805.00,404.00));
      corners.push_back(convertPt(805.00,397.00));
      corners.push_back(convertPt(831.00,397.00));
      corners.push_back(convertPt(831.00,434.00));
      corners.push_back(convertPt(844.00,434.00));
      corners.push_back(convertPt(844.00,412.00));
      corners.push_back(convertPt(857.00,412.00));
      corners.push_back(convertPt(857.00,390.00));
      corners.push_back(convertPt(869.00,390.00));
      corners.push_back(convertPt(869.00,367.00));
      corners.push_back(convertPt(882.00,367.00));
      corners.push_back(convertPt(882.00,353.00));
      corners.push_back(convertPt(895.00,353.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(703.00,383.00));
      corners.push_back(convertPt(703.00,390.00));
      corners.push_back(convertPt(690.00,390.00));
      corners.push_back(convertPt(690.00,383.00));
      corners.push_back(convertPt(703.00,383.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(703.00,426.00));
      corners.push_back(convertPt(703.00,434.00));
      corners.push_back(convertPt(689.00,434.00));
      corners.push_back(convertPt(689.00,426.00));
      corners.push_back(convertPt(703.00,426.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(573.00,486.00));
      corners.push_back(convertPt(573.00,494.00));
      corners.push_back(convertPt(561.00,494.00));
      corners.push_back(convertPt(561.00,501.00));
      corners.push_back(convertPt(549.00,501.00));
      corners.push_back(convertPt(549.00,508.00));
      corners.push_back(convertPt(535.00,508.00));
      corners.push_back(convertPt(535.00,501.00));
      corners.push_back(convertPt(549.00,501.00));
      corners.push_back(convertPt(549.00,494.00));
      corners.push_back(convertPt(561.00,494.00));
      corners.push_back(convertPt(561.00,486.00));
      corners.push_back(convertPt(573.00,486.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(677.00,486.00));
      corners.push_back(convertPt(677.00,494.00));
      corners.push_back(convertPt(664.00,494.00));
      corners.push_back(convertPt(664.00,486.00));
      corners.push_back(convertPt(677.00,486.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(754.00,486.00));
      corners.push_back(convertPt(754.00,494.00));
      corners.push_back(convertPt(741.00,494.00));
      corners.push_back(convertPt(741.00,486.00));
      corners.push_back(convertPt(754.00,486.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(728.00,516.00));
      corners.push_back(convertPt(728.00,523.00));
      corners.push_back(convertPt(716.00,523.00));
      corners.push_back(convertPt(716.00,516.00));
      corners.push_back(convertPt(728.00,516.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(613.00,523.00));
      corners.push_back(convertPt(613.00,531.00));
      corners.push_back(convertPt(599.00,531.00));
      corners.push_back(convertPt(599.00,523.00));
      corners.push_back(convertPt(613.00,523.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(677.00,531.00));
      corners.push_back(convertPt(677.00,538.00));
      corners.push_back(convertPt(664.00,538.00));
      corners.push_back(convertPt(664.00,531.00));
      corners.push_back(convertPt(677.00,531.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(703.00,546.00));
      corners.push_back(convertPt(703.00,553.00));
      corners.push_back(convertPt(690.00,553.00));
      corners.push_back(convertPt(690.00,546.00));
      corners.push_back(convertPt(703.00,546.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(728.00,546.00));
      corners.push_back(convertPt(728.00,553.00));
      corners.push_back(convertPt(716.00,553.00));
      corners.push_back(convertPt(716.00,546.00));
      corners.push_back(convertPt(728.00,546.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(844.00,553.00));
      corners.push_back(convertPt(844.00,560.00));
      corners.push_back(convertPt(857.00,560.00));
      corners.push_back(convertPt(857.00,553.00));
      corners.push_back(convertPt(844.00,553.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(728.00,560.00));
      corners.push_back(convertPt(728.00,568.00));
      corners.push_back(convertPt(716.00,568.00));
      corners.push_back(convertPt(716.00,560.00));
      corners.push_back(convertPt(728.00,560.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(201.00,605.00));
      corners.push_back(convertPt(201.00,612.00));
      corners.push_back(convertPt(214.00,612.00));
      corners.push_back(convertPt(214.00,649.00));
      corners.push_back(convertPt(201.00,649.00));
      corners.push_back(convertPt(201.00,656.00));
      corners.push_back(convertPt(176.00,656.00));
      corners.push_back(convertPt(176.00,605.00));
      corners.push_back(convertPt(201.00,605.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(573.00,635.00));
      corners.push_back(convertPt(573.00,642.00));
      corners.push_back(convertPt(561.00,642.00));
      corners.push_back(convertPt(561.00,649.00));
      corners.push_back(convertPt(549.00,649.00));
      corners.push_back(convertPt(549.00,656.00));
      corners.push_back(convertPt(535.00,656.00));
      corners.push_back(convertPt(535.00,649.00));
      corners.push_back(convertPt(549.00,649.00));
      corners.push_back(convertPt(549.00,642.00));
      corners.push_back(convertPt(561.00,642.00));
      corners.push_back(convertPt(561.00,635.00));
      corners.push_back(convertPt(573.00,635.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(626.00,663.00));
      corners.push_back(convertPt(626.00,671.00));
      corners.push_back(convertPt(613.00,671.00));
      corners.push_back(convertPt(613.00,679.00));
      corners.push_back(convertPt(599.00,679.00));
      corners.push_back(convertPt(599.00,686.00));
      corners.push_back(convertPt(587.00,686.00));
      corners.push_back(convertPt(587.00,679.00));
      corners.push_back(convertPt(599.00,679.00));
      corners.push_back(convertPt(599.00,671.00));
      corners.push_back(convertPt(613.00,671.00));
      corners.push_back(convertPt(613.00,663.00));
      corners.push_back(convertPt(626.00,663.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(702.00,678.00));
      corners.push_back(convertPt(702.00,686.00));
      corners.push_back(convertPt(690.00,686.00));
      corners.push_back(convertPt(690.00,678.00));
      corners.push_back(convertPt(702.00,678.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(317.00,693.00));
      corners.push_back(convertPt(317.00,701.00));
      corners.push_back(convertPt(304.00,701.00));
      corners.push_back(convertPt(304.00,715.00));
      corners.push_back(convertPt(278.00,715.00));
      corners.push_back(convertPt(278.00,701.00));
      corners.push_back(convertPt(304.00,701.00));
      corners.push_back(convertPt(304.00,693.00));
      corners.push_back(convertPt(317.00,693.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(626.00,693.00));
      corners.push_back(convertPt(626.00,701.00));
      corners.push_back(convertPt(613.00,701.00));
      corners.push_back(convertPt(613.00,708.00));
      corners.push_back(convertPt(599.00,708.00));
      corners.push_back(convertPt(599.00,716.00));
      corners.push_back(convertPt(587.00,716.00));
      corners.push_back(convertPt(587.00,708.00));
      corners.push_back(convertPt(599.00,708.00));
      corners.push_back(convertPt(599.00,701.00));
      corners.push_back(convertPt(613.00,701.00));
      corners.push_back(convertPt(613.00,693.00));
      corners.push_back(convertPt(626.00,693.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(702.00,723.00));
      corners.push_back(convertPt(702.00,730.00));
      corners.push_back(convertPt(689.00,730.00));
      corners.push_back(convertPt(689.00,723.00));
      corners.push_back(convertPt(702.00,723.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(5, contoursPointer));

      ///// 0.07pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,116.00));
      corners.push_back(convertPt(869.00,131.00));
      corners.push_back(convertPt(857.00,131.00));
      corners.push_back(convertPt(857.00,138.00));
      corners.push_back(convertPt(844.00,138.00));
      corners.push_back(convertPt(844.00,146.00));
      corners.push_back(convertPt(857.00,146.00));
      corners.push_back(convertPt(857.00,160.00));
      corners.push_back(convertPt(869.00,160.00));
      corners.push_back(convertPt(869.00,153.00));
      corners.push_back(convertPt(882.00,153.00));
      corners.push_back(convertPt(882.00,146.00));
      corners.push_back(convertPt(895.00,146.00));
      corners.push_back(convertPt(895.00,168.00));
      corners.push_back(convertPt(882.00,168.00));
      corners.push_back(convertPt(882.00,212.00));
      corners.push_back(convertPt(895.00,212.00));
      corners.push_back(convertPt(895.00,220.00));
      corners.push_back(convertPt(869.00,220.00));
      corners.push_back(convertPt(869.00,235.00));
      corners.push_back(convertPt(857.00,235.00));
      corners.push_back(convertPt(857.00,264.00));
      corners.push_back(convertPt(869.00,264.00));
      corners.push_back(convertPt(869.00,271.00));
      corners.push_back(convertPt(857.00,271.00));
      corners.push_back(convertPt(857.00,294.00));
      corners.push_back(convertPt(844.00,294.00));
      corners.push_back(convertPt(844.00,323.00));
      corners.push_back(convertPt(831.00,323.00));
      corners.push_back(convertPt(831.00,338.00));
      corners.push_back(convertPt(818.00,338.00));
      corners.push_back(convertPt(818.00,360.00));
      corners.push_back(convertPt(831.00,360.00));
      corners.push_back(convertPt(831.00,368.00));
      corners.push_back(convertPt(844.00,368.00));
      corners.push_back(convertPt(844.00,376.00));
      corners.push_back(convertPt(857.00,376.00));
      corners.push_back(convertPt(857.00,390.00));
      corners.push_back(convertPt(869.00,390.00));
      corners.push_back(convertPt(869.00,367.00));
      corners.push_back(convertPt(882.00,367.00));
      corners.push_back(convertPt(882.00,353.00));
      corners.push_back(convertPt(895.00,353.00));
      corners.push_back(convertPt(895.00,323.00));
      corners.push_back(convertPt(908.00,323.00));
      corners.push_back(convertPt(908.00,353.00));
      corners.push_back(convertPt(895.00,353.00));
      corners.push_back(convertPt(895.00,360.00));
      corners.push_back(convertPt(908.00,360.00));
      corners.push_back(convertPt(908.00,531.00));
      corners.push_back(convertPt(895.00,531.00));
      corners.push_back(convertPt(895.00,516.00));
      corners.push_back(convertPt(882.00,516.00));
      corners.push_back(convertPt(882.00,583.00));
      corners.push_back(convertPt(870.00,583.00));
      corners.push_back(convertPt(870.00,708.00));
      corners.push_back(convertPt(882.00,708.00));
      corners.push_back(convertPt(882.00,803.00));
      corners.push_back(convertPt(716.00,803.00));
      corners.push_back(convertPt(716.00,716.00));
      corners.push_back(convertPt(677.00,716.00));
      corners.push_back(convertPt(677.00,701.00));
      corners.push_back(convertPt(664.00,701.00));
      corners.push_back(convertPt(664.00,678.00));
      corners.push_back(convertPt(651.00,678.00));
      corners.push_back(convertPt(651.00,686.00));
      corners.push_back(convertPt(613.00,686.00));
      corners.push_back(convertPt(613.00,693.00));
      corners.push_back(convertPt(626.00,693.00));
      corners.push_back(convertPt(626.00,716.00));
      corners.push_back(convertPt(638.00,716.00));
      corners.push_back(convertPt(638.00,752.00));
      corners.push_back(convertPt(625.00,752.00));
      corners.push_back(convertPt(625.00,767.00));
      corners.push_back(convertPt(613.00,767.00));
      corners.push_back(convertPt(613.00,759.00));
      corners.push_back(convertPt(587.00,759.00));
      corners.push_back(convertPt(587.00,752.00));
      corners.push_back(convertPt(574.00,752.00));
      corners.push_back(convertPt(574.00,745.00));
      corners.push_back(convertPt(587.00,745.00));
      corners.push_back(convertPt(587.00,738.00));
      corners.push_back(convertPt(613.00,738.00));
      corners.push_back(convertPt(613.00,723.00));
      corners.push_back(convertPt(626.00,723.00));
      corners.push_back(convertPt(626.00,716.00));
      corners.push_back(convertPt(587.00,716.00));
      corners.push_back(convertPt(587.00,693.00));
      corners.push_back(convertPt(561.00,693.00));
      corners.push_back(convertPt(561.00,686.00));
      corners.push_back(convertPt(587.00,686.00));
      corners.push_back(convertPt(587.00,664.00));
      corners.push_back(convertPt(613.00,664.00));
      corners.push_back(convertPt(613.00,656.00));
      corners.push_back(convertPt(599.00,656.00));
      corners.push_back(convertPt(599.00,649.00));
      corners.push_back(convertPt(587.00,649.00));
      corners.push_back(convertPt(587.00,642.00));
      corners.push_back(convertPt(573.00,642.00));
      corners.push_back(convertPt(573.00,656.00));
      corners.push_back(convertPt(535.00,656.00));
      corners.push_back(convertPt(535.00,635.00));
      corners.push_back(convertPt(561.00,635.00));
      corners.push_back(convertPt(561.00,627.00));
      corners.push_back(convertPt(549.00,627.00));
      corners.push_back(convertPt(549.00,619.00));
      corners.push_back(convertPt(535.00,619.00));
      corners.push_back(convertPt(535.00,612.00));
      corners.push_back(convertPt(458.00,612.00));
      corners.push_back(convertPt(458.00,619.00));
      corners.push_back(convertPt(445.00,619.00));
      corners.push_back(convertPt(445.00,626.00));
      corners.push_back(convertPt(432.00,626.00));
      corners.push_back(convertPt(432.00,656.00));
      corners.push_back(convertPt(420.00,656.00));
      corners.push_back(convertPt(420.00,663.00));
      corners.push_back(convertPt(406.00,663.00));
      corners.push_back(convertPt(406.00,671.00));
      corners.push_back(convertPt(393.00,671.00));
      corners.push_back(convertPt(393.00,678.00));
      corners.push_back(convertPt(368.00,678.00));
      corners.push_back(convertPt(368.00,686.00));
      corners.push_back(convertPt(342.00,686.00));
      corners.push_back(convertPt(342.00,693.00));
      corners.push_back(convertPt(355.00,693.00));
      corners.push_back(convertPt(355.00,708.00));
      corners.push_back(convertPt(368.00,708.00));
      corners.push_back(convertPt(368.00,716.00));
      corners.push_back(convertPt(381.00,716.00));
      corners.push_back(convertPt(381.00,745.00));
      corners.push_back(convertPt(368.00,745.00));
      corners.push_back(convertPt(368.00,752.00));
      corners.push_back(convertPt(381.00,752.00));
      corners.push_back(convertPt(381.00,759.00));
      corners.push_back(convertPt(393.00,759.00));
      corners.push_back(convertPt(393.00,803.00));
      corners.push_back(convertPt(176.00,803.00));
      corners.push_back(convertPt(176.00,494.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(188.00,486.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(201.00,479.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(214.00,472.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(226.00,464.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(240.00,456.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(253.00,449.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(265.00,442.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(278.00,434.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(291.00,427.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(304.00,419.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(317.00,412.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(330.00,404.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(343.00,397.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(355.00,390.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(368.00,383.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(382.00,376.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(394.00,368.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(407.00,360.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(420.00,353.00));
      corners.push_back(convertPt(432.00,353.00));
      corners.push_back(convertPt(432.00,346.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(446.00,338.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(458.00,331.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(471.00,324.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(484.00,316.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(497.00,309.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(510.00,301.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(522.00,294.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(535.00,287.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(549.00,280.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(561.00,272.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(574.00,264.00));
      corners.push_back(convertPt(587.00,264.00));
      corners.push_back(convertPt(587.00,257.00));
      corners.push_back(convertPt(599.00,257.00));
      corners.push_back(convertPt(599.00,250.00));
      corners.push_back(convertPt(613.00,250.00));
      corners.push_back(convertPt(613.00,242.00));
      corners.push_back(convertPt(626.00,242.00));
      corners.push_back(convertPt(626.00,235.00));
      corners.push_back(convertPt(639.00,235.00));
      corners.push_back(convertPt(639.00,228.00));
      corners.push_back(convertPt(651.00,228.00));
      corners.push_back(convertPt(651.00,220.00));
      corners.push_back(convertPt(664.00,220.00));
      corners.push_back(convertPt(664.00,212.00));
      corners.push_back(convertPt(677.00,212.00));
      corners.push_back(convertPt(677.00,205.00));
      corners.push_back(convertPt(689.00,205.00));
      corners.push_back(convertPt(689.00,198.00));
      corners.push_back(convertPt(716.00,198.00));
      corners.push_back(convertPt(716.00,190.00));
      corners.push_back(convertPt(728.00,190.00));
      corners.push_back(convertPt(728.00,183.00));
      corners.push_back(convertPt(741.00,183.00));
      corners.push_back(convertPt(741.00,175.00));
      corners.push_back(convertPt(754.00,175.00));
      corners.push_back(convertPt(754.00,168.00));
      corners.push_back(convertPt(767.00,168.00));
      corners.push_back(convertPt(767.00,160.00));
      corners.push_back(convertPt(780.00,160.00));
      corners.push_back(convertPt(780.00,153.00));
      corners.push_back(convertPt(792.00,153.00));
      corners.push_back(convertPt(792.00,146.00));
      corners.push_back(convertPt(805.00,146.00));
      corners.push_back(convertPt(805.00,138.00));
      corners.push_back(convertPt(818.00,138.00));
      corners.push_back(convertPt(818.00,131.00));
      corners.push_back(convertPt(844.00,131.00));
      corners.push_back(convertPt(844.00,124.00));
      corners.push_back(convertPt(857.00,124.00));
      corners.push_back(convertPt(857.00,116.00));
      corners.push_back(convertPt(869.00,116.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(908.00,116.00));
      corners.push_back(convertPt(908.00,124.00));
      corners.push_back(convertPt(895.00,124.00));
      corners.push_back(convertPt(895.00,116.00));
      corners.push_back(convertPt(908.00,116.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(882.00,323.00));
      corners.push_back(convertPt(882.00,331.00));
      corners.push_back(convertPt(869.00,331.00));
      corners.push_back(convertPt(869.00,323.00));
      corners.push_back(convertPt(882.00,323.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(728.00,360.00));
      corners.push_back(convertPt(728.00,375.00));
      corners.push_back(convertPt(703.00,375.00));
      corners.push_back(convertPt(703.00,390.00));
      corners.push_back(convertPt(677.00,390.00));
      corners.push_back(convertPt(677.00,404.00));
      corners.push_back(convertPt(664.00,404.00));
      corners.push_back(convertPt(664.00,434.00));
      corners.push_back(convertPt(677.00,434.00));
      corners.push_back(convertPt(677.00,442.00));
      corners.push_back(convertPt(626.00,442.00));
      corners.push_back(convertPt(626.00,434.00));
      corners.push_back(convertPt(613.00,434.00));
      corners.push_back(convertPt(613.00,449.00));
      corners.push_back(convertPt(599.00,449.00));
      corners.push_back(convertPt(599.00,471.00));
      corners.push_back(convertPt(613.00,471.00));
      corners.push_back(convertPt(613.00,478.00));
      corners.push_back(convertPt(626.00,478.00));
      corners.push_back(convertPt(626.00,486.00));
      corners.push_back(convertPt(587.00,486.00));
      corners.push_back(convertPt(587.00,494.00));
      corners.push_back(convertPt(573.00,494.00));
      corners.push_back(convertPt(573.00,508.00));
      corners.push_back(convertPt(549.00,508.00));
      corners.push_back(convertPt(549.00,516.00));
      corners.push_back(convertPt(535.00,516.00));
      corners.push_back(convertPt(535.00,530.00));
      corners.push_back(convertPt(522.00,530.00));
      corners.push_back(convertPt(522.00,538.00));
      corners.push_back(convertPt(445.00,538.00));
      corners.push_back(convertPt(445.00,546.00));
      corners.push_back(convertPt(561.00,546.00));
      corners.push_back(convertPt(561.00,553.00));
      corners.push_back(convertPt(599.00,553.00));
      corners.push_back(convertPt(599.00,546.00));
      corners.push_back(convertPt(651.00,546.00));
      corners.push_back(convertPt(651.00,531.00));
      corners.push_back(convertPt(677.00,531.00));
      corners.push_back(convertPt(677.00,546.00));
      corners.push_back(convertPt(690.00,546.00));
      corners.push_back(convertPt(690.00,523.00));
      corners.push_back(convertPt(716.00,523.00));
      corners.push_back(convertPt(716.00,516.00));
      corners.push_back(convertPt(728.00,516.00));
      corners.push_back(convertPt(728.00,523.00));
      corners.push_back(convertPt(716.00,523.00));
      corners.push_back(convertPt(716.00,531.00));
      corners.push_back(convertPt(728.00,531.00));
      corners.push_back(convertPt(728.00,546.00));
      corners.push_back(convertPt(741.00,546.00));
      corners.push_back(convertPt(741.00,568.00));
      corners.push_back(convertPt(754.00,568.00));
      corners.push_back(convertPt(754.00,576.00));
      corners.push_back(convertPt(741.00,576.00));
      corners.push_back(convertPt(741.00,590.00));
      corners.push_back(convertPt(754.00,590.00));
      corners.push_back(convertPt(754.00,597.00));
      corners.push_back(convertPt(766.00,597.00));
      corners.push_back(convertPt(766.00,546.00));
      corners.push_back(convertPt(792.00,546.00));
      corners.push_back(convertPt(792.00,508.00));
      corners.push_back(convertPt(805.00,508.00));
      corners.push_back(convertPt(805.00,494.00));
      corners.push_back(convertPt(818.00,494.00));
      corners.push_back(convertPt(818.00,456.00));
      corners.push_back(convertPt(831.00,456.00));
      corners.push_back(convertPt(831.00,449.00));
      corners.push_back(convertPt(780.00,449.00));
      corners.push_back(convertPt(780.00,442.00));
      corners.push_back(convertPt(754.00,442.00));
      corners.push_back(convertPt(754.00,434.00));
      corners.push_back(convertPt(741.00,434.00));
      corners.push_back(convertPt(741.00,426.00));
      corners.push_back(convertPt(703.00,426.00));
      corners.push_back(convertPt(703.00,434.00));
      corners.push_back(convertPt(689.00,434.00));
      corners.push_back(convertPt(689.00,412.00));
      corners.push_back(convertPt(703.00,412.00));
      corners.push_back(convertPt(703.00,397.00));
      corners.push_back(convertPt(716.00,397.00));
      corners.push_back(convertPt(716.00,390.00));
      corners.push_back(convertPt(728.00,390.00));
      corners.push_back(convertPt(728.00,383.00));
      corners.push_back(convertPt(754.00,383.00));
      corners.push_back(convertPt(754.00,375.00));
      corners.push_back(convertPt(741.00,375.00));
      corners.push_back(convertPt(741.00,360.00));
      corners.push_back(convertPt(728.00,360.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(792.00,367.00));
      corners.push_back(convertPt(792.00,376.00));
      corners.push_back(convertPt(806.00,376.00));
      corners.push_back(convertPt(806.00,367.00));
      corners.push_back(convertPt(792.00,367.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(844.00,390.00));
      corners.push_back(convertPt(844.00,412.00));
      corners.push_back(convertPt(857.00,412.00));
      corners.push_back(convertPt(857.00,390.00));
      corners.push_back(convertPt(844.00,390.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(651.00,456.00));
      corners.push_back(convertPt(651.00,464.00));
      corners.push_back(convertPt(639.00,464.00));
      corners.push_back(convertPt(639.00,456.00));
      corners.push_back(convertPt(651.00,456.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,456.00));
      corners.push_back(convertPt(780.00,464.00));
      corners.push_back(convertPt(767.00,464.00));
      corners.push_back(convertPt(767.00,456.00));
      corners.push_back(convertPt(780.00,456.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(522.00,478.00));
      corners.push_back(convertPt(522.00,486.00));
      corners.push_back(convertPt(535.00,486.00));
      corners.push_back(convertPt(535.00,478.00));
      corners.push_back(convertPt(522.00,478.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(766.00,479.00));
      corners.push_back(convertPt(766.00,501.00));
      corners.push_back(convertPt(754.00,501.00));
      corners.push_back(convertPt(754.00,494.00));
      corners.push_back(convertPt(716.00,494.00));
      corners.push_back(convertPt(716.00,486.00));
      corners.push_back(convertPt(703.00,486.00));
      corners.push_back(convertPt(703.00,494.00));
      corners.push_back(convertPt(664.00,494.00));
      corners.push_back(convertPt(664.00,479.00));
      corners.push_back(convertPt(766.00,479.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(638.00,494.00));
      corners.push_back(convertPt(638.00,501.00));
      corners.push_back(convertPt(626.00,501.00));
      corners.push_back(convertPt(626.00,494.00));
      corners.push_back(convertPt(638.00,494.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(626.00,516.00));
      corners.push_back(convertPt(626.00,538.00));
      corners.push_back(convertPt(587.00,538.00));
      corners.push_back(convertPt(587.00,523.00));
      corners.push_back(convertPt(599.00,523.00));
      corners.push_back(convertPt(599.00,516.00));
      corners.push_back(convertPt(626.00,516.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(703.00,553.00));
      corners.push_back(convertPt(703.00,560.00));
      corners.push_back(convertPt(716.00,560.00));
      corners.push_back(convertPt(716.00,553.00));
      corners.push_back(convertPt(703.00,553.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(895.00,605.00));
      corners.push_back(convertPt(895.00,619.00));
      corners.push_back(convertPt(882.00,619.00));
      corners.push_back(convertPt(882.00,605.00));
      corners.push_back(convertPt(895.00,605.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(728.00,635.00));
      corners.push_back(convertPt(728.00,642.00));
      corners.push_back(convertPt(716.00,642.00));
      corners.push_back(convertPt(716.00,656.00));
      corners.push_back(convertPt(728.00,656.00));
      corners.push_back(convertPt(728.00,679.00));
      corners.push_back(convertPt(741.00,679.00));
      corners.push_back(convertPt(741.00,635.00));
      corners.push_back(convertPt(728.00,635.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(702.00,723.00));
      corners.push_back(convertPt(702.00,738.00));
      corners.push_back(convertPt(689.00,738.00));
      corners.push_back(convertPt(689.00,745.00));
      corners.push_back(convertPt(677.00,745.00));
      corners.push_back(convertPt(677.00,723.00));
      corners.push_back(convertPt(702.00,723.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(689.00,759.00));
      corners.push_back(convertPt(689.00,790.00));
      corners.push_back(convertPt(677.00,790.00));
      corners.push_back(convertPt(677.00,759.00));
      corners.push_back(convertPt(689.00,759.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(638.00,775.00));
      corners.push_back(convertPt(638.00,797.00));
      corners.push_back(convertPt(626.00,797.00));
      corners.push_back(convertPt(626.00,775.00));
      corners.push_back(convertPt(638.00,775.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(689.00,797.00));
      corners.push_back(convertPt(689.00,803.00));
      corners.push_back(convertPt(677.00,803.00));
      corners.push_back(convertPt(677.00,797.00));
      corners.push_back(convertPt(689.00,797.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(6, contoursPointer));

      ///// 0.08pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,116.00));
      corners.push_back(convertPt(869.00,131.00));
      corners.push_back(convertPt(857.00,131.00));
      corners.push_back(convertPt(857.00,146.00));
      corners.push_back(convertPt(869.00,146.00));
      corners.push_back(convertPt(869.00,153.00));
      corners.push_back(convertPt(882.00,153.00));
      corners.push_back(convertPt(882.00,146.00));
      corners.push_back(convertPt(895.00,146.00));
      corners.push_back(convertPt(895.00,160.00));
      corners.push_back(convertPt(908.00,160.00));
      corners.push_back(convertPt(908.00,168.00));
      corners.push_back(convertPt(895.00,168.00));
      corners.push_back(convertPt(895.00,220.00));
      corners.push_back(convertPt(882.00,220.00));
      corners.push_back(convertPt(882.00,235.00));
      corners.push_back(convertPt(869.00,235.00));
      corners.push_back(convertPt(869.00,294.00));
      corners.push_back(convertPt(857.00,294.00));
      corners.push_back(convertPt(857.00,323.00));
      corners.push_back(convertPt(844.00,323.00));
      corners.push_back(convertPt(844.00,338.00));
      corners.push_back(convertPt(831.00,338.00));
      corners.push_back(convertPt(831.00,360.00));
      corners.push_back(convertPt(857.00,360.00));
      corners.push_back(convertPt(857.00,390.00));
      corners.push_back(convertPt(869.00,390.00));
      corners.push_back(convertPt(869.00,367.00));
      corners.push_back(convertPt(882.00,367.00));
      corners.push_back(convertPt(882.00,346.00));
      corners.push_back(convertPt(895.00,346.00));
      corners.push_back(convertPt(895.00,323.00));
      corners.push_back(convertPt(908.00,323.00));
      corners.push_back(convertPt(908.00,531.00));
      corners.push_back(convertPt(895.00,531.00));
      corners.push_back(convertPt(895.00,538.00));
      corners.push_back(convertPt(882.00,538.00));
      corners.push_back(convertPt(882.00,560.00));
      corners.push_back(convertPt(895.00,560.00));
      corners.push_back(convertPt(895.00,619.00));
      corners.push_back(convertPt(908.00,619.00));
      corners.push_back(convertPt(908.00,663.00));
      corners.push_back(convertPt(895.00,663.00));
      corners.push_back(convertPt(895.00,803.00));
      corners.push_back(convertPt(176.00,803.00));
      corners.push_back(convertPt(176.00,494.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(188.00,486.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(201.00,479.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(214.00,472.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(226.00,464.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(240.00,456.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(253.00,449.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(265.00,442.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(278.00,434.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(291.00,427.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(304.00,419.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(317.00,412.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(330.00,404.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(343.00,397.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(355.00,390.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(368.00,383.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(382.00,376.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(394.00,368.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(407.00,360.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(420.00,353.00));
      corners.push_back(convertPt(432.00,353.00));
      corners.push_back(convertPt(432.00,346.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(446.00,338.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(458.00,331.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(471.00,324.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(484.00,316.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(497.00,309.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(510.00,301.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(522.00,294.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(535.00,287.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(549.00,280.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(561.00,272.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(574.00,264.00));
      corners.push_back(convertPt(587.00,264.00));
      corners.push_back(convertPt(587.00,257.00));
      corners.push_back(convertPt(599.00,257.00));
      corners.push_back(convertPt(599.00,250.00));
      corners.push_back(convertPt(613.00,250.00));
      corners.push_back(convertPt(613.00,242.00));
      corners.push_back(convertPt(626.00,242.00));
      corners.push_back(convertPt(626.00,235.00));
      corners.push_back(convertPt(639.00,235.00));
      corners.push_back(convertPt(639.00,228.00));
      corners.push_back(convertPt(651.00,228.00));
      corners.push_back(convertPt(651.00,220.00));
      corners.push_back(convertPt(664.00,220.00));
      corners.push_back(convertPt(664.00,212.00));
      corners.push_back(convertPt(677.00,212.00));
      corners.push_back(convertPt(677.00,205.00));
      corners.push_back(convertPt(689.00,205.00));
      corners.push_back(convertPt(689.00,198.00));
      corners.push_back(convertPt(702.00,198.00));
      corners.push_back(convertPt(702.00,190.00));
      corners.push_back(convertPt(716.00,190.00));
      corners.push_back(convertPt(716.00,183.00));
      corners.push_back(convertPt(741.00,183.00));
      corners.push_back(convertPt(741.00,175.00));
      corners.push_back(convertPt(754.00,175.00));
      corners.push_back(convertPt(754.00,168.00));
      corners.push_back(convertPt(767.00,168.00));
      corners.push_back(convertPt(767.00,160.00));
      corners.push_back(convertPt(780.00,160.00));
      corners.push_back(convertPt(780.00,153.00));
      corners.push_back(convertPt(792.00,153.00));
      corners.push_back(convertPt(792.00,146.00));
      corners.push_back(convertPt(805.00,146.00));
      corners.push_back(convertPt(805.00,138.00));
      corners.push_back(convertPt(818.00,138.00));
      corners.push_back(convertPt(818.00,131.00));
      corners.push_back(convertPt(831.00,131.00));
      corners.push_back(convertPt(831.00,124.00));
      corners.push_back(convertPt(857.00,124.00));
      corners.push_back(convertPt(857.00,116.00));
      corners.push_back(convertPt(869.00,116.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(908.00,116.00));
      corners.push_back(convertPt(908.00,124.00));
      corners.push_back(convertPt(895.00,124.00));
      corners.push_back(convertPt(895.00,116.00));
      corners.push_back(convertPt(908.00,116.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(882.00,323.00));
      corners.push_back(convertPt(882.00,331.00));
      corners.push_back(convertPt(869.00,331.00));
      corners.push_back(convertPt(869.00,323.00));
      corners.push_back(convertPt(882.00,323.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(677.00,442.00));
      corners.push_back(convertPt(677.00,449.00));
      corners.push_back(convertPt(626.00,449.00));
      corners.push_back(convertPt(626.00,471.00));
      corners.push_back(convertPt(651.00,471.00));
      corners.push_back(convertPt(651.00,464.00));
      corners.push_back(convertPt(639.00,464.00));
      corners.push_back(convertPt(639.00,456.00));
      corners.push_back(convertPt(651.00,456.00));
      corners.push_back(convertPt(651.00,464.00));
      corners.push_back(convertPt(741.00,464.00));
      corners.push_back(convertPt(741.00,471.00));
      corners.push_back(convertPt(780.00,471.00));
      corners.push_back(convertPt(780.00,479.00));
      corners.push_back(convertPt(792.00,479.00));
      corners.push_back(convertPt(792.00,486.00));
      corners.push_back(convertPt(805.00,486.00));
      corners.push_back(convertPt(805.00,479.00));
      corners.push_back(convertPt(818.00,479.00));
      corners.push_back(convertPt(818.00,456.00));
      corners.push_back(convertPt(792.00,456.00));
      corners.push_back(convertPt(792.00,449.00));
      corners.push_back(convertPt(740.00,449.00));
      corners.push_back(convertPt(740.00,442.00));
      corners.push_back(convertPt(677.00,442.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,456.00));
      corners.push_back(convertPt(780.00,464.00));
      corners.push_back(convertPt(767.00,464.00));
      corners.push_back(convertPt(767.00,456.00));
      corners.push_back(convertPt(780.00,456.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(780.00,508.00));
      corners.push_back(convertPt(780.00,523.00));
      corners.push_back(convertPt(766.00,523.00));
      corners.push_back(convertPt(766.00,531.00));
      corners.push_back(convertPt(792.00,531.00));
      corners.push_back(convertPt(792.00,508.00));
      corners.push_back(convertPt(780.00,508.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(870.00,619.00));
      corners.push_back(convertPt(870.00,627.00));
      corners.push_back(convertPt(882.00,627.00));
      corners.push_back(convertPt(882.00,649.00));
      corners.push_back(convertPt(895.00,649.00));
      corners.push_back(convertPt(895.00,619.00));
      corners.push_back(convertPt(870.00,619.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(7, contoursPointer));

      ///// 0.09pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,116.00));
      corners.push_back(convertPt(869.00,131.00));
      corners.push_back(convertPt(857.00,131.00));
      corners.push_back(convertPt(857.00,138.00));
      corners.push_back(convertPt(869.00,138.00));
      corners.push_back(convertPt(869.00,153.00));
      corners.push_back(convertPt(882.00,153.00));
      corners.push_back(convertPt(882.00,146.00));
      corners.push_back(convertPt(895.00,146.00));
      corners.push_back(convertPt(895.00,138.00));
      corners.push_back(convertPt(908.00,138.00));
      corners.push_back(convertPt(908.00,168.00));
      corners.push_back(convertPt(895.00,168.00));
      corners.push_back(convertPt(895.00,175.00));
      corners.push_back(convertPt(908.00,175.00));
      corners.push_back(convertPt(908.00,190.00));
      corners.push_back(convertPt(895.00,190.00));
      corners.push_back(convertPt(895.00,198.00));
      corners.push_back(convertPt(908.00,198.00));
      corners.push_back(convertPt(908.00,205.00));
      corners.push_back(convertPt(895.00,205.00));
      corners.push_back(convertPt(895.00,212.00));
      corners.push_back(convertPt(908.00,212.00));
      corners.push_back(convertPt(908.00,220.00));
      corners.push_back(convertPt(895.00,220.00));
      corners.push_back(convertPt(895.00,235.00));
      corners.push_back(convertPt(882.00,235.00));
      corners.push_back(convertPt(882.00,286.00));
      corners.push_back(convertPt(895.00,286.00));
      corners.push_back(convertPt(895.00,323.00));
      corners.push_back(convertPt(908.00,323.00));
      corners.push_back(convertPt(908.00,301.00));
      corners.push_back(convertPt(921.00,301.00));
      corners.push_back(convertPt(921.00,501.00));
      corners.push_back(convertPt(908.00,501.00));
      corners.push_back(convertPt(908.00,538.00));
      corners.push_back(convertPt(895.00,538.00));
      corners.push_back(convertPt(895.00,583.00));
      corners.push_back(convertPt(908.00,583.00));
      corners.push_back(convertPt(908.00,663.00));
      corners.push_back(convertPt(895.00,663.00));
      corners.push_back(convertPt(895.00,803.00));
      corners.push_back(convertPt(176.00,803.00));
      corners.push_back(convertPt(176.00,494.00));
      corners.push_back(convertPt(188.00,494.00));
      corners.push_back(convertPt(188.00,486.00));
      corners.push_back(convertPt(201.00,486.00));
      corners.push_back(convertPt(201.00,479.00));
      corners.push_back(convertPt(214.00,479.00));
      corners.push_back(convertPt(214.00,472.00));
      corners.push_back(convertPt(226.00,472.00));
      corners.push_back(convertPt(226.00,464.00));
      corners.push_back(convertPt(240.00,464.00));
      corners.push_back(convertPt(240.00,456.00));
      corners.push_back(convertPt(253.00,456.00));
      corners.push_back(convertPt(253.00,449.00));
      corners.push_back(convertPt(265.00,449.00));
      corners.push_back(convertPt(265.00,442.00));
      corners.push_back(convertPt(278.00,442.00));
      corners.push_back(convertPt(278.00,434.00));
      corners.push_back(convertPt(291.00,434.00));
      corners.push_back(convertPt(291.00,427.00));
      corners.push_back(convertPt(304.00,427.00));
      corners.push_back(convertPt(304.00,419.00));
      corners.push_back(convertPt(317.00,419.00));
      corners.push_back(convertPt(317.00,412.00));
      corners.push_back(convertPt(330.00,412.00));
      corners.push_back(convertPt(330.00,404.00));
      corners.push_back(convertPt(343.00,404.00));
      corners.push_back(convertPt(343.00,397.00));
      corners.push_back(convertPt(355.00,397.00));
      corners.push_back(convertPt(355.00,390.00));
      corners.push_back(convertPt(368.00,390.00));
      corners.push_back(convertPt(368.00,383.00));
      corners.push_back(convertPt(382.00,383.00));
      corners.push_back(convertPt(382.00,376.00));
      corners.push_back(convertPt(394.00,376.00));
      corners.push_back(convertPt(394.00,368.00));
      corners.push_back(convertPt(407.00,368.00));
      corners.push_back(convertPt(407.00,360.00));
      corners.push_back(convertPt(420.00,360.00));
      corners.push_back(convertPt(420.00,353.00));
      corners.push_back(convertPt(432.00,353.00));
      corners.push_back(convertPt(432.00,346.00));
      corners.push_back(convertPt(446.00,346.00));
      corners.push_back(convertPt(446.00,338.00));
      corners.push_back(convertPt(458.00,338.00));
      corners.push_back(convertPt(458.00,331.00));
      corners.push_back(convertPt(471.00,331.00));
      corners.push_back(convertPt(471.00,324.00));
      corners.push_back(convertPt(484.00,324.00));
      corners.push_back(convertPt(484.00,316.00));
      corners.push_back(convertPt(497.00,316.00));
      corners.push_back(convertPt(497.00,309.00));
      corners.push_back(convertPt(510.00,309.00));
      corners.push_back(convertPt(510.00,301.00));
      corners.push_back(convertPt(522.00,301.00));
      corners.push_back(convertPt(522.00,294.00));
      corners.push_back(convertPt(535.00,294.00));
      corners.push_back(convertPt(535.00,287.00));
      corners.push_back(convertPt(549.00,287.00));
      corners.push_back(convertPt(549.00,280.00));
      corners.push_back(convertPt(561.00,280.00));
      corners.push_back(convertPt(561.00,272.00));
      corners.push_back(convertPt(574.00,272.00));
      corners.push_back(convertPt(574.00,264.00));
      corners.push_back(convertPt(587.00,264.00));
      corners.push_back(convertPt(587.00,257.00));
      corners.push_back(convertPt(599.00,257.00));
      corners.push_back(convertPt(599.00,250.00));
      corners.push_back(convertPt(613.00,250.00));
      corners.push_back(convertPt(613.00,242.00));
      corners.push_back(convertPt(626.00,242.00));
      corners.push_back(convertPt(626.00,235.00));
      corners.push_back(convertPt(639.00,235.00));
      corners.push_back(convertPt(639.00,228.00));
      corners.push_back(convertPt(651.00,228.00));
      corners.push_back(convertPt(651.00,220.00));
      corners.push_back(convertPt(664.00,220.00));
      corners.push_back(convertPt(664.00,212.00));
      corners.push_back(convertPt(677.00,212.00));
      corners.push_back(convertPt(677.00,205.00));
      corners.push_back(convertPt(689.00,205.00));
      corners.push_back(convertPt(689.00,198.00));
      corners.push_back(convertPt(702.00,198.00));
      corners.push_back(convertPt(702.00,190.00));
      corners.push_back(convertPt(716.00,190.00));
      corners.push_back(convertPt(716.00,183.00));
      corners.push_back(convertPt(728.00,183.00));
      corners.push_back(convertPt(728.00,175.00));
      corners.push_back(convertPt(741.00,175.00));
      corners.push_back(convertPt(741.00,168.00));
      corners.push_back(convertPt(767.00,168.00));
      corners.push_back(convertPt(767.00,160.00));
      corners.push_back(convertPt(780.00,160.00));
      corners.push_back(convertPt(780.00,153.00));
      corners.push_back(convertPt(792.00,153.00));
      corners.push_back(convertPt(792.00,146.00));
      corners.push_back(convertPt(805.00,146.00));
      corners.push_back(convertPt(805.00,138.00));
      corners.push_back(convertPt(818.00,138.00));
      corners.push_back(convertPt(818.00,131.00));
      corners.push_back(convertPt(831.00,131.00));
      corners.push_back(convertPt(831.00,124.00));
      corners.push_back(convertPt(857.00,124.00));
      corners.push_back(convertPt(857.00,116.00));
      corners.push_back(convertPt(869.00,116.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(908.00,116.00));
      corners.push_back(convertPt(908.00,124.00));
      corners.push_back(convertPt(895.00,124.00));
      corners.push_back(convertPt(895.00,116.00));
      corners.push_back(convertPt(908.00,116.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,294.00));
      corners.push_back(convertPt(869.00,309.00));
      corners.push_back(convertPt(882.00,309.00));
      corners.push_back(convertPt(882.00,294.00));
      corners.push_back(convertPt(869.00,294.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(882.00,331.00));
      corners.push_back(convertPt(882.00,338.00));
      corners.push_back(convertPt(895.00,338.00));
      corners.push_back(convertPt(895.00,331.00));
      corners.push_back(convertPt(882.00,331.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(844.00,338.00));
      corners.push_back(convertPt(844.00,346.00));
      corners.push_back(convertPt(857.00,346.00));
      corners.push_back(convertPt(857.00,338.00));
      corners.push_back(convertPt(844.00,338.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(869.00,346.00));
      corners.push_back(convertPt(869.00,367.00));
      corners.push_back(convertPt(882.00,367.00));
      corners.push_back(convertPt(882.00,346.00));
      corners.push_back(convertPt(869.00,346.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(664.00,449.00));
      corners.push_back(convertPt(664.00,456.00));
      corners.push_back(convertPt(689.00,456.00));
      corners.push_back(convertPt(689.00,449.00));
      corners.push_back(convertPt(664.00,449.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(921.00,553.00));
      corners.push_back(convertPt(921.00,568.00));
      corners.push_back(convertPt(908.00,568.00));
      corners.push_back(convertPt(908.00,553.00));
      corners.push_back(convertPt(921.00,553.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(8, contoursPointer));

      ///// 0.1pb /////
      corners.clear();
      corners.push_back(convertPt(933.00,50.00));
      corners.push_back(convertPt(933.00,803.0));
      corners.push_back(convertPt(176.00,803.0));
      corners.push_back(convertPt(176.00,479.0));
      corners.push_back(convertPt(188.00,479.0));
      corners.push_back(convertPt(188.00,472.0));
      corners.push_back(convertPt(201.00,472.0));
      corners.push_back(convertPt(201.00,464.0));
      corners.push_back(convertPt(214.00,464.0));
      corners.push_back(convertPt(214.00,456.0));
      corners.push_back(convertPt(226.00,456.0));
      corners.push_back(convertPt(226.00,449.0));
      corners.push_back(convertPt(240.00,449.0));
      corners.push_back(convertPt(240.00,442.0));
      corners.push_back(convertPt(253.00,442.0));
      corners.push_back(convertPt(253.00,434.0));
      corners.push_back(convertPt(265.28,426.0));
      corners.push_back(convertPt(278.00,427.0));
      corners.push_back(convertPt(278.00,419.0));
      corners.push_back(convertPt(291.00,419.0));
      corners.push_back(convertPt(291.00,412.0));
      corners.push_back(convertPt(304.00,412.0));
      corners.push_back(convertPt(304.00,404.0));
      corners.push_back(convertPt(317.00,404.0));
      corners.push_back(convertPt(317.00,397.0));
      corners.push_back(convertPt(330.00,397.0));
      corners.push_back(convertPt(330.00,390.0));
      corners.push_back(convertPt(342.00,390.0));
      corners.push_back(convertPt(342.00,383.0));
      corners.push_back(convertPt(355.00,383.0));
      corners.push_back(convertPt(355.00,376.0));
      corners.push_back(convertPt(368.00,376.0));
      corners.push_back(convertPt(368.00,368.0));
      corners.push_back(convertPt(382.00,368.0));
      corners.push_back(convertPt(382.00,360.0));
      corners.push_back(convertPt(394.00,360.0));
      corners.push_back(convertPt(394.00,353.0));
      corners.push_back(convertPt(406.00,353.0));
      corners.push_back(convertPt(406.00,346.0));
      corners.push_back(convertPt(420.00,346.0));
      corners.push_back(convertPt(420.00,338.0));
      corners.push_back(convertPt(432.00,338.0));
      corners.push_back(convertPt(432.00,331.0));
      corners.push_back(convertPt(446.00,331.0));
      corners.push_back(convertPt(446.00,324.0));
      corners.push_back(convertPt(458.00,324.0));
      corners.push_back(convertPt(458.00,316.0));
      corners.push_back(convertPt(471.00,316.0));
      corners.push_back(convertPt(471.00,309.0));
      corners.push_back(convertPt(484.00,309.0));
      corners.push_back(convertPt(484.00,301.0));
      corners.push_back(convertPt(497.00,301.0));
      corners.push_back(convertPt(497.00,294.0));
      corners.push_back(convertPt(510.00,294.0));
      corners.push_back(convertPt(510.00,287.0));
      corners.push_back(convertPt(522.00,287.0));
      corners.push_back(convertPt(522.00,279.0));
      corners.push_back(convertPt(535.00,279.0));
      corners.push_back(convertPt(535.00,271.0));
      corners.push_back(convertPt(549.00,271.0));
      corners.push_back(convertPt(549.00,264.0));
      corners.push_back(convertPt(561.00,264.0));
      corners.push_back(convertPt(561.00,257.0));
      corners.push_back(convertPt(574.00,257.0));
      corners.push_back(convertPt(574.00,250.0));
      corners.push_back(convertPt(587.00,250.0));
      corners.push_back(convertPt(587.00,242.0));
      corners.push_back(convertPt(599.00,242.0));
      corners.push_back(convertPt(599.00,235.0));
      corners.push_back(convertPt(613.00,235.0));
      corners.push_back(convertPt(613.00,228.0));
      corners.push_back(convertPt(626.00,228.0));
      corners.push_back(convertPt(626.00,220.0));
      corners.push_back(convertPt(639.00,220.0));
      corners.push_back(convertPt(639.00,212.0));
      corners.push_back(convertPt(651.00,212.0));
      corners.push_back(convertPt(651.00,205.0));
      corners.push_back(convertPt(664.00,205.0));
      corners.push_back(convertPt(664.00,198.0));
      corners.push_back(convertPt(677.00,198.0));
      corners.push_back(convertPt(677.00,190.0));
      corners.push_back(convertPt(690.00,190.0));
      corners.push_back(convertPt(690.00,183.0));
      corners.push_back(convertPt(702.00,183.0));
      corners.push_back(convertPt(702.00,176.0));
      corners.push_back(convertPt(716.00,176.0));
      corners.push_back(convertPt(716.00,168.0));
      corners.push_back(convertPt(728.00,168.0));
      corners.push_back(convertPt(728.00,160.0));
      corners.push_back(convertPt(741.00,160.0));
      corners.push_back(convertPt(741.00,153.0));
      corners.push_back(convertPt(754.00,153.0));
      corners.push_back(convertPt(754.00,146.0));
      corners.push_back(convertPt(767.00,146.0));
      corners.push_back(convertPt(767.00,138.0));
      corners.push_back(convertPt(780.00,138.0));
      corners.push_back(convertPt(780.00,131.0));
      corners.push_back(convertPt(792.00,131.0));
      corners.push_back(convertPt(792.00,124.0));
      corners.push_back(convertPt(805.00,124.0));
      corners.push_back(convertPt(805.00,116.0));
      corners.push_back(convertPt(818.00,116.0));
      corners.push_back(convertPt(818.00,108.0));
      corners.push_back(convertPt(831.00,108.0));
      corners.push_back(convertPt(831.00,101.0));
      corners.push_back(convertPt(844.00,101.0));
      corners.push_back(convertPt(844.00,94.00));
      corners.push_back(convertPt(857.00,94.00));
      corners.push_back(convertPt(857.00,87.00));
      corners.push_back(convertPt(869.00,87.00));
      corners.push_back(convertPt(869.00,79.00));
      corners.push_back(convertPt(882.00,79.00));
      corners.push_back(convertPt(882.00,72.00));
      corners.push_back(convertPt(895.00,72.00));
      corners.push_back(convertPt(895.00,64.00));
      corners.push_back(convertPt(908.00,64.00));
      corners.push_back(convertPt(908.00,57.00));
      corners.push_back(convertPt(921.00,57.00));
      corners.push_back(convertPt(921.00,50.00));
      corners.push_back(convertPt(933.00,50.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(9, contoursPointer));

    }



    P2 ALEPHStauLimitAt208GeV::convertPt(double x, double y) const
    {
      return P2(50. + (x - 232.00) / (875.00 - 232.00) * (100. - 50.),
                100. + (y - 66.00) / (805.00 - 66.00) * (0. - 100.));
    }
    
    bool ALEPHStauLimitAt208GeV::isWithinExclusionRegion(double x, double y, double mZ) const
    {
      return (y <= x and x <= 208. / 2. and x > mZ / 2.);
    }
    
    ALEPHStauLimitAt208GeV::ALEPHStauLimitAt208GeV()
    {
      ///// Limit values /////
      _limitValuesSorted.push_back(0.14);
      _limitValuesSorted.push_back(0.21);
      _limitValuesSorted.push_back(0.28);
      _limitValuesSorted.push_back(0.35);
      _limitValuesSorted.push_back(0.42);
      _limitValuesSorted.push_back(0.49);
      _limitValuesSorted.push_back(0.56);
      _limitValuesSorted.push_back(0.63);
      _limitValuesSorted.push_back(0.7);

      ///// Limit Contours /////
      Corners corners;
      ContoursPointer contoursPointer;
      size_t oldSize;

      ///// 0.14pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(720.00,266.00));
      corners.push_back(convertPt(720.00,273.00));
      corners.push_back(convertPt(708.00,273.00));
      corners.push_back(convertPt(708.00,266.00));
      corners.push_back(convertPt(720.00,266.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(694.00,281.00));
      corners.push_back(convertPt(694.00,289.00));
      corners.push_back(convertPt(681.00,289.00));
      corners.push_back(convertPt(681.00,281.00));
      corners.push_back(convertPt(694.00,281.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,296.00));
      corners.push_back(convertPt(643.00,304.00));
      corners.push_back(convertPt(630.00,304.00));
      corners.push_back(convertPt(630.00,296.00));
      corners.push_back(convertPt(643.00,296.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(694.00,296.00));
      corners.push_back(convertPt(694.00,304.00));
      corners.push_back(convertPt(681.00,304.00));
      corners.push_back(convertPt(681.00,296.00));
      corners.push_back(convertPt(694.00,296.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,311.00));
      corners.push_back(convertPt(643.00,318.00));
      corners.push_back(convertPt(630.00,318.00));
      corners.push_back(convertPt(630.00,311.00));
      corners.push_back(convertPt(643.00,311.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(823.00,318.00));
      corners.push_back(convertPt(823.00,326.00));
      corners.push_back(convertPt(836.00,326.00));
      corners.push_back(convertPt(836.00,348.00));
      corners.push_back(convertPt(849.00,348.00));
      corners.push_back(convertPt(849.00,370.00));
      corners.push_back(convertPt(836.00,370.00));
      corners.push_back(convertPt(836.00,377.00));
      corners.push_back(convertPt(849.00,377.00));
      corners.push_back(convertPt(849.00,385.00));
      corners.push_back(convertPt(836.00,385.00));
      corners.push_back(convertPt(836.00,407.00));
      corners.push_back(convertPt(797.00,407.00));
      corners.push_back(convertPt(797.00,415.00));
      corners.push_back(convertPt(810.00,415.00));
      corners.push_back(convertPt(810.00,422.00));
      corners.push_back(convertPt(797.00,422.00));
      corners.push_back(convertPt(797.00,415.00));
      corners.push_back(convertPt(784.00,415.00));
      corners.push_back(convertPt(784.00,407.00));
      corners.push_back(convertPt(758.00,407.00));
      corners.push_back(convertPt(758.00,400.00));
      corners.push_back(convertPt(746.00,400.00));
      corners.push_back(convertPt(746.00,407.00));
      corners.push_back(convertPt(708.00,407.00));
      corners.push_back(convertPt(708.00,415.00));
      corners.push_back(convertPt(694.00,415.00));
      corners.push_back(convertPt(694.00,422.00));
      corners.push_back(convertPt(656.00,422.00));
      corners.push_back(convertPt(656.00,415.00));
      corners.push_back(convertPt(669.00,415.00));
      corners.push_back(convertPt(669.00,407.00));
      corners.push_back(convertPt(681.00,407.00));
      corners.push_back(convertPt(681.00,400.00));
      corners.push_back(convertPt(694.00,400.00));
      corners.push_back(convertPt(694.00,393.00));
      corners.push_back(convertPt(681.00,393.00));
      corners.push_back(convertPt(681.00,386.00));
      corners.push_back(convertPt(694.00,386.00));
      corners.push_back(convertPt(694.00,393.00));
      corners.push_back(convertPt(708.00,393.00));
      corners.push_back(convertPt(708.00,386.00));
      corners.push_back(convertPt(720.00,386.00));
      corners.push_back(convertPt(720.00,377.00));
      corners.push_back(convertPt(708.00,377.00));
      corners.push_back(convertPt(708.00,370.00));
      corners.push_back(convertPt(720.00,370.00));
      corners.push_back(convertPt(720.00,377.00));
      corners.push_back(convertPt(733.00,377.00));
      corners.push_back(convertPt(733.00,370.00));
      corners.push_back(convertPt(746.00,370.00));
      corners.push_back(convertPt(746.00,363.00));
      corners.push_back(convertPt(758.00,363.00));
      corners.push_back(convertPt(758.00,356.00));
      corners.push_back(convertPt(772.00,356.00));
      corners.push_back(convertPt(772.00,348.00));
      corners.push_back(convertPt(784.00,348.00));
      corners.push_back(convertPt(784.00,334.00));
      corners.push_back(convertPt(798.00,334.00));
      corners.push_back(convertPt(798.00,326.00));
      corners.push_back(convertPt(810.00,326.00));
      corners.push_back(convertPt(810.00,318.00));
      corners.push_back(convertPt(823.00,318.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(669.00,325.00));
      corners.push_back(convertPt(669.00,334.00));
      corners.push_back(convertPt(656.00,334.00));
      corners.push_back(convertPt(656.00,325.00));
      corners.push_back(convertPt(669.00,325.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,340.00));
      corners.push_back(convertPt(643.00,348.00));
      corners.push_back(convertPt(630.00,348.00));
      corners.push_back(convertPt(630.00,340.00));
      corners.push_back(convertPt(643.00,340.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(669.00,340.00));
      corners.push_back(convertPt(669.00,348.00));
      corners.push_back(convertPt(656.00,348.00));
      corners.push_back(convertPt(656.00,340.00));
      corners.push_back(convertPt(669.00,340.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(694.00,356.00));
      corners.push_back(convertPt(694.00,363.00));
      corners.push_back(convertPt(681.00,363.00));
      corners.push_back(convertPt(681.00,356.00));
      corners.push_back(convertPt(694.00,356.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,370.00));
      corners.push_back(convertPt(643.00,377.00));
      corners.push_back(convertPt(630.00,377.00));
      corners.push_back(convertPt(630.00,370.00));
      corners.push_back(convertPt(643.00,370.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(669.00,370.00));
      corners.push_back(convertPt(669.00,377.00));
      corners.push_back(convertPt(656.00,377.00));
      corners.push_back(convertPt(656.00,370.00));
      corners.push_back(convertPt(669.00,370.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,386.00));
      corners.push_back(convertPt(643.00,393.00));
      corners.push_back(convertPt(630.00,393.00));
      corners.push_back(convertPt(630.00,386.00));
      corners.push_back(convertPt(643.00,386.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(617.00,400.00));
      corners.push_back(convertPt(617.00,415.00));
      corners.push_back(convertPt(605.00,415.00));
      corners.push_back(convertPt(605.00,422.00));
      corners.push_back(convertPt(579.00,422.00));
      corners.push_back(convertPt(579.00,400.00));
      corners.push_back(convertPt(617.00,400.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(541.00,415.00));
      corners.push_back(convertPt(541.00,422.00));
      corners.push_back(convertPt(565.00,422.00));
      corners.push_back(convertPt(565.00,429.00));
      corners.push_back(convertPt(527.00,429.00));
      corners.push_back(convertPt(527.00,437.00));
      corners.push_back(convertPt(514.00,437.00));
      corners.push_back(convertPt(514.00,452.00));
      corners.push_back(convertPt(476.00,452.00));
      corners.push_back(convertPt(476.00,459.00));
      corners.push_back(convertPt(449.00,459.00));
      corners.push_back(convertPt(449.00,466.00));
      corners.push_back(convertPt(412.00,466.00));
      corners.push_back(convertPt(412.00,481.00));
      corners.push_back(convertPt(374.00,481.00));
      corners.push_back(convertPt(374.00,466.00));
      corners.push_back(convertPt(386.00,466.00));
      corners.push_back(convertPt(386.00,459.00));
      corners.push_back(convertPt(398.00,459.00));
      corners.push_back(convertPt(398.00,452.00));
      corners.push_back(convertPt(412.00,452.00));
      corners.push_back(convertPt(412.00,445.00));
      corners.push_back(convertPt(463.00,445.00));
      corners.push_back(convertPt(463.00,452.00));
      corners.push_back(convertPt(476.00,452.00));
      corners.push_back(convertPt(476.00,430.00));
      corners.push_back(convertPt(489.00,430.00));
      corners.push_back(convertPt(489.00,422.00));
      corners.push_back(convertPt(514.00,422.00));
      corners.push_back(convertPt(514.00,415.00));
      corners.push_back(convertPt(541.00,415.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,415.00));
      corners.push_back(convertPt(643.00,422.00));
      corners.push_back(convertPt(630.00,422.00));
      corners.push_back(convertPt(630.00,415.00));
      corners.push_back(convertPt(643.00,415.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(617.00,429.00));
      corners.push_back(convertPt(617.00,437.00));
      corners.push_back(convertPt(643.00,437.00));
      corners.push_back(convertPt(643.00,429.00));
      corners.push_back(convertPt(669.00,429.00));
      corners.push_back(convertPt(669.00,437.00));
      corners.push_back(convertPt(694.00,437.00));
      corners.push_back(convertPt(694.00,452.00));
      corners.push_back(convertPt(708.00,452.00));
      corners.push_back(convertPt(708.00,482.00));
      corners.push_back(convertPt(656.00,482.00));
      corners.push_back(convertPt(656.00,496.00));
      corners.push_back(convertPt(669.00,496.00));
      corners.push_back(convertPt(669.00,503.00));
      corners.push_back(convertPt(630.00,503.00));
      corners.push_back(convertPt(630.00,511.00));
      corners.push_back(convertPt(617.00,511.00));
      corners.push_back(convertPt(617.00,503.00));
      corners.push_back(convertPt(605.00,503.00));
      corners.push_back(convertPt(605.00,511.00));
      corners.push_back(convertPt(579.00,511.00));
      corners.push_back(convertPt(579.00,525.00));
      corners.push_back(convertPt(565.00,525.00));
      corners.push_back(convertPt(565.00,541.00));
      corners.push_back(convertPt(541.00,541.00));
      corners.push_back(convertPt(541.00,548.00));
      corners.push_back(convertPt(527.00,548.00));
      corners.push_back(convertPt(527.00,555.00));
      corners.push_back(convertPt(514.00,555.00));
      corners.push_back(convertPt(514.00,570.00));
      corners.push_back(convertPt(502.00,570.00));
      corners.push_back(convertPt(502.00,585.00));
      corners.push_back(convertPt(489.00,585.00));
      corners.push_back(convertPt(489.00,614.00));
      corners.push_back(convertPt(476.00,614.00));
      corners.push_back(convertPt(476.00,621.00));
      corners.push_back(convertPt(463.00,621.00));
      corners.push_back(convertPt(463.00,637.00));
      corners.push_back(convertPt(476.00,637.00));
      corners.push_back(convertPt(476.00,644.00));
      corners.push_back(convertPt(489.00,644.00));
      corners.push_back(convertPt(489.00,651.00));
      corners.push_back(convertPt(502.00,651.00));
      corners.push_back(convertPt(502.00,682.00));
      corners.push_back(convertPt(489.00,682.00));
      corners.push_back(convertPt(489.00,696.00));
      corners.push_back(convertPt(476.00,696.00));
      corners.push_back(convertPt(476.00,718.00));
      corners.push_back(convertPt(463.00,718.00));
      corners.push_back(convertPt(463.00,725.00));
      corners.push_back(convertPt(450.00,725.00));
      corners.push_back(convertPt(450.00,741.00));
      corners.push_back(convertPt(437.00,741.00));
      corners.push_back(convertPt(437.00,748.00));
      corners.push_back(convertPt(424.00,748.00));
      corners.push_back(convertPt(424.00,762.00));
      corners.push_back(convertPt(412.00,762.00));
      corners.push_back(convertPt(412.00,770.00));
      corners.push_back(convertPt(398.00,770.00));
      corners.push_back(convertPt(398.00,785.00));
      corners.push_back(convertPt(386.00,785.00));
      corners.push_back(convertPt(386.00,800.00));
      corners.push_back(convertPt(374.00,800.00));
      corners.push_back(convertPt(374.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,689.00));
      corners.push_back(convertPt(218.00,689.00));
      corners.push_back(convertPt(218.00,681.00));
      corners.push_back(convertPt(245.00,681.00));
      corners.push_back(convertPt(245.00,666.00));
      corners.push_back(convertPt(257.00,666.00));
      corners.push_back(convertPt(257.00,659.00));
      corners.push_back(convertPt(283.00,659.00));
      corners.push_back(convertPt(283.00,651.00));
      corners.push_back(convertPt(296.00,651.00));
      corners.push_back(convertPt(296.00,644.00));
      corners.push_back(convertPt(309.00,644.00));
      corners.push_back(convertPt(309.00,629.00));
      corners.push_back(convertPt(334.00,629.00));
      corners.push_back(convertPt(334.00,622.00));
      corners.push_back(convertPt(347.00,622.00));
      corners.push_back(convertPt(347.00,614.00));
      corners.push_back(convertPt(360.00,614.00));
      corners.push_back(convertPt(360.00,599.00));
      corners.push_back(convertPt(374.00,599.00));
      corners.push_back(convertPt(374.00,585.00));
      corners.push_back(convertPt(385.00,585.00));
      corners.push_back(convertPt(385.00,578.00));
      corners.push_back(convertPt(412.00,578.00));
      corners.push_back(convertPt(412.00,570.00));
      corners.push_back(convertPt(449.00,570.00));
      corners.push_back(convertPt(449.00,562.00));
      corners.push_back(convertPt(463.00,562.00));
      corners.push_back(convertPt(463.00,541.00));
      corners.push_back(convertPt(514.00,541.00));
      corners.push_back(convertPt(514.00,511.00));
      corners.push_back(convertPt(553.00,511.00));
      corners.push_back(convertPt(553.00,482.00));
      corners.push_back(convertPt(527.00,482.00));
      corners.push_back(convertPt(527.00,474.00));
      corners.push_back(convertPt(541.00,474.00));
      corners.push_back(convertPt(541.00,459.00));
      corners.push_back(convertPt(565.00,459.00));
      corners.push_back(convertPt(565.00,474.00));
      corners.push_back(convertPt(579.00,474.00));
      corners.push_back(convertPt(579.00,459.00));
      corners.push_back(convertPt(605.00,459.00));
      corners.push_back(convertPt(605.00,452.00));
      corners.push_back(convertPt(579.00,452.00));
      corners.push_back(convertPt(579.00,437.00));
      corners.push_back(convertPt(591.00,437.00));
      corners.push_back(convertPt(591.00,429.00));
      corners.push_back(convertPt(617.00,429.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(772.00,445.00));
      corners.push_back(convertPt(772.00,452.00));
      corners.push_back(convertPt(758.00,452.00));
      corners.push_back(convertPt(758.00,445.00));
      corners.push_back(convertPt(772.00,445.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(772.00,459.00));
      corners.push_back(convertPt(772.00,466.00));
      corners.push_back(convertPt(758.00,466.00));
      corners.push_back(convertPt(758.00,459.00));
      corners.push_back(convertPt(772.00,459.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(772.00,474.00));
      corners.push_back(convertPt(772.00,482.00));
      corners.push_back(convertPt(758.00,482.00));
      corners.push_back(convertPt(758.00,474.00));
      corners.push_back(convertPt(772.00,474.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(360.00,489.00));
      corners.push_back(convertPt(360.00,511.00));
      corners.push_back(convertPt(322.00,511.00));
      corners.push_back(convertPt(322.00,496.00));
      corners.push_back(convertPt(334.00,496.00));
      corners.push_back(convertPt(334.00,489.00));
      corners.push_back(convertPt(360.00,489.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(514.00,489.00));
      corners.push_back(convertPt(514.00,503.00));
      corners.push_back(convertPt(489.00,503.00));
      corners.push_back(convertPt(489.00,511.00));
      corners.push_back(convertPt(476.00,511.00));
      corners.push_back(convertPt(476.00,503.00));
      corners.push_back(convertPt(489.00,503.00));
      corners.push_back(convertPt(489.00,496.00));
      corners.push_back(convertPt(501.00,496.00));
      corners.push_back(convertPt(501.00,489.00));
      corners.push_back(convertPt(514.00,489.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(694.00,489.00));
      corners.push_back(convertPt(694.00,496.00));
      corners.push_back(convertPt(682.00,496.00));
      corners.push_back(convertPt(682.00,489.00));
      corners.push_back(convertPt(694.00,489.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(309.00,518.00));
      corners.push_back(convertPt(309.00,533.00));
      corners.push_back(convertPt(296.00,533.00));
      corners.push_back(convertPt(296.00,541.00));
      corners.push_back(convertPt(270.00,541.00));
      corners.push_back(convertPt(270.00,518.00));
      corners.push_back(convertPt(309.00,518.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(463.00,518.00));
      corners.push_back(convertPt(463.00,525.00));
      corners.push_back(convertPt(449.00,525.00));
      corners.push_back(convertPt(449.00,533.00));
      corners.push_back(convertPt(437.00,533.00));
      corners.push_back(convertPt(437.00,525.00));
      corners.push_back(convertPt(449.00,525.00));
      corners.push_back(convertPt(449.00,518.00));
      corners.push_back(convertPt(463.00,518.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,518.00));
      corners.push_back(convertPt(643.00,525.00));
      corners.push_back(convertPt(630.00,525.00));
      corners.push_back(convertPt(630.00,518.00));
      corners.push_back(convertPt(643.00,518.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(643.00,533.00));
      corners.push_back(convertPt(643.00,541.00));
      corners.push_back(convertPt(630.00,541.00));
      corners.push_back(convertPt(630.00,533.00));
      corners.push_back(convertPt(643.00,533.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(257.00,548.00));
      corners.push_back(convertPt(257.00,555.00));
      corners.push_back(convertPt(245.00,555.00));
      corners.push_back(convertPt(245.00,562.00));
      corners.push_back(convertPt(232.00,562.00));
      corners.push_back(convertPt(232.00,570.00));
      corners.push_back(convertPt(218.00,570.00));
      corners.push_back(convertPt(218.00,555.00));
      corners.push_back(convertPt(232.00,555.00));
      corners.push_back(convertPt(232.00,548.00));
      corners.push_back(convertPt(257.00,548.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(746.00,548.00));
      corners.push_back(convertPt(746.00,555.00));
      corners.push_back(convertPt(733.00,555.00));
      corners.push_back(convertPt(733.00,548.00));
      corners.push_back(convertPt(746.00,548.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(398.00,555.00));
      corners.push_back(convertPt(398.00,562.00));
      corners.push_back(convertPt(385.00,562.00));
      corners.push_back(convertPt(385.00,555.00));
      corners.push_back(convertPt(398.00,555.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(720.00,563.00));
      corners.push_back(convertPt(720.00,570.00));
      corners.push_back(convertPt(708.00,570.00));
      corners.push_back(convertPt(708.00,563.00));
      corners.push_back(convertPt(720.00,563.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(746.00,578.00));
      corners.push_back(convertPt(746.00,585.00));
      corners.push_back(convertPt(733.00,585.00));
      corners.push_back(convertPt(733.00,578.00));
      corners.push_back(convertPt(746.00,578.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(347.00,585.00));
      corners.push_back(convertPt(347.00,592.00));
      corners.push_back(convertPt(334.00,592.00));
      corners.push_back(convertPt(334.00,585.00));
      corners.push_back(convertPt(347.00,585.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(694.00,607.00));
      corners.push_back(convertPt(694.00,614.00));
      corners.push_back(convertPt(681.00,614.00));
      corners.push_back(convertPt(681.00,607.00));
      corners.push_back(convertPt(694.00,607.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(296.00,614.00));
      corners.push_back(convertPt(296.00,621.00));
      corners.push_back(convertPt(283.00,621.00));
      corners.push_back(convertPt(283.00,614.00));
      corners.push_back(convertPt(296.00,614.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(720.00,637.00));
      corners.push_back(convertPt(720.00,644.00));
      corners.push_back(convertPt(708.00,644.00));
      corners.push_back(convertPt(708.00,637.00));
      corners.push_back(convertPt(720.00,637.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(245.00,644.00));
      corners.push_back(convertPt(245.00,651.00));
      corners.push_back(convertPt(232.00,651.00));
      corners.push_back(convertPt(232.00,644.00));
      corners.push_back(convertPt(245.00,644.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(746.00,666.00));
      corners.push_back(convertPt(746.00,673.00));
      corners.push_back(convertPt(733.00,673.00));
      corners.push_back(convertPt(733.00,666.00));
      corners.push_back(convertPt(746.00,666.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(514.00,755.00));
      corners.push_back(convertPt(514.00,777.00));
      corners.push_back(convertPt(476.00,777.00));
      corners.push_back(convertPt(476.00,755.00));
      corners.push_back(convertPt(514.00,755.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(0, contoursPointer));

      ///// 0.21pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(836.00,215.00));
      corners.push_back(convertPt(836.00,237.00));
      corners.push_back(convertPt(849.00,237.00));
      corners.push_back(convertPt(849.00,244.00));
      corners.push_back(convertPt(823.00,244.00));
      corners.push_back(convertPt(823.00,259.00));
      corners.push_back(convertPt(784.00,259.00));
      corners.push_back(convertPt(784.00,266.00));
      corners.push_back(convertPt(823.00,266.00));
      corners.push_back(convertPt(823.00,289.00));
      corners.push_back(convertPt(836.00,289.00));
      corners.push_back(convertPt(836.00,304.00));
      corners.push_back(convertPt(849.00,304.00));
      corners.push_back(convertPt(849.00,296.00));
      corners.push_back(convertPt(874.00,296.00));
      corners.push_back(convertPt(874.00,333.00));
      corners.push_back(convertPt(887.00,333.00));
      corners.push_back(convertPt(887.00,386.00));
      corners.push_back(convertPt(874.00,386.00));
      corners.push_back(convertPt(874.00,466.00));
      corners.push_back(convertPt(862.00,466.00));
      corners.push_back(convertPt(862.00,481.00));
      corners.push_back(convertPt(874.00,481.00));
      corners.push_back(convertPt(874.00,548.00));
      corners.push_back(convertPt(862.00,548.00));
      corners.push_back(convertPt(862.00,562.00));
      corners.push_back(convertPt(874.00,562.00));
      corners.push_back(convertPt(874.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,548.00));
      corners.push_back(convertPt(180.00,548.00));
      corners.push_back(convertPt(180.00,541.00));
      corners.push_back(convertPt(193.00,541.00));
      corners.push_back(convertPt(193.00,533.00));
      corners.push_back(convertPt(206.00,533.00));
      corners.push_back(convertPt(206.00,518.00));
      corners.push_back(convertPt(218.00,518.00));
      corners.push_back(convertPt(218.00,511.00));
      corners.push_back(convertPt(257.00,511.00));
      corners.push_back(convertPt(257.00,489.00));
      corners.push_back(convertPt(283.00,489.00));
      corners.push_back(convertPt(283.00,482.00));
      corners.push_back(convertPt(309.00,482.00));
      corners.push_back(convertPt(309.00,466.00));
      corners.push_back(convertPt(322.00,466.00));
      corners.push_back(convertPt(322.00,459.00));
      corners.push_back(convertPt(334.00,459.00));
      corners.push_back(convertPt(334.00,452.00));
      corners.push_back(convertPt(360.00,452.00));
      corners.push_back(convertPt(360.00,422.00));
      corners.push_back(convertPt(374.00,422.00));
      corners.push_back(convertPt(374.00,415.00));
      corners.push_back(convertPt(386.00,415.00));
      corners.push_back(convertPt(386.00,407.00));
      corners.push_back(convertPt(398.00,407.00));
      corners.push_back(convertPt(398.00,400.00));
      corners.push_back(convertPt(412.00,400.00));
      corners.push_back(convertPt(412.00,393.00));
      corners.push_back(convertPt(424.00,393.00));
      corners.push_back(convertPt(424.00,385.00));
      corners.push_back(convertPt(438.00,385.00));
      corners.push_back(convertPt(438.00,377.00));
      corners.push_back(convertPt(450.00,377.00));
      corners.push_back(convertPt(450.00,370.00));
      corners.push_back(convertPt(463.00,370.00));
      corners.push_back(convertPt(463.00,363.00));
      corners.push_back(convertPt(476.00,363.00));
      corners.push_back(convertPt(476.00,356.00));
      corners.push_back(convertPt(489.00,356.00));
      corners.push_back(convertPt(489.00,363.00));
      corners.push_back(convertPt(514.00,363.00));
      corners.push_back(convertPt(514.00,356.00));
      corners.push_back(convertPt(527.00,356.00));
      corners.push_back(convertPt(527.00,348.00));
      corners.push_back(convertPt(541.00,348.00));
      corners.push_back(convertPt(541.00,341.00));
      corners.push_back(convertPt(553.00,341.00));
      corners.push_back(convertPt(553.00,334.00));
      corners.push_back(convertPt(579.00,334.00));
      corners.push_back(convertPt(579.00,325.00));
      corners.push_back(convertPt(591.00,325.00));
      corners.push_back(convertPt(591.00,311.00));
      corners.push_back(convertPt(605.00,311.00));
      corners.push_back(convertPt(605.00,304.00));
      corners.push_back(convertPt(618.00,304.00));
      corners.push_back(convertPt(618.00,289.00));
      corners.push_back(convertPt(643.00,289.00));
      corners.push_back(convertPt(643.00,281.00));
      corners.push_back(convertPt(656.00,281.00));
      corners.push_back(convertPt(656.00,273.00));
      corners.push_back(convertPt(669.00,273.00));
      corners.push_back(convertPt(669.00,266.00));
      corners.push_back(convertPt(694.00,266.00));
      corners.push_back(convertPt(694.00,259.00));
      corners.push_back(convertPt(708.00,259.00));
      corners.push_back(convertPt(708.00,252.00));
      corners.push_back(convertPt(720.00,252.00));
      corners.push_back(convertPt(720.00,244.00));
      corners.push_back(convertPt(746.00,244.00));
      corners.push_back(convertPt(746.00,237.00));
      corners.push_back(convertPt(758.00,237.00));
      corners.push_back(convertPt(758.00,229.00));
      corners.push_back(convertPt(784.00,229.00));
      corners.push_back(convertPt(784.00,222.00));
      corners.push_back(convertPt(797.00,222.00));
      corners.push_back(convertPt(797.00,215.00));
      corners.push_back(convertPt(836.00,215.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(450.00,377.00));
      corners.push_back(convertPt(450.00,385.00));
      corners.push_back(convertPt(438.00,385.00));
      corners.push_back(convertPt(438.00,393.00));
      corners.push_back(convertPt(463.00,393.00));
      corners.push_back(convertPt(463.00,377.00));
      corners.push_back(convertPt(450.00,377.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(398.00,407.00));
      corners.push_back(convertPt(398.00,415.00));
      corners.push_back(convertPt(386.00,415.00));
      corners.push_back(convertPt(386.00,422.00));
      corners.push_back(convertPt(412.00,422.00));
      corners.push_back(convertPt(412.00,407.00));
      corners.push_back(convertPt(398.00,407.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(1, contoursPointer));

      ///// 0.28pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(887.00,170.00));
      corners.push_back(convertPt(887.00,178.00));
      corners.push_back(convertPt(874.00,178.00));
      corners.push_back(convertPt(874.00,200.00));
      corners.push_back(convertPt(887.00,200.00));
      corners.push_back(convertPt(887.00,215.00));
      corners.push_back(convertPt(874.00,215.00));
      corners.push_back(convertPt(874.00,222.00));
      corners.push_back(convertPt(887.00,222.00));
      corners.push_back(convertPt(887.00,237.00));
      corners.push_back(convertPt(874.00,237.00));
      corners.push_back(convertPt(874.00,282.00));
      corners.push_back(convertPt(887.00,282.00));
      corners.push_back(convertPt(887.00,333.00));
      corners.push_back(convertPt(900.00,333.00));
      corners.push_back(convertPt(900.00,393.00));
      corners.push_back(convertPt(887.00,393.00));
      corners.push_back(convertPt(887.00,422.00));
      corners.push_back(convertPt(900.00,422.00));
      corners.push_back(convertPt(900.00,429.00));
      corners.push_back(convertPt(887.00,429.00));
      corners.push_back(convertPt(887.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,526.00));
      corners.push_back(convertPt(180.00,526.00));
      corners.push_back(convertPt(180.00,518.00));
      corners.push_back(convertPt(193.00,518.00));
      corners.push_back(convertPt(193.00,511.00));
      corners.push_back(convertPt(206.00,511.00));
      corners.push_back(convertPt(206.00,503.00));
      corners.push_back(convertPt(218.00,503.00));
      corners.push_back(convertPt(218.00,496.00));
      corners.push_back(convertPt(232.00,496.00));
      corners.push_back(convertPt(232.00,489.00));
      corners.push_back(convertPt(245.00,489.00));
      corners.push_back(convertPt(245.00,482.00));
      corners.push_back(convertPt(257.00,482.00));
      corners.push_back(convertPt(257.00,466.00));
      corners.push_back(convertPt(270.00,466.00));
      corners.push_back(convertPt(270.00,459.00));
      corners.push_back(convertPt(283.00,459.00));
      corners.push_back(convertPt(283.00,452.00));
      corners.push_back(convertPt(309.00,452.00));
      corners.push_back(convertPt(309.00,445.00));
      corners.push_back(convertPt(322.00,445.00));
      corners.push_back(convertPt(322.00,437.00));
      corners.push_back(convertPt(335.00,437.00));
      corners.push_back(convertPt(335.00,430.00));
      corners.push_back(convertPt(347.00,430.00));
      corners.push_back(convertPt(347.00,422.00));
      corners.push_back(convertPt(360.00,422.00));
      corners.push_back(convertPt(360.00,415.00));
      corners.push_back(convertPt(374.00,415.00));
      corners.push_back(convertPt(374.00,407.00));
      corners.push_back(convertPt(386.00,407.00));
      corners.push_back(convertPt(386.00,400.00));
      corners.push_back(convertPt(398.00,400.00));
      corners.push_back(convertPt(398.00,393.00));
      corners.push_back(convertPt(412.00,393.00));
      corners.push_back(convertPt(412.00,385.00));
      corners.push_back(convertPt(424.00,385.00));
      corners.push_back(convertPt(424.00,377.00));
      corners.push_back(convertPt(438.00,377.00));
      corners.push_back(convertPt(438.00,370.00));
      corners.push_back(convertPt(450.00,370.00));
      corners.push_back(convertPt(450.00,363.00));
      corners.push_back(convertPt(463.00,363.00));
      corners.push_back(convertPt(463.00,356.00));
      corners.push_back(convertPt(489.00,356.00));
      corners.push_back(convertPt(489.00,348.00));
      corners.push_back(convertPt(502.00,348.00));
      corners.push_back(convertPt(502.00,341.00));
      corners.push_back(convertPt(514.00,341.00));
      corners.push_back(convertPt(514.00,326.00));
      corners.push_back(convertPt(541.00,326.00));
      corners.push_back(convertPt(541.00,318.00));
      corners.push_back(convertPt(553.00,318.00));
      corners.push_back(convertPt(553.00,311.00));
      corners.push_back(convertPt(566.00,311.00));
      corners.push_back(convertPt(566.00,304.00));
      corners.push_back(convertPt(579.00,304.00));
      corners.push_back(convertPt(579.00,296.00));
      corners.push_back(convertPt(591.00,296.00));
      corners.push_back(convertPt(591.00,289.00));
      corners.push_back(convertPt(605.00,289.00));
      corners.push_back(convertPt(605.00,282.00));
      corners.push_back(convertPt(618.00,282.00));
      corners.push_back(convertPt(618.00,274.00));
      corners.push_back(convertPt(631.00,274.00));
      corners.push_back(convertPt(631.00,266.00));
      corners.push_back(convertPt(643.00,266.00));
      corners.push_back(convertPt(643.00,259.00));
      corners.push_back(convertPt(669.00,259.00));
      corners.push_back(convertPt(669.00,244.00));
      corners.push_back(convertPt(694.00,244.00));
      corners.push_back(convertPt(694.00,237.00));
      corners.push_back(convertPt(708.00,237.00));
      corners.push_back(convertPt(708.00,229.00));
      corners.push_back(convertPt(720.00,229.00));
      corners.push_back(convertPt(720.00,222.00));
      corners.push_back(convertPt(733.00,222.00));
      corners.push_back(convertPt(733.00,215.00));
      corners.push_back(convertPt(758.00,215.00));
      corners.push_back(convertPt(758.00,207.00));
      corners.push_back(convertPt(772.00,207.00));
      corners.push_back(convertPt(772.00,200.00));
      corners.push_back(convertPt(797.00,200.00));
      corners.push_back(convertPt(797.00,186.00));
      corners.push_back(convertPt(836.00,186.00));
      corners.push_back(convertPt(836.00,177.00));
      corners.push_back(convertPt(849.00,177.00));
      corners.push_back(convertPt(849.00,170.00));
      corners.push_back(convertPt(887.00,170.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(553.00,318.00));
      corners.push_back(convertPt(553.00,326.00));
      corners.push_back(convertPt(541.00,326.00));
      corners.push_back(convertPt(541.00,334.00));
      corners.push_back(convertPt(566.00,334.00));
      corners.push_back(convertPt(566.00,318.00));
      corners.push_back(convertPt(553.00,318.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(502.00,348.00));
      corners.push_back(convertPt(502.00,356.00));
      corners.push_back(convertPt(514.00,356.00));
      corners.push_back(convertPt(514.00,348.00));
      corners.push_back(convertPt(502.00,348.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(489.00,356.00));
      corners.push_back(convertPt(489.00,363.00));
      corners.push_back(convertPt(502.00,363.00));
      corners.push_back(convertPt(502.00,356.00));
      corners.push_back(convertPt(489.00,356.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(450.00,377.00));
      corners.push_back(convertPt(450.00,385.00));
      corners.push_back(convertPt(463.00,385.00));
      corners.push_back(convertPt(463.00,377.00));
      corners.push_back(convertPt(450.00,377.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(438.00,385.00));
      corners.push_back(convertPt(438.00,393.00));
      corners.push_back(convertPt(450.00,393.00));
      corners.push_back(convertPt(450.00,385.00));
      corners.push_back(convertPt(438.00,385.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(334.00,445.00));
      corners.push_back(convertPt(334.00,452.00));
      corners.push_back(convertPt(347.00,452.00));
      corners.push_back(convertPt(347.00,445.00));
      corners.push_back(convertPt(334.00,445.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(296.00,466.00));
      corners.push_back(convertPt(296.00,474.00));
      corners.push_back(convertPt(309.00,474.00));
      corners.push_back(convertPt(309.00,466.00));
      corners.push_back(convertPt(296.00,466.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(283.00,474.00));
      corners.push_back(convertPt(283.00,482.00));
      corners.push_back(convertPt(296.00,482.00));
      corners.push_back(convertPt(296.00,474.00));
      corners.push_back(convertPt(283.00,474.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(2, contoursPointer));

      ///// 0.35pb /////
      contoursPointer = new Contours();

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(887.00,156.00));
      corners.push_back(convertPt(887.00,170.00));
      corners.push_back(convertPt(900.00,170.00));
      corners.push_back(convertPt(900.00,178.00));
      corners.push_back(convertPt(887.00,178.00));
      corners.push_back(convertPt(887.00,193.00));
      corners.push_back(convertPt(900.00,193.00));
      corners.push_back(convertPt(900.00,215.00));
      corners.push_back(convertPt(887.00,215.00));
      corners.push_back(convertPt(887.00,222.00));
      corners.push_back(convertPt(900.00,222.00));
      corners.push_back(convertPt(900.00,237.00));
      corners.push_back(convertPt(887.00,237.00));
      corners.push_back(convertPt(887.00,273.00));
      corners.push_back(convertPt(900.00,273.00));
      corners.push_back(convertPt(900.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,518.00));
      corners.push_back(convertPt(180.00,518.00));
      corners.push_back(convertPt(180.00,511.00));
      corners.push_back(convertPt(193.00,511.00));
      corners.push_back(convertPt(193.00,503.00));
      corners.push_back(convertPt(206.00,503.00));
      corners.push_back(convertPt(206.00,496.00));
      corners.push_back(convertPt(218.00,496.00));
      corners.push_back(convertPt(218.00,489.00));
      corners.push_back(convertPt(232.00,489.00));
      corners.push_back(convertPt(232.00,482.00));
      corners.push_back(convertPt(245.00,482.00));
      corners.push_back(convertPt(245.00,474.00));
      corners.push_back(convertPt(257.00,474.00));
      corners.push_back(convertPt(257.00,466.00));
      corners.push_back(convertPt(270.00,466.00));
      corners.push_back(convertPt(270.00,459.00));
      corners.push_back(convertPt(283.00,459.00));
      corners.push_back(convertPt(283.00,452.00));
      corners.push_back(convertPt(296.00,452.00));
      corners.push_back(convertPt(296.00,445.00));
      corners.push_back(convertPt(309.00,445.00));
      corners.push_back(convertPt(309.00,437.00));
      corners.push_back(convertPt(322.00,437.00));
      corners.push_back(convertPt(322.00,430.00));
      corners.push_back(convertPt(335.00,430.00));
      corners.push_back(convertPt(335.00,422.00));
      corners.push_back(convertPt(347.00,422.00));
      corners.push_back(convertPt(347.00,415.00));
      corners.push_back(convertPt(360.00,415.00));
      corners.push_back(convertPt(360.00,407.00));
      corners.push_back(convertPt(374.00,407.00));
      corners.push_back(convertPt(374.00,400.00));
      corners.push_back(convertPt(386.00,400.00));
      corners.push_back(convertPt(386.00,393.00));
      corners.push_back(convertPt(398.00,393.00));
      corners.push_back(convertPt(398.00,385.00));
      corners.push_back(convertPt(412.00,385.00));
      corners.push_back(convertPt(412.00,377.00));
      corners.push_back(convertPt(424.00,377.00));
      corners.push_back(convertPt(424.00,370.00));
      corners.push_back(convertPt(438.00,370.00));
      corners.push_back(convertPt(438.00,363.00));
      corners.push_back(convertPt(450.00,363.00));
      corners.push_back(convertPt(450.00,356.00));
      corners.push_back(convertPt(476.00,356.00));
      corners.push_back(convertPt(476.00,348.00));
      corners.push_back(convertPt(489.00,348.00));
      corners.push_back(convertPt(489.00,334.00));
      corners.push_back(convertPt(502.00,334.00));
      corners.push_back(convertPt(502.00,326.00));
      corners.push_back(convertPt(514.00,326.00));
      corners.push_back(convertPt(514.00,318.00));
      corners.push_back(convertPt(541.00,318.00));
      corners.push_back(convertPt(541.00,311.00));
      corners.push_back(convertPt(553.00,311.00));
      corners.push_back(convertPt(553.00,304.00));
      corners.push_back(convertPt(566.00,304.00));
      corners.push_back(convertPt(566.00,296.00));
      corners.push_back(convertPt(579.00,296.00));
      corners.push_back(convertPt(579.00,289.00));
      corners.push_back(convertPt(591.00,289.00));
      corners.push_back(convertPt(591.00,282.00));
      corners.push_back(convertPt(605.00,282.00));
      corners.push_back(convertPt(605.00,274.00));
      corners.push_back(convertPt(618.00,274.00));
      corners.push_back(convertPt(618.00,266.00));
      corners.push_back(convertPt(631.00,266.00));
      corners.push_back(convertPt(631.00,259.00));
      corners.push_back(convertPt(643.00,259.00));
      corners.push_back(convertPt(643.00,252.00));
      corners.push_back(convertPt(656.00,252.00));
      corners.push_back(convertPt(656.00,244.00));
      corners.push_back(convertPt(681.00,244.00));
      corners.push_back(convertPt(681.00,237.00));
      corners.push_back(convertPt(694.00,237.00));
      corners.push_back(convertPt(694.00,229.00));
      corners.push_back(convertPt(708.00,229.00));
      corners.push_back(convertPt(708.00,222.00));
      corners.push_back(convertPt(720.00,222.00));
      corners.push_back(convertPt(720.00,215.00));
      corners.push_back(convertPt(733.00,215.00));
      corners.push_back(convertPt(733.00,207.00));
      corners.push_back(convertPt(746.00,207.00));
      corners.push_back(convertPt(746.00,200.00));
      corners.push_back(convertPt(758.00,200.00));
      corners.push_back(convertPt(758.00,193.00));
      corners.push_back(convertPt(784.00,193.00));
      corners.push_back(convertPt(784.00,186.00));
      corners.push_back(convertPt(797.00,186.00));
      corners.push_back(convertPt(797.00,177.00));
      corners.push_back(convertPt(810.00,177.00));
      corners.push_back(convertPt(810.00,170.00));
      corners.push_back(convertPt(836.00,170.00));
      corners.push_back(convertPt(836.00,163.00));
      corners.push_back(convertPt(849.00,163.00));
      corners.push_back(convertPt(849.00,156.00));
      corners.push_back(convertPt(887.00,156.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(553.00,318.00));
      corners.push_back(convertPt(553.00,326.00));
      corners.push_back(convertPt(566.00,326.00));
      corners.push_back(convertPt(566.00,318.00));
      corners.push_back(convertPt(553.00,318.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      corners.clear();
      oldSize = contoursPointer->size();
      corners.push_back(convertPt(541.00,326.00));
      corners.push_back(convertPt(541.00,334.00));
      corners.push_back(convertPt(553.00,334.00));
      corners.push_back(convertPt(553.00,326.00));
      corners.push_back(convertPt(541.00,326.00));
      contoursPointer->resize(oldSize + corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin() + oldSize, makeLine);

      _limitContours.insert(LimitContourEntry(3, contoursPointer));

      ///// 0.42pb /////
      corners.clear();
      corners.push_back(convertPt(874.00,134.00));
      corners.push_back(convertPt(874.00,141.00));
      corners.push_back(convertPt(887.00,141.00));
      corners.push_back(convertPt(887.00,156.00));
      corners.push_back(convertPt(900.00,156.00));
      corners.push_back(convertPt(900.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,511.00));
      corners.push_back(convertPt(180.00,511.00));
      corners.push_back(convertPt(180.00,503.00));
      corners.push_back(convertPt(193.00,503.00));
      corners.push_back(convertPt(193.00,496.00));
      corners.push_back(convertPt(206.00,496.00));
      corners.push_back(convertPt(206.00,489.00));
      corners.push_back(convertPt(218.00,489.00));
      corners.push_back(convertPt(218.00,482.00));
      corners.push_back(convertPt(232.00,482.00));
      corners.push_back(convertPt(232.00,474.00));
      corners.push_back(convertPt(257.00,474.00));
      corners.push_back(convertPt(257.00,466.00));
      corners.push_back(convertPt(270.00,466.00));
      corners.push_back(convertPt(270.00,459.00));
      corners.push_back(convertPt(283.00,459.00));
      corners.push_back(convertPt(283.00,452.00));
      corners.push_back(convertPt(296.00,452.00));
      corners.push_back(convertPt(296.00,445.00));
      corners.push_back(convertPt(309.00,445.00));
      corners.push_back(convertPt(309.00,437.00));
      corners.push_back(convertPt(322.00,437.00));
      corners.push_back(convertPt(322.00,430.00));
      corners.push_back(convertPt(335.00,430.00));
      corners.push_back(convertPt(335.00,422.00));
      corners.push_back(convertPt(347.00,422.00));
      corners.push_back(convertPt(347.00,415.00));
      corners.push_back(convertPt(360.00,415.00));
      corners.push_back(convertPt(360.00,407.00));
      corners.push_back(convertPt(374.00,407.00));
      corners.push_back(convertPt(374.00,400.00));
      corners.push_back(convertPt(386.00,400.00));
      corners.push_back(convertPt(386.00,393.00));
      corners.push_back(convertPt(398.00,393.00));
      corners.push_back(convertPt(398.00,385.00));
      corners.push_back(convertPt(412.00,385.00));
      corners.push_back(convertPt(412.00,377.00));
      corners.push_back(convertPt(424.00,377.00));
      corners.push_back(convertPt(424.00,370.00));
      corners.push_back(convertPt(438.00,370.00));
      corners.push_back(convertPt(438.00,363.00));
      corners.push_back(convertPt(450.00,363.00));
      corners.push_back(convertPt(450.00,356.00));
      corners.push_back(convertPt(463.00,356.00));
      corners.push_back(convertPt(463.00,348.00));
      corners.push_back(convertPt(476.00,348.00));
      corners.push_back(convertPt(476.00,341.00));
      corners.push_back(convertPt(489.00,341.00));
      corners.push_back(convertPt(489.00,334.00));
      corners.push_back(convertPt(502.00,334.00));
      corners.push_back(convertPt(502.00,326.00));
      corners.push_back(convertPt(514.00,326.00));
      corners.push_back(convertPt(514.00,318.00));
      corners.push_back(convertPt(527.00,318.00));
      corners.push_back(convertPt(527.00,311.00));
      corners.push_back(convertPt(541.00,311.00));
      corners.push_back(convertPt(541.00,304.00));
      corners.push_back(convertPt(553.00,304.00));
      corners.push_back(convertPt(553.00,296.00));
      corners.push_back(convertPt(566.00,296.00));
      corners.push_back(convertPt(566.00,289.00));
      corners.push_back(convertPt(579.00,289.00));
      corners.push_back(convertPt(579.00,282.00));
      corners.push_back(convertPt(605.00,282.00));
      corners.push_back(convertPt(605.00,274.00));
      corners.push_back(convertPt(618.00,274.00));
      corners.push_back(convertPt(618.00,266.00));
      corners.push_back(convertPt(631.00,266.00));
      corners.push_back(convertPt(631.00,259.00));
      corners.push_back(convertPt(643.00,259.00));
      corners.push_back(convertPt(643.00,252.00));
      corners.push_back(convertPt(656.00,252.00));
      corners.push_back(convertPt(656.00,244.00));
      corners.push_back(convertPt(669.00,244.00));
      corners.push_back(convertPt(669.00,237.00));
      corners.push_back(convertPt(681.00,237.00));
      corners.push_back(convertPt(681.00,229.00));
      corners.push_back(convertPt(694.00,229.00));
      corners.push_back(convertPt(694.00,222.00));
      corners.push_back(convertPt(708.00,222.00));
      corners.push_back(convertPt(708.00,215.00));
      corners.push_back(convertPt(720.00,215.00));
      corners.push_back(convertPt(720.00,207.00));
      corners.push_back(convertPt(733.00,207.00));
      corners.push_back(convertPt(733.00,200.00));
      corners.push_back(convertPt(758.00,200.00));
      corners.push_back(convertPt(758.00,193.00));
      corners.push_back(convertPt(772.00,193.00));
      corners.push_back(convertPt(772.00,186.00));
      corners.push_back(convertPt(784.00,186.00));
      corners.push_back(convertPt(784.00,177.00));
      corners.push_back(convertPt(797.00,177.00));
      corners.push_back(convertPt(797.00,170.00));
      corners.push_back(convertPt(810.00,170.00));
      corners.push_back(convertPt(810.00,163.00));
      corners.push_back(convertPt(823.00,163.00));
      corners.push_back(convertPt(823.00,156.00));
      corners.push_back(convertPt(849.00,156.00));
      corners.push_back(convertPt(849.00,149.00));
      corners.push_back(convertPt(861.00,149.00));
      corners.push_back(convertPt(861.00,134.00));
      corners.push_back(convertPt(874.00,134.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(4, contoursPointer));

      ///// 0.49pb /////
      corners.clear();
      corners.push_back(convertPt(887.00,126.00));
      corners.push_back(convertPt(887.00,141.00));
      corners.push_back(convertPt(900.00,141.00));
      corners.push_back(convertPt(900.00,215.00));
      corners.push_back(convertPt(913.00,215.00));
      corners.push_back(convertPt(913.00,222.00));
      corners.push_back(convertPt(900.00,222.00));
      corners.push_back(convertPt(900.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,511.00));
      corners.push_back(convertPt(180.00,511.00));
      corners.push_back(convertPt(180.00,503.00));
      corners.push_back(convertPt(193.00,503.00));
      corners.push_back(convertPt(193.00,496.00));
      corners.push_back(convertPt(206.00,496.00));
      corners.push_back(convertPt(206.00,489.00));
      corners.push_back(convertPt(218.00,489.00));
      corners.push_back(convertPt(218.00,482.00));
      corners.push_back(convertPt(232.00,482.00));
      corners.push_back(convertPt(232.00,474.00));
      corners.push_back(convertPt(245.00,474.00));
      corners.push_back(convertPt(245.00,466.00));
      corners.push_back(convertPt(257.00,466.00));
      corners.push_back(convertPt(257.00,459.00));
      corners.push_back(convertPt(270.00,459.00));
      corners.push_back(convertPt(270.00,452.00));
      corners.push_back(convertPt(283.00,452.00));
      corners.push_back(convertPt(283.00,445.00));
      corners.push_back(convertPt(296.00,445.00));
      corners.push_back(convertPt(296.00,437.00));
      corners.push_back(convertPt(309.00,437.00));
      corners.push_back(convertPt(309.00,430.00));
      corners.push_back(convertPt(322.00,430.00));
      corners.push_back(convertPt(322.00,422.00));
      corners.push_back(convertPt(335.00,422.00));
      corners.push_back(convertPt(335.00,415.00));
      corners.push_back(convertPt(347.00,415.00));
      corners.push_back(convertPt(347.00,407.00));
      corners.push_back(convertPt(360.00,407.00));
      corners.push_back(convertPt(360.00,400.00));
      corners.push_back(convertPt(374.00,400.00));
      corners.push_back(convertPt(374.00,393.00));
      corners.push_back(convertPt(398.00,393.00));
      corners.push_back(convertPt(398.00,377.00));
      corners.push_back(convertPt(412.00,377.00));
      corners.push_back(convertPt(412.00,370.00));
      corners.push_back(convertPt(424.00,370.00));
      corners.push_back(convertPt(424.00,363.00));
      corners.push_back(convertPt(438.00,363.00));
      corners.push_back(convertPt(438.00,356.00));
      corners.push_back(convertPt(463.00,356.00));
      corners.push_back(convertPt(463.00,348.00));
      corners.push_back(convertPt(476.00,348.00));
      corners.push_back(convertPt(476.00,341.00));
      corners.push_back(convertPt(489.00,341.00));
      corners.push_back(convertPt(489.00,334.00));
      corners.push_back(convertPt(502.00,334.00));
      corners.push_back(convertPt(502.00,326.00));
      corners.push_back(convertPt(514.00,326.00));
      corners.push_back(convertPt(514.00,318.00));
      corners.push_back(convertPt(527.00,318.00));
      corners.push_back(convertPt(527.00,311.00));
      corners.push_back(convertPt(541.00,311.00));
      corners.push_back(convertPt(541.00,304.00));
      corners.push_back(convertPt(553.00,304.00));
      corners.push_back(convertPt(553.00,296.00));
      corners.push_back(convertPt(566.00,296.00));
      corners.push_back(convertPt(566.00,289.00));
      corners.push_back(convertPt(579.00,289.00));
      corners.push_back(convertPt(579.00,282.00));
      corners.push_back(convertPt(591.00,282.00));
      corners.push_back(convertPt(591.00,274.00));
      corners.push_back(convertPt(605.00,274.00));
      corners.push_back(convertPt(605.00,266.00));
      corners.push_back(convertPt(618.00,266.00));
      corners.push_back(convertPt(618.00,259.00));
      corners.push_back(convertPt(631.00,259.00));
      corners.push_back(convertPt(631.00,252.00));
      corners.push_back(convertPt(643.00,252.00));
      corners.push_back(convertPt(643.00,244.00));
      corners.push_back(convertPt(669.00,244.00));
      corners.push_back(convertPt(669.00,237.00));
      corners.push_back(convertPt(681.00,237.00));
      corners.push_back(convertPt(681.00,229.00));
      corners.push_back(convertPt(694.00,229.00));
      corners.push_back(convertPt(694.00,222.00));
      corners.push_back(convertPt(708.00,222.00));
      corners.push_back(convertPt(708.00,215.00));
      corners.push_back(convertPt(720.00,215.00));
      corners.push_back(convertPt(720.00,207.00));
      corners.push_back(convertPt(733.00,207.00));
      corners.push_back(convertPt(733.00,200.00));
      corners.push_back(convertPt(746.00,200.00));
      corners.push_back(convertPt(746.00,193.00));
      corners.push_back(convertPt(758.00,193.00));
      corners.push_back(convertPt(758.00,186.00));
      corners.push_back(convertPt(772.00,186.00));
      corners.push_back(convertPt(772.00,177.00));
      corners.push_back(convertPt(784.00,177.00));
      corners.push_back(convertPt(784.00,170.00));
      corners.push_back(convertPt(797.00,170.00));
      corners.push_back(convertPt(797.00,163.00));
      corners.push_back(convertPt(810.00,163.00));
      corners.push_back(convertPt(810.00,156.00));
      corners.push_back(convertPt(823.00,156.00));
      corners.push_back(convertPt(823.00,149.00));
      corners.push_back(convertPt(836.00,149.00));
      corners.push_back(convertPt(836.00,141.00));
      corners.push_back(convertPt(861.00,141.00));
      corners.push_back(convertPt(861.00,126.00));
      corners.push_back(convertPt(887.00,126.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(5, contoursPointer));

      ///// 0.56pb /////
      corners.clear();
      corners.push_back(convertPt(887.00,119.00));
      corners.push_back(convertPt(887.00,133.00));
      corners.push_back(convertPt(900.00,133.00));
      corners.push_back(convertPt(900.00,156.00));
      corners.push_back(convertPt(913.00,156.00));
      corners.push_back(convertPt(913.00,244.00));
      corners.push_back(convertPt(900.00,244.00));
      corners.push_back(convertPt(900.00,318.00));
      corners.push_back(convertPt(913.00,318.00));
      corners.push_back(convertPt(913.00,422.00));
      corners.push_back(convertPt(900.00,422.00));
      corners.push_back(convertPt(900.00,466.00));
      corners.push_back(convertPt(913.00,466.00));
      corners.push_back(convertPt(913.00,481.00));
      corners.push_back(convertPt(900.00,481.00));
      corners.push_back(convertPt(900.00,488.00));
      corners.push_back(convertPt(913.00,488.00));
      corners.push_back(convertPt(913.00,496.00));
      corners.push_back(convertPt(900.00,496.00));
      corners.push_back(convertPt(900.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,511.00));
      corners.push_back(convertPt(180.00,511.00));
      corners.push_back(convertPt(180.00,503.00));
      corners.push_back(convertPt(193.00,503.00));
      corners.push_back(convertPt(193.00,496.00));
      corners.push_back(convertPt(206.00,496.00));
      corners.push_back(convertPt(206.00,489.00));
      corners.push_back(convertPt(218.00,489.00));
      corners.push_back(convertPt(218.00,482.00));
      corners.push_back(convertPt(232.00,482.00));
      corners.push_back(convertPt(232.00,474.00));
      corners.push_back(convertPt(245.00,474.00));
      corners.push_back(convertPt(245.00,466.00));
      corners.push_back(convertPt(257.00,466.00));
      corners.push_back(convertPt(257.00,459.00));
      corners.push_back(convertPt(270.00,459.00));
      corners.push_back(convertPt(270.00,452.00));
      corners.push_back(convertPt(283.00,452.00));
      corners.push_back(convertPt(283.00,445.00));
      corners.push_back(convertPt(296.00,445.00));
      corners.push_back(convertPt(296.00,437.00));
      corners.push_back(convertPt(309.00,437.00));
      corners.push_back(convertPt(309.00,430.00));
      corners.push_back(convertPt(322.00,430.00));
      corners.push_back(convertPt(322.00,422.00));
      corners.push_back(convertPt(335.00,422.00));
      corners.push_back(convertPt(335.00,415.00));
      corners.push_back(convertPt(347.00,415.00));
      corners.push_back(convertPt(347.00,407.00));
      corners.push_back(convertPt(360.00,407.00));
      corners.push_back(convertPt(360.00,400.00));
      corners.push_back(convertPt(374.00,400.00));
      corners.push_back(convertPt(374.00,393.00));
      corners.push_back(convertPt(386.00,393.00));
      corners.push_back(convertPt(386.00,385.00));
      corners.push_back(convertPt(398.00,385.00));
      corners.push_back(convertPt(398.00,377.00));
      corners.push_back(convertPt(412.00,377.00));
      corners.push_back(convertPt(412.00,370.00));
      corners.push_back(convertPt(424.00,370.00));
      corners.push_back(convertPt(424.00,363.00));
      corners.push_back(convertPt(438.00,363.00));
      corners.push_back(convertPt(438.00,356.00));
      corners.push_back(convertPt(450.00,356.00));
      corners.push_back(convertPt(450.00,348.00));
      corners.push_back(convertPt(463.00,348.00));
      corners.push_back(convertPt(463.00,341.00));
      corners.push_back(convertPt(476.00,341.00));
      corners.push_back(convertPt(476.00,334.00));
      corners.push_back(convertPt(502.00,334.00));
      corners.push_back(convertPt(502.00,326.00));
      corners.push_back(convertPt(514.00,326.00));
      corners.push_back(convertPt(514.00,318.00));
      corners.push_back(convertPt(527.00,318.00));
      corners.push_back(convertPt(527.00,311.00));
      corners.push_back(convertPt(541.00,311.00));
      corners.push_back(convertPt(541.00,304.00));
      corners.push_back(convertPt(553.00,304.00));
      corners.push_back(convertPt(553.00,296.00));
      corners.push_back(convertPt(566.00,296.00));
      corners.push_back(convertPt(566.00,289.00));
      corners.push_back(convertPt(579.00,289.00));
      corners.push_back(convertPt(579.00,282.00));
      corners.push_back(convertPt(591.00,282.00));
      corners.push_back(convertPt(591.00,274.00));
      corners.push_back(convertPt(605.00,274.00));
      corners.push_back(convertPt(605.00,266.00));
      corners.push_back(convertPt(618.00,266.00));
      corners.push_back(convertPt(618.00,259.00));
      corners.push_back(convertPt(631.00,259.00));
      corners.push_back(convertPt(631.00,252.00));
      corners.push_back(convertPt(643.00,252.00));
      corners.push_back(convertPt(643.00,244.00));
      corners.push_back(convertPt(656.00,244.00));
      corners.push_back(convertPt(656.00,237.00));
      corners.push_back(convertPt(669.00,237.00));
      corners.push_back(convertPt(669.00,229.00));
      corners.push_back(convertPt(681.00,229.00));
      corners.push_back(convertPt(681.00,222.00));
      corners.push_back(convertPt(694.00,222.00));
      corners.push_back(convertPt(694.00,215.00));
      corners.push_back(convertPt(708.00,215.00));
      corners.push_back(convertPt(708.00,207.00));
      corners.push_back(convertPt(733.00,207.00));
      corners.push_back(convertPt(733.00,193.00));
      corners.push_back(convertPt(746.00,193.00));
      corners.push_back(convertPt(746.00,186.00));
      corners.push_back(convertPt(758.00,186.00));
      corners.push_back(convertPt(758.00,177.00));
      corners.push_back(convertPt(772.00,177.00));
      corners.push_back(convertPt(772.00,170.00));
      corners.push_back(convertPt(784.00,170.00));
      corners.push_back(convertPt(784.00,163.00));
      corners.push_back(convertPt(810.00,163.00));
      corners.push_back(convertPt(810.00,149.00));
      corners.push_back(convertPt(823.00,149.00));
      corners.push_back(convertPt(823.00,141.00));
      corners.push_back(convertPt(836.00,141.00));
      corners.push_back(convertPt(836.00,134.00));
      corners.push_back(convertPt(861.00,134.00));
      corners.push_back(convertPt(861.00,126.00));
      corners.push_back(convertPt(874.00,126.00));
      corners.push_back(convertPt(874.00,119.00));
      corners.push_back(convertPt(887.00,119.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(6, contoursPointer));

      ///// 0.63pb /////
      corners.clear();
      corners.push_back(convertPt(900.00,119.00));
      corners.push_back(convertPt(900.00,149.00));
      corners.push_back(convertPt(913.00,149.00));
      corners.push_back(convertPt(913.00,259.00));
      corners.push_back(convertPt(900.00,259.00));
      corners.push_back(convertPt(900.00,266.00));
      corners.push_back(convertPt(913.00,266.00));
      corners.push_back(convertPt(913.00,511.00));
      corners.push_back(convertPt(900.00,511.00));
      corners.push_back(convertPt(900.00,555.00));
      corners.push_back(convertPt(912.00,555.00));
      corners.push_back(convertPt(912.00,805.00));
      corners.push_back(convertPt(169.00,805.00));
      corners.push_back(convertPt(169.00,511.00));
      corners.push_back(convertPt(180.00,511.00));
      corners.push_back(convertPt(180.00,503.00));
      corners.push_back(convertPt(193.00,503.00));
      corners.push_back(convertPt(193.00,496.00));
      corners.push_back(convertPt(206.00,496.00));
      corners.push_back(convertPt(206.00,489.00));
      corners.push_back(convertPt(218.00,489.00));
      corners.push_back(convertPt(218.00,482.00));
      corners.push_back(convertPt(232.00,482.00));
      corners.push_back(convertPt(232.00,474.00));
      corners.push_back(convertPt(245.00,474.00));
      corners.push_back(convertPt(245.00,466.00));
      corners.push_back(convertPt(257.00,466.00));
      corners.push_back(convertPt(257.00,459.00));
      corners.push_back(convertPt(270.00,459.00));
      corners.push_back(convertPt(270.00,452.00));
      corners.push_back(convertPt(283.00,452.00));
      corners.push_back(convertPt(283.00,445.00));
      corners.push_back(convertPt(296.00,445.00));
      corners.push_back(convertPt(296.00,437.00));
      corners.push_back(convertPt(309.00,437.00));
      corners.push_back(convertPt(309.00,430.00));
      corners.push_back(convertPt(322.00,430.00));
      corners.push_back(convertPt(322.00,422.00));
      corners.push_back(convertPt(335.00,422.00));
      corners.push_back(convertPt(335.00,415.00));
      corners.push_back(convertPt(347.00,415.00));
      corners.push_back(convertPt(347.00,407.00));
      corners.push_back(convertPt(360.00,407.00));
      corners.push_back(convertPt(360.00,400.00));
      corners.push_back(convertPt(374.00,400.00));
      corners.push_back(convertPt(374.00,393.00));
      corners.push_back(convertPt(386.00,393.00));
      corners.push_back(convertPt(386.00,385.00));
      corners.push_back(convertPt(398.00,385.00));
      corners.push_back(convertPt(398.00,377.00));
      corners.push_back(convertPt(412.00,377.00));
      corners.push_back(convertPt(412.00,370.00));
      corners.push_back(convertPt(424.00,370.00));
      corners.push_back(convertPt(424.00,363.00));
      corners.push_back(convertPt(438.00,363.00));
      corners.push_back(convertPt(438.00,356.00));
      corners.push_back(convertPt(450.00,356.00));
      corners.push_back(convertPt(450.00,348.00));
      corners.push_back(convertPt(463.00,348.00));
      corners.push_back(convertPt(463.00,341.00));
      corners.push_back(convertPt(476.00,341.00));
      corners.push_back(convertPt(476.00,334.00));
      corners.push_back(convertPt(489.00,334.00));
      corners.push_back(convertPt(489.00,326.00));
      corners.push_back(convertPt(502.00,326.00));
      corners.push_back(convertPt(502.00,318.00));
      corners.push_back(convertPt(514.00,318.00));
      corners.push_back(convertPt(514.00,311.00));
      corners.push_back(convertPt(541.00,311.00));
      corners.push_back(convertPt(541.00,304.00));
      corners.push_back(convertPt(553.00,304.00));
      corners.push_back(convertPt(553.00,296.00));
      corners.push_back(convertPt(566.00,296.00));
      corners.push_back(convertPt(566.00,289.00));
      corners.push_back(convertPt(579.00,289.00));
      corners.push_back(convertPt(579.00,282.00));
      corners.push_back(convertPt(591.00,282.00));
      corners.push_back(convertPt(591.00,274.00));
      corners.push_back(convertPt(605.00,274.00));
      corners.push_back(convertPt(605.00,266.00));
      corners.push_back(convertPt(618.00,266.00));
      corners.push_back(convertPt(618.00,259.00));
      corners.push_back(convertPt(631.00,259.00));
      corners.push_back(convertPt(631.00,252.00));
      corners.push_back(convertPt(643.00,252.00));
      corners.push_back(convertPt(643.00,244.00));
      corners.push_back(convertPt(656.00,244.00));
      corners.push_back(convertPt(656.00,237.00));
      corners.push_back(convertPt(669.00,237.00));
      corners.push_back(convertPt(669.00,229.00));
      corners.push_back(convertPt(681.00,229.00));
      corners.push_back(convertPt(681.00,222.00));
      corners.push_back(convertPt(694.00,222.00));
      corners.push_back(convertPt(694.00,215.00));
      corners.push_back(convertPt(708.00,215.00));
      corners.push_back(convertPt(708.00,207.00));
      corners.push_back(convertPt(720.00,207.00));
      corners.push_back(convertPt(720.00,200.00));
      corners.push_back(convertPt(733.00,200.00));
      corners.push_back(convertPt(733.00,193.00));
      corners.push_back(convertPt(746.00,193.00));
      corners.push_back(convertPt(746.00,186.00));
      corners.push_back(convertPt(758.00,186.00));
      corners.push_back(convertPt(758.00,177.00));
      corners.push_back(convertPt(772.00,177.00));
      corners.push_back(convertPt(772.00,170.00));
      corners.push_back(convertPt(784.00,170.00));
      corners.push_back(convertPt(784.00,163.00));
      corners.push_back(convertPt(797.00,163.00));
      corners.push_back(convertPt(797.00,156.00));
      corners.push_back(convertPt(810.00,156.00));
      corners.push_back(convertPt(810.00,149.00));
      corners.push_back(convertPt(823.00,149.00));
      corners.push_back(convertPt(823.00,141.00));
      corners.push_back(convertPt(836.00,141.00));
      corners.push_back(convertPt(836.00,134.00));
      corners.push_back(convertPt(849.00,134.00));
      corners.push_back(convertPt(849.00,126.00));
      corners.push_back(convertPt(874.00,126.00));
      corners.push_back(convertPt(874.00,119.00));
      corners.push_back(convertPt(900.00,119.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(7, contoursPointer));

      ///// 0.7pb /////
      corners.clear();
      corners.push_back(convertPt(925.00,52.00));
      corners.push_back(convertPt(925.00,805.0));
      corners.push_back(convertPt(169.00,805.0));
      corners.push_back(convertPt(169.00,482.0));
      corners.push_back(convertPt(180.00,482.0));
      corners.push_back(convertPt(180.00,475.0));
      corners.push_back(convertPt(193.00,475.0));
      corners.push_back(convertPt(193.00,467.0));
      corners.push_back(convertPt(207.00,467.0));
      corners.push_back(convertPt(207.00,459.0));
      corners.push_back(convertPt(219.00,459.0));
      corners.push_back(convertPt(219.00,452.0));
      corners.push_back(convertPt(232.00,452.0));
      corners.push_back(convertPt(232.00,445.0));
      corners.push_back(convertPt(245.00,445.0));
      corners.push_back(convertPt(245.00,437.0));
      corners.push_back(convertPt(257.00,437.0));
      corners.push_back(convertPt(257.00,430.0));
      corners.push_back(convertPt(271.00,430.0));
      corners.push_back(convertPt(271.00,423.0));
      corners.push_back(convertPt(283.00,423.0));
      corners.push_back(convertPt(283.00,415.0));
      corners.push_back(convertPt(296.00,415.0));
      corners.push_back(convertPt(296.00,408.0));
      corners.push_back(convertPt(309.00,408.0));
      corners.push_back(convertPt(309.00,400.0));
      corners.push_back(convertPt(322.00,400.0));
      corners.push_back(convertPt(322.00,393.0));
      corners.push_back(convertPt(335.00,393.0));
      corners.push_back(convertPt(335.00,386.0));
      corners.push_back(convertPt(347.00,386.0));
      corners.push_back(convertPt(347.00,378.0));
      corners.push_back(convertPt(360.00,378.0));
      corners.push_back(convertPt(360.00,371.0));
      corners.push_back(convertPt(374.00,371.0));
      corners.push_back(convertPt(374.00,364.0));
      corners.push_back(convertPt(386.00,364.0));
      corners.push_back(convertPt(386.00,356.0));
      corners.push_back(convertPt(399.00,356.0));
      corners.push_back(convertPt(399.00,348.0));
      corners.push_back(convertPt(412.00,348.0));
      corners.push_back(convertPt(412.00,341.0));
      corners.push_back(convertPt(424.00,341.0));
      corners.push_back(convertPt(424.00,334.0));
      corners.push_back(convertPt(438.00,334.0));
      corners.push_back(convertPt(438.00,326.0));
      corners.push_back(convertPt(451.00,326.0));
      corners.push_back(convertPt(451.00,319.0));
      corners.push_back(convertPt(463.00,319.0));
      corners.push_back(convertPt(463.00,311.0));
      corners.push_back(convertPt(476.00,311.0));
      corners.push_back(convertPt(476.00,304.0));
      corners.push_back(convertPt(489.00,304.0));
      corners.push_back(convertPt(489.00,296.0));
      corners.push_back(convertPt(502.00,296.0));
      corners.push_back(convertPt(502.00,289.0));
      corners.push_back(convertPt(515.00,289.0));
      corners.push_back(convertPt(515.00,282.0));
      corners.push_back(convertPt(527.00,282.0));
      corners.push_back(convertPt(527.00,274.0));
      corners.push_back(convertPt(541.00,274.0));
      corners.push_back(convertPt(541.00,267.0));
      corners.push_back(convertPt(553.00,267.0));
      corners.push_back(convertPt(553.00,260.0));
      corners.push_back(convertPt(566.00,260.0));
      corners.push_back(convertPt(566.00,252.0));
      corners.push_back(convertPt(579.00,252.0));
      corners.push_back(convertPt(579.00,244.0));
      corners.push_back(convertPt(591.00,244.0));
      corners.push_back(convertPt(591.00,237.0));
      corners.push_back(convertPt(605.00,237.0));
      corners.push_back(convertPt(605.00,230.0));
      corners.push_back(convertPt(618.00,230.0));
      corners.push_back(convertPt(618.00,223.0));
      corners.push_back(convertPt(631.00,223.0));
      corners.push_back(convertPt(631.00,216.0));
      corners.push_back(convertPt(643.00,216.0));
      corners.push_back(convertPt(643.00,208.0));
      corners.push_back(convertPt(656.00,208.0));
      corners.push_back(convertPt(656.00,200.0));
      corners.push_back(convertPt(669.00,200.0));
      corners.push_back(convertPt(669.00,193.0));
      corners.push_back(convertPt(682.00,193.0));
      corners.push_back(convertPt(682.00,186.0));
      corners.push_back(convertPt(695.00,186.0));
      corners.push_back(convertPt(695.00,178.0));
      corners.push_back(convertPt(708.00,178.0));
      corners.push_back(convertPt(708.00,171.0));
      corners.push_back(convertPt(720.00,171.0));
      corners.push_back(convertPt(720.00,163.0));
      corners.push_back(convertPt(733.00,163.0));
      corners.push_back(convertPt(733.00,156.0));
      corners.push_back(convertPt(747.00,156.0));
      corners.push_back(convertPt(747.00,149.0));
      corners.push_back(convertPt(759.00,149.0));
      corners.push_back(convertPt(759.00,141.0));
      corners.push_back(convertPt(772.00,141.0));
      corners.push_back(convertPt(772.00,134.0));
      corners.push_back(convertPt(784.00,134.0));
      corners.push_back(convertPt(784.00,127.0));
      corners.push_back(convertPt(798.00,127.0));
      corners.push_back(convertPt(798.00,119.0));
      corners.push_back(convertPt(811.00,119.0));
      corners.push_back(convertPt(811.00,112.0));
      corners.push_back(convertPt(823.00,112.0));
      corners.push_back(convertPt(823.00,104.0));
      corners.push_back(convertPt(836.00,104.0));
      corners.push_back(convertPt(836.00,97.00));
      corners.push_back(convertPt(849.00,97.00));
      corners.push_back(convertPt(849.00,90.00));
      corners.push_back(convertPt(862.00,90.00));
      corners.push_back(convertPt(862.00,82.00));
      corners.push_back(convertPt(875.00,82.00));
      corners.push_back(convertPt(875.00,75.00));
      corners.push_back(convertPt(887.00,75.00));
      corners.push_back(convertPt(887.00,68.00));
      corners.push_back(convertPt(900.00,68.00));
      corners.push_back(convertPt(900.00,60.00));
      corners.push_back(convertPt(913.00,60.00));
      corners.push_back(convertPt(913.00,52.00));
      corners.push_back(convertPt(925.00,52.00));

      contoursPointer = new Contours();
      contoursPointer->resize(corners.size() - 1);
      std::transform(corners.begin(), --corners.end(), ++corners.begin(),
                     contoursPointer->begin(), makeLine);
      _limitContours.insert(LimitContourEntry(8, contoursPointer));

    }

  }
}
